import { Injectable, NgModule, Component, ViewChild, Input, Output, Renderer2 } from '@angular/core';
import { CustomFieldsModule, ControlErrorsModule, EmptyStateModule, DynamicFormModule, ButtonModule, LoadingStateModule, InfoSignModule, FieldType, FormField, LocaleModule } from '@seniorsistemas/angular-components';
import { CommonModule } from '@angular/common';
import { FormsModule, ReactiveFormsModule, Validators, FormControl, FormGroup, FormBuilder } from '@angular/forms';
import { TranslateModule, TranslateService } from '@ngx-translate/core';
import { HotkeyModule, Hotkey, HotkeysService } from 'angular2-hotkeys';
import { CurrencyMaskModule } from 'ng2-currency-mask';
import { CalendarModule } from 'primeng/calendar';
import { ConfirmDialogModule } from 'primeng/confirmdialog';
import { InputTextModule } from 'primeng/inputtext';
import { MessagesModule } from 'primeng/messages';
import { PanelModule } from 'primeng/panel';
import { SharedModule } from 'primeng/shared';
import { SplitButtonModule } from 'primeng/splitbutton';
import { HttpClient, HttpParams } from '@angular/common/http';
import { MessageService } from 'primeng/components/common/messageservice';
import { throwError, Subject, forkJoin, of } from 'rxjs';
import { catchError, takeUntil, filter, map, tap } from 'rxjs/operators';
import { __awaiter } from 'tslib';
import { user } from '@seniorsistemas/senior-platform-data';
import { InputTextareaModule } from 'primeng/inputtextarea';
import { InputMaskModule } from 'primeng/inputmask';
import { DropdownModule } from 'primeng/dropdown';
import { InputSwitchModule } from 'primeng/inputswitch';
import { Router, ActivatedRoute } from '@angular/router';
import * as moment_ from 'moment';
import { ConfirmationService } from 'primeng/api';
import { PermissionsModule } from '@seniorsistemas/platform-components';

/**
 * @fileoverview added by tsickle
 * Generated from: shared/focus/focus.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FocusService {
    /**
     * @return {?}
     */
    focusFirstInvalidInput() {
        /** @type {?} */
        const invalidFields = Array.from(document.getElementsByClassName("ng-invalid"));
        /** @type {?} */
        const firstField = invalidFields.find((/**
         * @param {?} f
         * @return {?}
         */
        (f) => f.nodeName !== "FORM"));
        if (firstField.nodeName === "P-CALENDAR") {
            /** @type {?} */
            const firstInputId = firstField.getAttribute("ng-reflect-input-id");
            /** @type {?} */
            const firstInvalidInput = document.getElementById(firstInputId);
            if (firstInvalidInput)
                firstInvalidInput.focus();
        }
        else if (firstField.nodeName === "S-LOOKUP") {
            /** @type {?} */
            const nestedInput = this.getNestedInput(firstField.firstElementChild);
            if (nestedInput)
                nestedInput.focus();
        }
        else
            firstField.focus();
    }
    /**
     * @private
     * @param {?} element
     * @return {?}
     */
    getNestedInput(element) {
        if (element.nodeName === "INPUT") {
            return element;
        }
        return this.getNestedInput(element.firstElementChild);
    }
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/services/field-customization.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FieldCustomizationService {
    /**
     * @param {?} http
     * @param {?} messageService
     */
    constructor(http, messageService) {
        this.http = http;
        this.messageService = messageService;
        this.http = http;
        this.messageService = messageService;
        this.defaultCatch = this.defaultCatch.bind(this);
    }
    /**
     * @param {?} objects
     * @return {?}
     */
    commitFiles(objects) {
        return this.http.post("platform/field_customization/actions/commitObject", { objects }).pipe(this.defaultCatch());
    }
    /**
     * @param {?} objects
     * @return {?}
     */
    deleteFiles(objects) {
        return this.http.post("platform/field_customization/actions/deleteObjects", objects).pipe(this.defaultCatch());
    }
    /**
     * @param {?} formGroup
     * @return {?}
     */
    getFiles(formGroup) {
        /** @type {?} */
        let fieldCustomization = [];
        if (formGroup.value.custom) {
            fieldCustomization = formGroup.value.custom.fieldCustomization || [];
            delete formGroup.value.custom.fieldCustomization;
        }
        /** @type {?} */
        const filesToCommit = [];
        /** @type {?} */
        let filesToDelete = {};
        fieldCustomization.forEach((/**
         * @param {?} __0
         * @return {?}
         */
        ({ domain, service, entity, toDelete, toInsert }) => {
            if (!this.isEmpty(toInsert)) {
                /** @type {?} */
                const files = Object.keys(toInsert).map((/**
                 * @param {?} key
                 * @return {?}
                 */
                (key) => {
                    /** @type {?} */
                    const version = toInsert[key].version;
                    /** @type {?} */
                    const fileName = toInsert[key].name;
                    /** @type {?} */
                    const objectId = toInsert[key].objectId;
                    return { version, fileName, objectId };
                }));
                if (!this.isEmpty(files)) {
                    filesToCommit.push(...files);
                }
            }
            if (!this.isEmpty(toDelete)) {
                /** @type {?} */
                const objects = [];
                Object.keys(toDelete).forEach((/**
                 * @param {?} key
                 * @return {?}
                 */
                (key) => {
                    /** @type {?} */
                    const fields = toDelete[key] || [];
                    /** @type {?} */
                    const files = fields.map((/**
                     * @param {?} file
                     * @return {?}
                     */
                    (file) => {
                        return {
                            field: key,
                            objectId: file,
                        };
                    }));
                    objects.push(...files);
                }));
                filesToDelete = { domain, service, entityName: entity, objects };
            }
        }));
        return { filesToCommit, filesToDelete };
    }
    /**
     * @param {?} object
     * @return {?}
     */
    isEmpty(object) {
        if (Array.isArray(object)) {
            return object.length === 0;
        }
        return Object.entries(object).length === 0 && object.constructor === Object;
    }
    /**
     * @return {?}
     */
    defaultCatch() {
        return catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            if (err) {
                /** @type {?} */
                const summary = err.status ? String(err.status) : "Error";
                /** @type {?} */
                const detail = (err.error && err.error.message) || err.statusText || err.message || "Error";
                this.messageService.add({
                    severity: "error",
                    summary,
                    detail,
                });
            }
            return throwError(err);
        }));
    }
}
FieldCustomizationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
FieldCustomizationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    FieldCustomizationService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    FieldCustomizationService.prototype.messageService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/storage/storage.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StorageService {
    constructor() {
        this.GET_USER_ID = user.getUserData().then((/**
         * @param {?} user
         * @return {?}
         */
        user => user.id));
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    store(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            localStorage.setItem(`${yield this.GET_USER_ID}_${key}`, JSON.stringify(value));
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return JSON.parse(localStorage.getItem(`${yield this.GET_USER_ID}_${key}`)) || {};
        });
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    StorageService.prototype.GET_USER_ID;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/storage/filters-storage.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FiltersStorageService extends StorageService {
    constructor() {
        super(...arguments);
        this.FILTERS_KEY = "SENIOR_FILTERS";
    }
    /**
     * @param {?} key
     * @param {?} filters
     * @return {?}
     */
    storeFilters(key, filters) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            this.removeEmptyValues(filters);
            store[key] = filters;
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    getFilters(key) {
        const _super = Object.create(null, {
            get: { get: () => super.get }
        });
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            return store[key] || {};
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    removeFilter(key) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            delete store[key];
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    /**
     * @param {?} key
     * @param {?} filters
     * @return {?}
     */
    clearFilterValue(key, filters) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            this.removeEmptyValues(filters);
            store[key] = filters;
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    /**
     * @private
     * @param {?} filters
     * @return {?}
     */
    removeEmptyValues(filters) {
        Object.keys(filters).forEach((/**
         * @param {?} field
         * @return {?}
         */
        (field) => {
            if (Array.isArray(filters[field]) ? filters[field].length === 0 : !filters[field]) {
                delete filters[field];
            }
        }));
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    FiltersStorageService.prototype.FILTERS_KEY;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/storage/paginator-storage.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginatorStorageService {
    constructor() {
        this.GET_USER_ID = user.getUserData().then((/**
         * @param {?} user
         * @return {?}
         */
        user => user.id));
        this.PAGINATOR_KEY = "SENIOR_PAGINATOR";
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    store(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            sessionStorage.setItem(`${yield this.GET_USER_ID}_${key}`, JSON.stringify(value));
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return JSON.parse(sessionStorage.getItem(`${yield this.GET_USER_ID}_${key}`)) || {};
        });
    }
    /**
     * @param {?} key
     * @param {?=} listParams
     * @return {?}
     */
    storePaginator(key, listParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield this.get(this.PAGINATOR_KEY)) || {};
            store[key] = listParams;
            yield this.store(this.PAGINATOR_KEY, store);
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    getPaginator(key) {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield this.get(this.PAGINATOR_KEY)) || {};
            return store[key] || {};
        });
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    PaginatorStorageService.prototype.GET_USER_ID;
    /**
     * @type {?}
     * @private
     */
    PaginatorStorageService.prototype.PAGINATOR_KEY;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/shared-schedule.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SharedScheduleModule {
}
SharedScheduleModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    /*{CA:MODULE_IMPORTS:START}*/
                    SplitButtonModule,
                    MessagesModule,
                    FormsModule,
                    ReactiveFormsModule,
                    CommonModule,
                    CurrencyMaskModule,
                    TranslateModule,
                    CustomFieldsModule,
                    ControlErrorsModule,
                    EmptyStateModule,
                    DynamicFormModule,
                    PanelModule,
                    InputTextModule,
                    ButtonModule,
                    ConfirmDialogModule,
                    CalendarModule,
                    SharedModule,
                    HotkeyModule,
                    LoadingStateModule,
                    InputMaskModule,
                    InfoSignModule,
                    DropdownModule,
                    InputTextareaModule
                    /*{CA:MODULE_IMPORTS:END}*/
                ],
                providers: [
                    FiltersStorageService,
                    PaginatorStorageService,
                    FocusService,
                    FieldCustomizationService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                /*{CA:MODULE_CONFIG:START}*/
                exports: [
                    SplitButtonModule,
                    MessagesModule,
                    FormsModule,
                    ReactiveFormsModule,
                    CommonModule,
                    CurrencyMaskModule,
                    TranslateModule,
                    CustomFieldsModule,
                    ControlErrorsModule,
                    EmptyStateModule,
                    DynamicFormModule,
                    PanelModule,
                    InputTextModule,
                    ButtonModule,
                    ConfirmDialogModule,
                    CalendarModule,
                    SharedModule,
                    HotkeyModule,
                    LoadingStateModule,
                    InputTextareaModule,
                    InputSwitchModule
                ]
                /*{CA:MODULE_CONFIG:END}*/
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/e-001-pes.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class E001Pes {
    constructor() {
        this.excluido = false;
    }
    /**
     * @param {?} e001PesDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(e001PesDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, e001PesDto);
        model.createdDate = model.createdDate && moment(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["nomPes"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} e001Pes
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(e001Pes, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, e001Pes);
        dto.createdDate = dto.createdDate && moment(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    E001Pes.prototype.id;
    /** @type {?} */
    E001Pes.prototype.nomPes;
    /** @type {?} */
    E001Pes.prototype.excluido;
    /** @type {?} */
    E001Pes.prototype.extIntSts;
    /** @type {?} */
    E001Pes.prototype.extIntMsg;
    /** @type {?} */
    E001Pes.prototype.createdBy;
    /** @type {?} */
    E001Pes.prototype.createdDate;
    /** @type {?} */
    E001Pes.prototype.lastModifiedBy;
    /** @type {?} */
    E001Pes.prototype.lastModifiedDate;
    /** @type {?} */
    E001Pes.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/employee.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$1 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class Employee {
    constructor() {
        this.deleted = false;
    }
    /**
     * @param {?} employeeDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(employeeDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, employeeDto);
        model.hireDate = model.hireDate && moment$1(model.hireDate).toDate();
        model.dismissalDate = model.dismissalDate && moment$1(model.dismissalDate).toDate();
        model.createdDate = model.createdDate && moment$1(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$1(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "code",
            "person.nomPes",
            "hireDate",
            "dismissalDate",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "E001Pes" && model.person)
            model.person = E001Pes.fromDto(model.person, "Employee");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} employee
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(employee, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, employee);
        dto.hireDate = dto.hireDate && moment$1(dto.hireDate).format("YYYY-MM-DD");
        dto.dismissalDate = dto.dismissalDate && moment$1(dto.dismissalDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$1(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$1(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "E001Pes" && dto.person)
            dto.person = E001Pes.toDto(dto.person, "Employee");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Employee.prototype.id;
    /** @type {?} */
    Employee.prototype.code;
    /** @type {?} */
    Employee.prototype.person;
    /** @type {?} */
    Employee.prototype.employer;
    /** @type {?} */
    Employee.prototype.hireDate;
    /** @type {?} */
    Employee.prototype.dismissalDate;
    /** @type {?} */
    Employee.prototype.deleted;
    /** @type {?} */
    Employee.prototype.extIntSts;
    /** @type {?} */
    Employee.prototype.extIntMsg;
    /** @type {?} */
    Employee.prototype.createdBy;
    /** @type {?} */
    Employee.prototype.createdDate;
    /** @type {?} */
    Employee.prototype.lastModifiedBy;
    /** @type {?} */
    Employee.prototype.lastModifiedDate;
    /** @type {?} */
    Employee.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/bridge.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$2 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class Bridge {
    /**
     * @param {?} bridgeDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(bridgeDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, bridgeDto);
        model.originDate = model.originDate && moment$2(model.originDate).toDate();
        model.destinationDate = model.destinationDate && moment$2(model.destinationDate).toDate();
        model.createdDate = model.createdDate && moment$2(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$2(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "originDate",
            "destinationDate",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "Bridge");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} bridge
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(bridge, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, bridge);
        dto.originDate = dto.originDate && moment$2(dto.originDate).format("YYYY-MM-DD");
        dto.destinationDate = dto.destinationDate && moment$2(dto.destinationDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$2(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$2(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "Bridge");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Bridge.prototype.id;
    /** @type {?} */
    Bridge.prototype.employee;
    /** @type {?} */
    Bridge.prototype.originDate;
    /** @type {?} */
    Bridge.prototype.destinationDate;
    /** @type {?} */
    Bridge.prototype.createdBy;
    /** @type {?} */
    Bridge.prototype.createdDate;
    /** @type {?} */
    Bridge.prototype.lastModifiedBy;
    /** @type {?} */
    Bridge.prototype.lastModifiedDate;
    /** @type {?} */
    Bridge.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/services/entity-service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
class EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} entityUrl
     * @param {?} actionsUrl
     * @param {?} translate
     */
    constructor(http, messageService, entityUrl, actionsUrl, translate) {
        this.http = http;
        this.messageService = messageService;
        this.entityUrl = entityUrl;
        this.actionsUrl = actionsUrl;
        this.translate = translate;
        this.http = http;
        this.messageService = messageService;
        this.entityUrl = entityUrl;
        this.actionsUrl = actionsUrl;
        this.translate = translate;
        this.defaultCatch = this.defaultCatch.bind(this);
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    getListQueryParams(listParams) {
        const { page = 0, size = 10, sort = [], filterQuery = "", displayFields = [] } = listParams;
        /** @type {?} */
        let params = new HttpParams();
        params = params.append("size", String(size));
        params = params.append("offset", String(page));
        if (sort && sort.length) {
            params = params.append("orderby", sort
                .map((/**
             * @param {?} s
             * @return {?}
             */
            s => {
                /** @type {?} */
                let order = "";
                if (s.order === 1)
                    order = " asc";
                else if (s.order === -1)
                    order = " desc";
                return `${s.field}${order}`;
            }))
                .join(", "));
        }
        if (filterQuery)
            params = params.append("filter", filterQuery);
        if (displayFields && displayFields.length)
            params = params.append("displayfields", displayFields.join());
        return params;
    }
    /**
     * @private
     * @param {?} listParams
     * @return {?}
     */
    getBodyParams(listParams) {
        const { page = 0, size = 10, sort = [], filterQuery = "", displayFields = [] } = listParams;
        /** @type {?} */
        const bodyParams = {};
        bodyParams.size = size;
        bodyParams.offset = page;
        if (sort && sort.length) {
            bodyParams.orderBy = sort
                .map((/**
             * @param {?} s
             * @return {?}
             */
            s => {
                /** @type {?} */
                let order = "";
                if (s.order === 1)
                    order = " asc";
                else if (s.order === -1)
                    order = " desc";
                return `${s.field}${order}`;
            }))
                .join(", ");
        }
        if (filterQuery)
            bodyParams.filter = filterQuery;
        if (displayFields && displayFields.length)
            bodyParams.displayfields = displayFields.join();
        return bodyParams;
    }
    /**
     * @return {?}
     */
    defaultCatch() {
        return catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            if (err) {
                /** @type {?} */
                let summary = err.status ? String(err.status) : "Error";
                /** @type {?} */
                let detail = (err.error && err.error.message) || err.statusText || err.message || "Error";
                if (err.status === 401) {
                    summary = this.translate.instant("hcm_clocking_event_foundation.general.error_unauthorized_title");
                    detail = this.translate.instant("hcm_clocking_event_foundation.general.error_unauthorized_description");
                }
                this.messageService.add({
                    severity: "error",
                    summary,
                    detail,
                });
            }
            return throwError(err);
        }));
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    list(listParams) {
        return this.http.get(this.entityUrl, { params: this.getListQueryParams(listParams) }).pipe(this.defaultCatch());
    }
    /**
     * @param {?} id
     * @return {?}
     */
    get(id) {
        return this.http.get(`${this.entityUrl}/${id}`).pipe(this.defaultCatch());
    }
    /**
     * @param {?} entity
     * @return {?}
     */
    insert(entity) {
        return this.http.post(`${this.entityUrl}`, entity).pipe(this.defaultCatch());
    }
    /**
     * @param {?} id
     * @param {?} entity
     * @return {?}
     */
    update(id, entity) {
        return this.http.put(`${this.entityUrl}/${id}`, entity).pipe(this.defaultCatch());
    }
    /**
     * @param {?} id
     * @return {?}
     */
    delete(id) {
        return this.http.delete(`${this.entityUrl}/${id}`).pipe(this.defaultCatch());
    }
    /**
     * @param {?} listParams
     * @param {?} action
     * @return {?}
     */
    listCustomFilter(listParams, action) {
        return this.http.post(`${this.actionsUrl}/${action}`, this.getBodyParams(listParams)).pipe(this.defaultCatch());
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.entityUrl;
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.actionsUrl;
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.translate;
}
/**
 * @record
 */
function ListParams() { }
if (false) {
    /** @type {?|undefined} */
    ListParams.prototype.page;
    /** @type {?|undefined} */
    ListParams.prototype.size;
    /** @type {?|undefined} */
    ListParams.prototype.sort;
    /** @type {?|undefined} */
    ListParams.prototype.filterQuery;
    /** @type {?|undefined} */
    ListParams.prototype.displayFields;
}
/**
 * @record
 */
function BodyParams() { }
if (false) {
    /** @type {?|undefined} */
    BodyParams.prototype.offset;
    /** @type {?|undefined} */
    BodyParams.prototype.size;
    /** @type {?|undefined} */
    BodyParams.prototype.orderBy;
    /** @type {?|undefined} */
    BodyParams.prototype.filter;
    /** @type {?|undefined} */
    BodyParams.prototype.displayfields;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/bridge.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BridgeService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/bridge`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
}
BridgeService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
BridgeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    BridgeService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    BridgeService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    BridgeService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/company-clocking-event-indications.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CompanyClockingEventIndicationsService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/companyClockingEventIndications`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
}
CompanyClockingEventIndicationsService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
CompanyClockingEventIndicationsService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    CompanyClockingEventIndicationsService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    CompanyClockingEventIndicationsService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    CompanyClockingEventIndicationsService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/employee.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EmployeeService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_contract/employment_contract/entities/employee`, `hcm_contract/employment_contract/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    listExternalEmployee(listParams) {
        return this.http
            .get("hcm_contract/employment_contract/entities/employee", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
}
EmployeeService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
EmployeeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    EmployeeService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    EmployeeService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    EmployeeService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/utils/date-validator.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$3 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/**
 * @param {?} startDateTime
 * @param {?} endDateTime
 * @return {?}
 */
function startDateTimeIsBeforeEndDateTimeValidator(startDateTime, endDateTime) {
    if (startDateTime && endDateTime && startDateTime.value && endDateTime.value) {
        /** @type {?} */
        const isInvalid = moment$3(startDateTime.value).seconds(0).isSameOrAfter(moment$3(endDateTime.value).seconds(0)) ? { startDateTimeIsBeforeEndDateTime: { value: [endDateTime.value, startDateTime.value] } } : null;
        if (isInvalid) {
            startDateTime.markAsDirty();
            endDateTime.markAsDirty();
            endDateTime.setErrors(isInvalid);
            startDateTime.setErrors(isInvalid);
            return isInvalid;
        }
        removeErrorFromField(endDateTime, 'startDateTimeIsBeforeEndDateTime');
        removeErrorFromField(startDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    else if (startDateTime && startDateTime.value && !(endDateTime && endDateTime.value)) {
        removeErrorFromField(startDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    else if (!(startDateTime && startDateTime.value) && endDateTime && endDateTime.value) {
        removeErrorFromField(endDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    return null;
}
;
/**
 * @param {?} startDate
 * @param {?} endDate
 * @return {?}
 */
function startDateIsBeforeOrEqualToEndDateValidator(startDate, endDate) {
    if (startDate && endDate && startDate.value && endDate.value) {
        /** @type {?} */
        const forbidden = startDate.value > endDate.value ? { startDateIsBeforeEndDate: { value: endDate.value } } : null;
        if (forbidden) {
            startDate.markAsDirty();
            endDate.markAsDirty();
            startDate.setErrors(forbidden);
            endDate.setErrors(forbidden);
            return forbidden;
        }
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (startDate && startDate.value && !(endDate && endDate.value)) {
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (!(startDate && startDate.value) && endDate && endDate.value) {
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
    }
    return null;
}
/**
 * @param {?} field
 * @param {?} error
 * @return {?}
 */
function removeErrorFromField(field, error) {
    if (field.errors) {
        delete field.errors[error];
    }
    if (JSON.stringify(field.errors) == JSON.stringify({})) {
        field.setErrors(null);
    }
}
/**
 * @param {?} startDate
 * @param {?} endDate
 * @return {?}
 */
function startDateIsBeforeEndDateValidator(startDate, endDate) {
    if (startDate && endDate && startDate.value && endDate.value) {
        /** @type {?} */
        const forbidden = moment$3(startDate.value).isSameOrAfter(endDate.value) ? { startDateIsBeforeEndDate: { value: endDate.value } } : null;
        if (forbidden) {
            startDate.markAsDirty();
            endDate.markAsDirty();
            startDate.setErrors(forbidden);
            endDate.setErrors(forbidden);
            return forbidden;
        }
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (startDate && startDate.value && !(endDate && endDate.value)) {
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (!(startDate && startDate.value) && endDate && endDate.value) {
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
    }
    return null;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/utils/utils.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const numberTypes = [FieldType.Integer, FieldType.Double];
/** @type {?} */
const numberPattern = /^\d+\b$/;
/** @type {?} */
const mergeUnique = (/**
 * @param {?} array
 * @param {?} otherArray
 * @return {?}
 */
(array, otherArray) => array.concat(otherArray.filter((/**
 * @param {?} item
 * @return {?}
 */
item => !array.includes(item)))));
/** @type {?} */
const isValidFilter = (/**
 * @param {?} type
 * @param {?} value
 * @return {?}
 */
(type, value) => {
    const { isValidValue, typeExists } = getTypeInformation(type, value);
    return !(typeExists && !isValidValue);
});
/** @type {?} */
const getTypeInformation = (/**
 * @param {?} type
 * @param {?} value
 * @return {?}
 */
(type, value) => {
    switch (type) {
        case FieldType.Time:
        case FieldType.Date:
        case FieldType.DateTime:
            return { isValidValue: false, typeExists: true };
        case FieldType.Integer:
        case FieldType.Double:
            return {
                isValidValue: value.match(numberPattern),
                typeExists: numberTypes.includes(type),
            };
        default:
            return {
                isValidValue: value.match(numberPattern),
                typeExists: numberTypes.includes(type),
            };
    }
});
/** @type {?} */
const convertMinutesToTime = (/**
 * @param {?} minutes
 * @param {?=} monthMinute
 * @return {?}
 */
(minutes, monthMinute) => {
    /** @type {?} */
    const time = minutes.replace(".", "");
    /** @type {?} */
    const hour = Math.floor(parseInt(time) / 60);
    /** @type {?} */
    const minute = parseInt(time) % 60;
    /** @type {?} */
    let msg = (hour < 10) ? "0" + hour : hour;
    msg += ":";
    msg += (minute < 10) ? "0" + minute : "" + minute;
    if (monthMinute) {
        msg = putZeroAtHours(msg.toString());
    }
    return msg;
});
/** @type {?} */
const putZeroAtHours = (/**
 * @param {?} msg
 * @return {?}
 */
(msg) => {
    if (msg.length === 4) {
        return "00" + msg;
    }
    else if (msg.length === 5) {
        return "0" + msg;
    }
    else {
        return msg;
    }
});
const ɵ0 = putZeroAtHours;
/** @type {?} */
const convertTimeToMinutes = (/**
 * @param {?} time
 * @return {?}
 */
(time) => {
    if (time) {
        /** @type {?} */
        const array = time.toString().split(":");
        return (array[0] * 60) + parseInt(array[1]);
    }
    return null;
});

/**
 * @fileoverview added by tsickle
 * Generated from: lib/bridge/form/bridge-form.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$4 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class BridgeFormComponent {
    /**
     * @param {?} companyClockingEventIndicationsService
     * @param {?} bridgeService
     * @param {?} router
     * @param {?} route
     * @param {?} messageService
     * @param {?} confirmationService
     * @param {?} formBuilder
     * @param {?} translate
     * @param {?} hotkeysService
     * @param {?} fieldCustomization
     * @param {?} focusService
     * @param {?} employeeService
     */
    constructor(companyClockingEventIndicationsService, bridgeService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, employeeService) {
        this.companyClockingEventIndicationsService = companyClockingEventIndicationsService;
        this.bridgeService = bridgeService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.employeeService = employeeService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"),
                value: "EMPLOYEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"),
                value: "DIRECTOR",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"),
                value: "TRAINEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"),
                value: "APRENTICE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"),
                value: "THIRD_PARTY",
            },
        ];
        this.employeeLookupDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType",
        ];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        /*{CA:CLASS_ATTRIBUTES:START}*/
        this.cacheLimitDaysBackwardScheduling = new Map();
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter((/**
             * @param {?} name
             * @return {?}
             */
            name => name === 'bridge'))).subscribe((/**
             * @return {?}
             */
            () => {
                this.onSave();
            }));
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((/**
             * @param {?} value
             * @return {?}
             */
            (value) => {
                this.loadLockedEmployee(value);
            }));
        }
        else {
            this.setHotkeys();
        }
        this.route.params
            .pipe(takeUntil(this.ngUnsubscribe))
            .subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => this.onRouteParamsChange(params)));
        this.route.data
            .pipe(takeUntil(this.ngUnsubscribe))
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => this.onRouteDataChange(data)));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLockedEmployee(value) {
        /** @type {?} */
        const employee = this.formGroup.controls['employee'].value;
        this.formGroup.reset();
        this.formGroup.controls['employee'].setValue(employee);
        if (this.formGroup.controls['employee'].value) {
            this.formGroup.controls['originDate'].setValue(moment$4(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((/**
             * @param {?} dto
             * @return {?}
             */
            (dto) => {
                this.onLoadFormSubject.next(false);
                /** @type {?} */
                const bridge = new Bridge();
                bridge.originDate = moment$4(value.evaluationDate).toDate();
                bridge.employee = Employee.fromDto(dto.contents[0], "Bridge");
                this.updateSuggestions(bridge);
                this.formGroup.patchValue(bridge);
                this.formGroup.controls['employee'].disable();
                this.loading = false;
            }));
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.unsubscribe();
        this.cacheLimitDaysBackwardScheduling.clear();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    /**
     * @return {?}
     */
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", (/**
         * @return {?}
         */
        () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", (/**
         * @return {?}
         */
        () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", (/**
         * @return {?}
         */
        () => {
            this.onCancel();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    /**
     * @return {?}
     */
    isNew() {
        return this.routeParams.bridge == "new";
    }
    /**
     * @param {?} params
     * @return {?}
     */
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue([
                "employer.codEmp",
                "code",
                "person.nomPes",
                "employmentRelationship.contractTypeLabel",
            ], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    /**
     * @param {?} displayFields
     * @param {?} ownerEntity
     * @param {?} value
     * @param {?} separator
     * @return {?}
     */
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => this.getProp(value, `${ownerEntity}.${field}`)))
            .reduce((/**
         * @param {?} acc
         * @param {?} val
         * @return {?}
         */
        (acc, val) => `${acc}${separator}${val}`));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.bridge;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity && data.entity[0]) {
            /** @type {?} */
            const canEdit = this.permissions.editar;
            if (!canEdit)
                this.formGroup.disable();
            /** @type {?} */
            const value = Bridge.fromDto(data.entity[0]);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
            /** @type {?} */
            let limitDate = new Date();
            limitDate.setDate(limitDate.getDate() -
                data.entity[1].timeEvaluationDefinition.limitDaysBackwardScheduling);
            this.cacheLimitDaysBackwardScheduling.set(data.entity[1].id, limitDate);
        }
        else {
            this.formGroup.patchValue(new Bridge());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    /**
     * @return {?}
     */
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    /**
     * @param {?} filesToDelete
     * @param {?} filesToCommit
     * @return {?}
     */
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /** @type {?} */
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    /**
     * @return {?}
     */
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        })))
            .subscribe((/**
         * @return {?}
         */
        () => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
             * @param {?} err
             * @return {?}
             */
            (err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            })))
                .subscribe((/**
             * @return {?}
             */
            () => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                if (this.lockedEmployee) {
                    this.onClose.next(true);
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            }));
        }));
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    /**
     * @return {?}
     */
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: (/**
             * @return {?}
             */
            () => this.getDeleteObservable().pipe(takeUntil(this.ngUnsubscribe)).subscribe()),
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    /**
     * @param {?} obj
     * @param {?} path
     * @return {?}
     */
    getProp(obj, path) {
        return path
            .split(".")
            .reduce((/**
         * @param {?} result
         * @param {?} prop
         * @return {?}
         */
        (result, prop) => (result[prop] === undefined ? "" : result[prop])), obj);
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((/**
         * @param {?} r
         * @return {?}
         */
        (r) => r.value === value))[0].label;
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions
                .filter((/**
             * @param {?} r
             * @return {?}
             */
            (r) => {
                /** @type {?} */
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            }))
                .map((/**
             * @param {?} r
             * @return {?}
             */
            (r) => r.value));
        }
        return [];
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.employeeLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$4(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$4(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$4(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value)
                    .map((/**
                 * @param {?} enumConstant
                 * @return {?}
                 */
                (enumConstant) => `${name} eq '${enumConstant}'`))
                    .join(" or ");
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        (filter) => filter !== ""))
            .join(" or ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                (field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === "employmentRelationship.contractType") {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                }))
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeLookupSuggestions = list.contents;
        }));
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$4(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$4(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$4(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" and ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                (field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.employeeLookupSeparator) })))) })))) // NOSONAR
        ) // NOSONAR
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeSearchGridData = list.contents; // NOSONAR
            this.employeeSearchTotalRecords = list.totalElements; // NOSONAR
        })); // NOSONAR
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getFormGroup() {
        /** @type {?} */
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            originDate: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            destinationDate: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.validLimitDaysBackwardScheduling(),
                this.startDateIsBeforeEndDate(),
            ],
        });
        formGroup.controls.employee.valueChanges.subscribe((/**
         * @param {?} employee
         * @return {?}
         */
        (employee) => {
            if (employee) {
                /** @type {?} */
                let limitDaysBackwardScheduling = this.cacheLimitDaysBackwardScheduling.get(employee.employer.id);
                if (limitDaysBackwardScheduling === undefined) {
                    this.companyClockingEventIndicationsService
                        .list({
                        filterQuery: `id eq '${employee.employer.id}'`,
                        displayFields: ['timeEvaluationDefinition.limitDaysBackwardScheduling']
                    })
                        .pipe(map((/**
                     * @param {?} data
                     * @return {?}
                     */
                    (data) => data.contents[0])), catchError((/**
                     * @param {?} error
                     * @return {?}
                     */
                    (error) => {
                        formGroup.controls.employee.setErrors({
                            hasNotCompanyClockingEventIndications: { value: error },
                        });
                        return throwError(error);
                    })))
                        .subscribe((/**
                     * @param {?} companyClockingEventIndications
                     * @return {?}
                     */
                    companyClockingEventIndications => {
                        /** @type {?} */
                        let limitDate = new Date();
                        limitDate.setDate(limitDate.getDate() -
                            companyClockingEventIndications.timeEvaluationDefinition
                                .limitDaysBackwardScheduling);
                        this.cacheLimitDaysBackwardScheduling.set(companyClockingEventIndications.id, limitDate);
                    }));
                }
            }
        }));
        return formGroup;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions,
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    goBack() {
        /** @type {?} */
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    /**
     * @private
     * @param {?} formGroup
     * @return {?}
     */
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((/**
         * @param {?} field
         * @return {?}
         */
        (field) => {
            /** @type {?} */
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        }));
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls['employee'].value;
        /** @type {?} */
        const bridgeDto = Bridge.toDto(value);
        /** @type {?} */
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.bridgeService.insert(bridgeDto);
        }
        else {
            /** @type {?} */
            const id = this.routeParams.bridge;
            observable = this.bridgeService.update(id, bridgeDto);
        }
        return observable;
    }
    /**
     * @private
     * @return {?}
     */
    getDeleteObservable() {
        return this.bridgeService.delete(this.routeParams.bridge).pipe(tap((/**
         * @return {?}
         */
        () => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
            this.goBack(); // NOSONAR
        })) // NOSONAR
        ); // NOSONAR
    } // NOSONAR
    // NOSONAR
    /**
     * @private
     * @return {?}
     */
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        /** @type {?} */
        const toValidate = ["employee"];
        if (!toValidate.every((/**
         * @param {?} e
         * @return {?}
         */
        (e) => this.allPermissions[e] && this.allPermissions[e].visualizar))) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    validLimitDaysBackwardScheduling() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const originDate = control.get("originDate");
            /** @type {?} */
            const employee = control.get("employee");
            if (employee.value && originDate.value) {
                /** @type {?} */
                const limitDate = this.cacheLimitDaysBackwardScheduling.get(employee.value.employer.id);
                if (limitDate && moment$4(originDate.value).isBefore(limitDate, "day")) {
                    originDate.setErrors({ exceededLimit: { value: originDate.value } });
                }
                else {
                    removeErrorFromField(originDate, "exceededLimit");
                }
            }
            return null;
        });
    }
    /**
     * @private
     * @return {?}
     */
    startDateIsBeforeEndDate() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const originDate = control.get("originDate");
            /** @type {?} */
            const destinationDate = control.get("destinationDate");
            startDateIsBeforeEndDateValidator(originDate, destinationDate);
            return null;
        });
    }
    /*{CA:CLASS_METHODS:END}*/
    /**
     * @private
     * @param {?} severity
     * @param {?} summary
     * @param {?} detail
     * @return {?}
     */
    addMessage(severity, summary, detail) {
        this.messageService.add({
            severity,
            summary: this.translate.instant(summary),
            detail: this.translate.instant(detail),
        });
    }
}
BridgeFormComponent.decorators = [
    { type: Component, args: [{
                template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\" \n            [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.bridge_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.bridge_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div> \n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.bridge_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                        [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                        [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                        (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                        [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.bridge_employee_search_title' | translate\"\n                        [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                        [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                        [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                        [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\"\n                        [errorMessages]=\"{\n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            hasNotCompanyClockingEventIndications: 'hcm_clocking_event_foundation.general.error_company_of_employee_need_time_evaluation_definition' | translate\n                        }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-md-6\"></div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"originDate\">{{\"hcm_clocking_event_foundation.general.bridge_origin_date\" | translate}}</label>\n                        <p-calendar #originDateFormInput inputId=\"originDate\" name=\"originDate\" [showIcon]=\"true\" formControlName=\"originDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['originDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                exceededLimit: 'hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling' | translate, \n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_start_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"destinationDate\">{{\"hcm_clocking_event_foundation.general.bridge_destination_date\" | translate}}</label>\n                        <p-calendar #destinationDateFormInput inputId=\"destinationDate\" name=\"destinationDate\" [showIcon]=\"true\"\n                            formControlName=\"destinationDate\" [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['destinationDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_end_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"bridge\" formControlName=\"custom\" *ngIf=\"formGroup.controls['custom']\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\"> \n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
                providers: [
                    ConfirmationService,
                ],
                selector: "cem-bridge-form",
                styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
            }] }
];
/** @nocollapse */
BridgeFormComponent.ctorParameters = () => [
    { type: CompanyClockingEventIndicationsService },
    { type: BridgeService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: EmployeeService }
];
BridgeFormComponent.propDecorators = {
    customTemplate: [{ type: ViewChild, args: ["customTemplate", { static: false },] }],
    customFormFields: [{ type: ViewChild, args: ["customFormFields", { static: false },] }],
    onSubmitObservable: [{ type: Input }],
    onLockedEmployeeChanges: [{ type: Input }],
    lockedEmployee: [{ type: Input }],
    onCloseObservable: [{ type: Output }],
    onLoadForm: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    BridgeFormComponent.prototype.localeConfig;
    /** @type {?} */
    BridgeFormComponent.prototype.currencyLocaleOptions;
    /** @type {?} */
    BridgeFormComponent.prototype.permissions;
    /** @type {?} */
    BridgeFormComponent.prototype.allPermissions;
    /** @type {?} */
    BridgeFormComponent.prototype.formGroup;
    /** @type {?} */
    BridgeFormComponent.prototype.loading;
    /** @type {?} */
    BridgeFormComponent.prototype.mainPanelCollapsed;
    /** @type {?} */
    BridgeFormComponent.prototype.contractTypeOptions;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeLookupSuggestions;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeLookupDisplayFields;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeAdvancedDisplayFields;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeLookupSeparator;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeSearchFields;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeSearchGridFields;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeSearchGridData;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeSearchTotalRecords;
    /** @type {?} */
    BridgeFormComponent.prototype.customTemplate;
    /** @type {?} */
    BridgeFormComponent.prototype.customFormFields;
    /** @type {?} */
    BridgeFormComponent.prototype.cacheLimitDaysBackwardScheduling;
    /** @type {?} */
    BridgeFormComponent.prototype.onSubmitObservable;
    /** @type {?} */
    BridgeFormComponent.prototype.onLockedEmployeeChanges;
    /** @type {?} */
    BridgeFormComponent.prototype.lockedEmployee;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.onClose;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.onLoadFormSubject;
    /** @type {?} */
    BridgeFormComponent.prototype.onCloseObservable;
    /** @type {?} */
    BridgeFormComponent.prototype.onLoadForm;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.routeParams;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.ngUnsubscribe;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.companyClockingEventIndicationsService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.bridgeService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.router;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.route;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.messageService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.confirmationService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.formBuilder;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.translate;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.hotkeysService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.fieldCustomization;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.focusService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.employeeService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/bridge/bridge-form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BridgeFormModule {
}
BridgeFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    LocaleModule.forChild(),
                    SharedScheduleModule
                ],
                declarations: [
                    BridgeFormComponent
                ],
                exports: [
                    BridgeFormComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/employee-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function EmployeeDto() { }
if (false) {
    /** @type {?|undefined} */
    EmployeeDto.prototype.id;
    /** @type {?} */
    EmployeeDto.prototype.code;
    /** @type {?|undefined} */
    EmployeeDto.prototype.employmentRelationship;
    /** @type {?|undefined} */
    EmployeeDto.prototype.employer;
    /** @type {?|undefined} */
    EmployeeDto.prototype.person;
    /** @type {?|undefined} */
    EmployeeDto.prototype.hireDate;
    /** @type {?|undefined} */
    EmployeeDto.prototype.dismissalDate;
    /** @type {?|undefined} */
    EmployeeDto.prototype.deleted;
    /** @type {?|undefined} */
    EmployeeDto.prototype.extIntSts;
    /** @type {?|undefined} */
    EmployeeDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    EmployeeDto.prototype.createdBy;
    /** @type {?|undefined} */
    EmployeeDto.prototype.createdDate;
    /** @type {?|undefined} */
    EmployeeDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    EmployeeDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    EmployeeDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/situation.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$5 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PACKAGE_IMPORTS:END}*/
class Situation {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} situationDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(situationDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, situationDto);
        model.createdDate = model.createdDate && moment$5(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$5(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["code", "name"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} situation
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(situation, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, situation);
        dto.createdDate = dto.createdDate && moment$5(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$5(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Situation.prototype.id;
    /** @type {?} */
    Situation.prototype.code;
    /** @type {?} */
    Situation.prototype.name;
    /** @type {?} */
    Situation.prototype.deleted;
    /** @type {?} */
    Situation.prototype.extIntSts;
    /** @type {?} */
    Situation.prototype.extIntMsg;
    /** @type {?} */
    Situation.prototype.createdBy;
    /** @type {?} */
    Situation.prototype.createdDate;
    /** @type {?} */
    Situation.prototype.lastModifiedBy;
    /** @type {?} */
    Situation.prototype.lastModifiedDate;
    /** @type {?} */
    Situation.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/readiness/readiness.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/** @type {?} */
const moment$6 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class Readiness {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} readinessDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(readinessDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, readinessDto);
        model.startDateTime = model.startDateTime && moment$6(model.startDateTime).toDate();
        model.endDateTime = model.endDateTime && moment$6(model.endDateTime).toDate();
        model.createdDate = model.createdDate && moment$6(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$6(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "startDateTime",
            "endDateTime",
            "situation.code",
            "situation.name",
            "situation.situationType",
            "observation",
            "continuous",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "Readiness");
        if (originEntity !== "Situation" && model.situation)
            model.situation = Situation.fromDto(model.situation, "Readiness");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} readiness
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(readiness, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, readiness);
        dto.startDateTime = dto.startDateTime && moment$6(dto.startDateTime).format();
        dto.endDateTime = dto.endDateTime && moment$6(dto.endDateTime).format();
        dto.createdDate = dto.createdDate && moment$6(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$6(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "Readiness");
        if (originEntity !== "Situation" && dto.situation)
            dto.situation = Situation.toDto(dto.situation, "Readiness");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Readiness.prototype.id;
    /** @type {?} */
    Readiness.prototype.employee;
    /** @type {?} */
    Readiness.prototype.startDateTime;
    /** @type {?} */
    Readiness.prototype.endDateTime;
    /** @type {?} */
    Readiness.prototype.situation;
    /** @type {?} */
    Readiness.prototype.observation;
    /** @type {?} */
    Readiness.prototype.continuous;
    /** @type {?} */
    Readiness.prototype.createdBy;
    /** @type {?} */
    Readiness.prototype.createdDate;
    /** @type {?} */
    Readiness.prototype.lastModifiedBy;
    /** @type {?} */
    Readiness.prototype.lastModifiedDate;
    /** @type {?} */
    Readiness.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/readiness/readiness.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class ReadinessService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/readiness`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
ReadinessService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ReadinessService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    ReadinessService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    ReadinessService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    ReadinessService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/situation.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SituationService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_foundation/general/entities/situation`, `hcm_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    listExternalSituation(listParams) {
        return this.http
            .get("hcm_foundation/general/entities/situation", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
}
SituationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SituationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    SituationService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    SituationService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    SituationService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/readiness/form/readiness-form.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$7 = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class ReadinessFormComponent {
    /**
     * @param {?} readinessService
     * @param {?} router
     * @param {?} route
     * @param {?} messageService
     * @param {?} confirmationService
     * @param {?} formBuilder
     * @param {?} translate
     * @param {?} hotkeysService
     * @param {?} fieldCustomization
     * @param {?} focusService
     * @param {?} employeeService
     * @param {?} situationService
     */
    constructor(readinessService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, employeeService, situationService) {
        this.readinessService = readinessService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.employeeService = employeeService;
        this.situationService = situationService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.situationLookupDisplayFields = ["code", "name"];
        this.situationAdvancedDisplayFields = ["code", "name", "situationType"];
        this.situationLookupSeparator = " - ";
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter((/**
             * @param {?} name
             * @return {?}
             */
            name => name === 'readiness'))).subscribe((/**
             * @return {?}
             */
            () => {
                this.onSave();
            }));
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((/**
             * @param {?} value
             * @return {?}
             */
            (value) => {
                this.loadLockedEmployee(value);
            }));
        }
        else {
            this.setHotkeys();
        }
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => this.onRouteParamsChange(params)));
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => this.onRouteDataChange(data)));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.situationSearchFields = this.getSituationSearchFields();
        this.situationSearchGridFields = this.getSituationSearchGridFields();
        this.setHotkeys();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLockedEmployee(value) {
        /** @type {?} */
        const employee = this.formGroup.controls['employee'].value;
        this.formGroup.reset();
        this.formGroup.controls['continuous'].setValue(false);
        this.formGroup.controls['employee'].setValue(employee);
        if (this.formGroup.controls['employee'].value) {
            this.formGroup.controls['startDateTime'].setValue(moment$7(value.evaluationDate).startOf('day').toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((/**
             * @param {?} dto
             * @return {?}
             */
            (dto) => {
                this.onLoadFormSubject.next(false);
                /** @type {?} */
                const readiness = new Readiness();
                readiness.startDateTime = moment$7(value.evaluationDate).startOf('day').toDate();
                readiness.employee = Employee.fromDto(dto.contents[0], "Readiness");
                this.updateSuggestions(readiness);
                this.formGroup.patchValue(readiness);
                this.formGroup.controls['employee'].disable();
                this.loading = false;
            }));
        }
    }
    /**
     * @return {?}
     */
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", (/**
         * @return {?}
         */
        () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", (/**
         * @return {?}
         */
        () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", (/**
         * @return {?}
         */
        () => {
            this.onCancel();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    /**
     * @return {?}
     */
    isNew() {
        return this.routeParams.readiness == "new";
    }
    /**
     * @param {?} params
     * @return {?}
     */
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue(["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractTypeLabel"], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.situation) {
            value.situation.label = this.getSuggestionValue(["code", "name"], "situation", value, this.situationLookupSeparator);
            if (value.situation.label.trim() === this.situationLookupSeparator.trim()) {
                delete value.situation.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    /**
     * @param {?} displayFields
     * @param {?} ownerEntity
     * @param {?} value
     * @param {?} separator
     * @return {?}
     */
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((/**
         * @param {?} field
         * @return {?}
         */
        field => this.getProp(value, `${ownerEntity}.${field}`)))
            .reduce((/**
         * @param {?} acc
         * @param {?} val
         * @return {?}
         */
        (acc, val) => `${acc}${separator}${val}`));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.readiness;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity) {
            /** @type {?} */
            const canEdit = this.permissions.editar;
            if (!canEdit)
                this.formGroup.disable();
            /** @type {?} */
            const value = Readiness.fromDto(data.entity);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
        }
        else {
            this.formGroup.patchValue(new Readiness());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    /**
     * @return {?}
     */
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    /**
     * @param {?} filesToDelete
     * @param {?} filesToCommit
     * @return {?}
     */
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /** @type {?} */
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    /**
     * @return {?}
     */
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        this.onLoadFormSubject.next(true);
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        })))
            .subscribe((/**
         * @return {?}
         */
        () => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
             * @param {?} err
             * @return {?}
             */
            (err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            })))
                .subscribe((/**
             * @return {?}
             */
            () => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                if (this.lockedEmployee) {
                    this.onClose.next();
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            }));
        }));
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    /**
     * @return {?}
     */
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: (/**
             * @return {?}
             */
            () => this.getDeleteObservable()
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe()),
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    /**
     * @param {?} obj
     * @param {?} path
     * @return {?}
     */
    getProp(obj, path) {
        return path.split(".").reduce((/**
         * @param {?} result
         * @param {?} prop
         * @return {?}
         */
        (result, prop) => (result[prop] === undefined ? "" : result[prop])), obj);
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((/**
         * @param {?} r
         * @return {?}
         */
        r => r.value === value))[0].label;
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions.filter((/**
             * @param {?} r
             * @return {?}
             */
            r => {
                /** @type {?} */
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            }))
                .map((/**
             * @param {?} r
             * @return {?}
             */
            r => r.value));
        }
        return [];
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.employeeLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$7(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$7(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$7(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map((/**
                 * @param {?} enumConstant
                 * @return {?}
                 */
                enumConstant => `${name} eq '${enumConstant}'`)).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        filter => filter !== ''))
            .join(" or ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                }))
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeLookupSuggestions = list.contents;
        }));
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$7(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$7(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$7(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" and ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === 'employmentRelationship.contractType') { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onSituationLookupRequest(value) {
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:END}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        var filterQuery = this.getSituationSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$7(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$7(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$7(value).format()}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" or ");
        if (filterQuery != "") {
            filterQuery = "( " + filterQuery + " ) and ";
        }
        filterQuery = filterQuery.concat("situationType eq 'PRECAUTIONREADINESS'");
        /** @type {?} */
        const displayFields = mergeUnique(this.situationLookupDisplayFields, this.situationAdvancedDisplayFields);
        this.situationService
            .listExternalSituation({ filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.situationLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.situationLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.situationLookupSuggestions = list.contents;
        }));
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSituationSearchRequest(event) {
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        var filterQuery = this.getSituationSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            // NOSONAR
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$7(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$7(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$7(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" and ");
        if (filterQuery != "") {
            filterQuery = "( " + filterQuery + " ) and ";
        }
        filterQuery = filterQuery.concat("situationType eq 'PRECAUTIONREADINESS'");
        /** @type {?} */
        const displayFields = mergeUnique(this.situationLookupDisplayFields, this.situationAdvancedDisplayFields);
        this.situationService
            .listExternalSituation({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.situationLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.situationLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.situationSearchGridData = list.contents;
            this.situationSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_SITUATION_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getFormGroup() {
        /** @type {?} */
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startDateTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endDateTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            situation: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            observation: [{ value: undefined, disabled: false }, Validators.compose([Validators.maxLength(255)])],
            continuous: [{ value: false, disabled: false }, Validators.compose([])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.startDateTimeIsBeforeEndDateTime(),
            ]
        });
        return formGroup;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    getSituationSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_SITUATION_SEARCH_FIELDS:START}*/
        /*{CA:GET_SITUATION_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getSituationSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_name"),
                type: FieldType.String,
            }),
            new FormField({
                name: "situationType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_situation_type"),
                type: FieldType.Enum,
                placeholder: this.translate.instant("hcm_clocking_event_foundation.general.situation_situation_type_placeholder"),
                options: [
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_working"), value: "WORKING" },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_vacation"), value: "VACATION" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_illnessaid"),
                        value: "ILLNESSAID",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_laboraccident"),
                        value: "LABORACCIDENT",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_militaryservice"),
                        value: "MILITARYSERVICE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleave"),
                        value: "MATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleavenoncriminalabortion"),
                        value: "MATERNITYLEAVENONCRIMINALABORTION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleaveanticipationextension"),
                        value: "MATERNITYLEAVEANTICIPATIONEXTENSION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_citizencompanymaternity"),
                        value: "CITIZENCOMPANYMATERNITY",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_inssmaternityleave"),
                        value: "INSSMATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_leavewithoutcompensation"),
                        value: "LEAVEWITHOUTCOMPENSATION",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_paidleave"), value: "PAIDLEAVE" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_paternityleave"),
                        value: "PATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_citizencompanypaternity"),
                        value: "CITIZENCOMPANYPATERNITY",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_collectivevacation"),
                        value: "COLLECTIVEVACATION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_medicalleave"),
                        value: "MEDICALLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_medicalleavewithoutinss"),
                        value: "MEDICALLEAVEWITHOUTINSS",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_absences"), value: "ABSENCES" },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_overtime"), value: "OVERTIME" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_timeevaluationsituation"),
                        value: "TIMEEVALUATIONSITUATION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_precautionreadiness"),
                        value: "PRECAUTIONREADINESS",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_tradeunionmandate"),
                        value: "TRADEUNIONMANDATE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_workaccidentleave"),
                        value: "WORKACCIDENTLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_workaccidentleavewithoutinss"),
                        value: "WORKACCIDENTLEAVEWITHOUTINSS",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_retirementduetodisability"),
                        value: "RETIREMENTDUETODISABILITY",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_others"), value: "OTHERS" },
                ],
            }),
        ];
        /*{CA:GET_SITUATION_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_SITUATION_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    goBack() {
        /** @type {?} */
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    /**
     * @private
     * @param {?} formGroup
     * @return {?}
     */
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((/**
         * @param {?} field
         * @return {?}
         */
        field => {
            /** @type {?} */
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        }));
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls['employee'].value;
        /** @type {?} */
        const readinessDto = Readiness.toDto(value);
        /** @type {?} */
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.readinessService.insert(readinessDto);
        }
        else {
            /** @type {?} */
            const id = this.routeParams.readiness;
            observable = this.readinessService.update(id, readinessDto);
        }
        return observable;
    }
    /**
     * @private
     * @return {?}
     */
    getDeleteObservable() {
        return this.readinessService.delete(this.routeParams.readiness).pipe(tap((/**
         * @return {?}
         */
        () => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
            this.goBack(); // NOSONAR
        })));
    }
    /**
     * @private
     * @return {?}
     */
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        /** @type {?} */
        const toValidate = ["employee", "situation"];
        if (!toValidate.every((/**
         * @param {?} e
         * @return {?}
         */
        e => this.allPermissions[e] && this.allPermissions[e].visualizar))) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    /**
     * @private
     * @return {?}
     */
    startDateTimeIsBeforeEndDateTime() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const startDateTime = control.get('startDateTime');
            /** @type {?} */
            const endDateTime = control.get('endDateTime');
            return startDateTimeIsBeforeEndDateTimeValidator(startDateTime, endDateTime);
        });
    }
    /*{CA:CLASS_METHODS:END}*/
    /**
     * @private
     * @param {?} severity
     * @param {?} summary
     * @param {?} detail
     * @return {?}
     */
    addMessage(severity, summary, detail) {
        this.messageService.add({
            severity,
            summary: this.translate.instant(summary),
            detail: this.translate.instant(detail),
        });
    }
}
ReadinessFormComponent.decorators = [
    { type: Component, args: [{
                template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\" \n            [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.readiness_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.readiness_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.readiness_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.readiness_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.situation.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"situation\">{{\"hcm_clocking_event_foundation.general.readiness_situation\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"situation\" name=\"situation\" formControlName=\"situation\" [searchFields]=\"situationSearchFields\"\n                            [searchGridFields]=\"situationSearchGridFields\" [searchGridData]=\"situationSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"situationLookupSuggestions\" (onLookupRequest)=\"onSituationLookupRequest($event)\"\n                            (onSearchRequest)=\"onSituationSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=situationSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.readiness_situation_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\"\n                            [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: situationSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['situation']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"startDateTime\">{{\"hcm_clocking_event_foundation.general.readiness_start_date_time\" | translate}}</label>\n                        <p-calendar #startDateTimeFormInput inputId=\"startDateTime\" name=\"startDateTime\" [showIcon]=\"true\" [showTime]=\"true\" formControlName=\"startDateTime\" [locale]=\"localeConfig.calendar\"\n                            [dateFormat]=\"localeConfig.calendar.dateFormat\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDateTime']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateTimeIsBeforeEndDateTime: 'hcm_clocking_event_foundation.general.error_start_date_time_after_end_date_time_to_start_date' | translate \n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"endDateTime\">{{\"hcm_clocking_event_foundation.general.readiness_end_date_time\" | translate}}</label>\n                        <p-calendar #endDateTimeFormInput inputId=\"endDateTime\" name=\"endDateTime\" [showIcon]=\"true\" [showTime]=\"true\" formControlName=\"endDateTime\" [locale]=\"localeConfig.calendar\"\n                            [dateFormat]=\"localeConfig.calendar.dateFormat\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['endDateTime']\" \n                        [errorMessages]=\"{ \n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            startDateTimeIsBeforeEndDateTime: 'hcm_clocking_event_foundation.general.error_start_date_time_after_end_date_time_to_end_date' | translate\n                        }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-12\">\n                        <label for=\"observation\">{{\"hcm_clocking_event_foundation.general.readiness_observation\" | translate}}</label>\n                        <textarea #observationFormInput type=\"text\" id=\"observation\" name=\"observation\" rows=\"5\" pInputTextarea formControlName=\"observation\"\n                            autocomplete=\"off\"></textarea>\n                        <s-control-errors [control]=\"formGroup.controls['observation']\" [errorMessages]=\"{ maxlength: 'hcm_clocking_event_foundation.general.error_max_length' | translate: {value: '255'} }\"></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6\">\n                        <label for=\"continuous\">{{\"hcm_clocking_event_foundation.general.readiness_continuous\" | translate}}</label>\n                        <div class=\"ui-grid ui-grid-responsive ui-grid-pad ui-fluid\">\n                            <div class=\"ui-inputgroup\">\n                                <p-inputSwitch id=\"continuous\" formControlName=\"continuous\"></p-inputSwitch>\n                                <div style=\"padding-right: 0.75em;\"></div>\n                                <ng-container *ngIf=\"formGroup.get('continuous').value; else noContinuous\">\n                                    <span>{{ 'hcm_clocking_event_foundation.general.generic_yes' | translate }}</span>\n                                </ng-container>\n                                <ng-template #noContinuous>\n                                    <span>{{ 'hcm_clocking_event_foundation.general.generic_no' | translate }}</span>\n                                </ng-template>\n                            </div>\n                        </div>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"readiness\" formControlName=\"custom\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
                providers: [
                    ConfirmationService,
                ],
                /*{CA:COMPONENT_CONFIG:START}*/
                selector: 'cem-readiness-form'
                /*{CA:COMPONENT_CONFIG:END}*/
                ,
                styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}#observation{max-width:100%!important}"]
            }] }
];
/** @nocollapse */
ReadinessFormComponent.ctorParameters = () => [
    { type: ReadinessService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: EmployeeService },
    { type: SituationService }
];
ReadinessFormComponent.propDecorators = {
    customTemplate: [{ type: ViewChild, args: ["customTemplate", { static: false },] }],
    customFormFields: [{ type: ViewChild, args: ["customFormFields", { static: false },] }],
    onSubmitObservable: [{ type: Input }],
    onLockedEmployeeChanges: [{ type: Input }],
    lockedEmployee: [{ type: Input }],
    onCloseObservable: [{ type: Output }],
    onLoadForm: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    ReadinessFormComponent.prototype.localeConfig;
    /** @type {?} */
    ReadinessFormComponent.prototype.currencyLocaleOptions;
    /** @type {?} */
    ReadinessFormComponent.prototype.permissions;
    /** @type {?} */
    ReadinessFormComponent.prototype.allPermissions;
    /** @type {?} */
    ReadinessFormComponent.prototype.formGroup;
    /** @type {?} */
    ReadinessFormComponent.prototype.loading;
    /** @type {?} */
    ReadinessFormComponent.prototype.mainPanelCollapsed;
    /** @type {?} */
    ReadinessFormComponent.prototype.contractTypeOptions;
    /** @type {?} */
    ReadinessFormComponent.prototype.employeeLookupSuggestions;
    /** @type {?} */
    ReadinessFormComponent.prototype.employeeLookupDisplayFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.employeeAdvancedDisplayFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.employeeLookupSeparator;
    /** @type {?} */
    ReadinessFormComponent.prototype.employeeSearchFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.employeeSearchGridFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.employeeSearchGridData;
    /** @type {?} */
    ReadinessFormComponent.prototype.employeeSearchTotalRecords;
    /** @type {?} */
    ReadinessFormComponent.prototype.situationLookupSuggestions;
    /** @type {?} */
    ReadinessFormComponent.prototype.situationLookupDisplayFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.situationAdvancedDisplayFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.situationLookupSeparator;
    /** @type {?} */
    ReadinessFormComponent.prototype.situationSearchFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.situationSearchGridFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.situationSearchGridData;
    /** @type {?} */
    ReadinessFormComponent.prototype.situationSearchTotalRecords;
    /** @type {?} */
    ReadinessFormComponent.prototype.customTemplate;
    /** @type {?} */
    ReadinessFormComponent.prototype.customFormFields;
    /** @type {?} */
    ReadinessFormComponent.prototype.onSubmitObservable;
    /** @type {?} */
    ReadinessFormComponent.prototype.onLockedEmployeeChanges;
    /** @type {?} */
    ReadinessFormComponent.prototype.lockedEmployee;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.onClose;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.onLoadFormSubject;
    /** @type {?} */
    ReadinessFormComponent.prototype.onCloseObservable;
    /** @type {?} */
    ReadinessFormComponent.prototype.onLoadForm;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.routeParams;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.ngUnsubscribe;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.readinessService;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.router;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.route;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.messageService;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.confirmationService;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.formBuilder;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.translate;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.hotkeysService;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.fieldCustomization;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.focusService;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.employeeService;
    /**
     * @type {?}
     * @private
     */
    ReadinessFormComponent.prototype.situationService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/readiness/readiness-form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ReadinessFormModule {
}
ReadinessFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    LocaleModule.forChild(),
                    SharedScheduleModule
                ],
                declarations: [
                    ReadinessFormComponent
                ],
                exports: [
                    ReadinessFormComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workschedule/workschedule.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$8 = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class Workschedule {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} workscheduleDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(workscheduleDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, workscheduleDto);
        model.createdDate = model.createdDate && moment$8(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$8(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "code",
            "name",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} workschedule
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(workschedule, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, workschedule);
        dto.createdDate = dto.createdDate && moment$8(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$8(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Workschedule.prototype.id;
    /** @type {?} */
    Workschedule.prototype.code;
    /** @type {?} */
    Workschedule.prototype.name;
    /** @type {?} */
    Workschedule.prototype.deleted;
    /** @type {?} */
    Workschedule.prototype.extIntSts;
    /** @type {?} */
    Workschedule.prototype.extIntMsg;
    /** @type {?} */
    Workschedule.prototype.createdBy;
    /** @type {?} */
    Workschedule.prototype.createdDate;
    /** @type {?} */
    Workschedule.prototype.lastModifiedBy;
    /** @type {?} */
    Workschedule.prototype.lastModifiedDate;
    /** @type {?} */
    Workschedule.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/work-schedule-change/work-schedule-change.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$9 = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkScheduleChange {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} workScheduleChangeDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(workScheduleChangeDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, workScheduleChangeDto);
        model.date = model.date && moment$9(model.date).toDate();
        model.createdDate = model.createdDate && moment$9(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$9(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "date",
            "workSchedule.code",
            "workSchedule.name",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "WorkScheduleChange");
        if (originEntity !== "Workschedule" && model.workSchedule)
            model.workSchedule = Workschedule.fromDto(model.workSchedule, "WorkScheduleChange");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} workScheduleChange
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(workScheduleChange, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, workScheduleChange);
        dto.date = dto.date && moment$9(dto.date).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$9(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$9(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "WorkScheduleChange");
        if (originEntity !== "Workschedule" && dto.workSchedule)
            dto.workSchedule = Workschedule.toDto(dto.workSchedule, "WorkScheduleChange");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    WorkScheduleChange.prototype.id;
    /** @type {?} */
    WorkScheduleChange.prototype.employee;
    /** @type {?} */
    WorkScheduleChange.prototype.date;
    /** @type {?} */
    WorkScheduleChange.prototype.workSchedule;
    /** @type {?} */
    WorkScheduleChange.prototype.createdBy;
    /** @type {?} */
    WorkScheduleChange.prototype.createdDate;
    /** @type {?} */
    WorkScheduleChange.prototype.lastModifiedBy;
    /** @type {?} */
    WorkScheduleChange.prototype.lastModifiedDate;
    /** @type {?} */
    WorkScheduleChange.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/work-schedule-change/work-schedule-change-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function WorkScheduleChangeDto() { }
if (false) {
    /** @type {?|undefined} */
    WorkScheduleChangeDto.prototype.id;
    /** @type {?} */
    WorkScheduleChangeDto.prototype.employee;
    /** @type {?} */
    WorkScheduleChangeDto.prototype.date;
    /** @type {?} */
    WorkScheduleChangeDto.prototype.workSchedule;
    /** @type {?|undefined} */
    WorkScheduleChangeDto.prototype.createdBy;
    /** @type {?|undefined} */
    WorkScheduleChangeDto.prototype.createdDate;
    /** @type {?|undefined} */
    WorkScheduleChangeDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    WorkScheduleChangeDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    WorkScheduleChangeDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/work-schedule-change/work-schedule-change.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkScheduleChangeService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/workScheduleChange`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
WorkScheduleChangeService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
WorkScheduleChangeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    WorkScheduleChangeService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    WorkScheduleChangeService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    WorkScheduleChangeService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/work-schedule-change/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workschedule/workschedule.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkscheduleService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_foundation/work_schedule/entities/workschedule`, `hcm_foundation/work_schedule/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
WorkscheduleService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
WorkscheduleService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    WorkscheduleService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    WorkscheduleService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    WorkscheduleService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/work-schedule-change/form/work-schedule-change-form.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/** @type {?} */
const moment$a = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class WorkScheduleChangeFormComponent {
    /**
     * @param {?} workScheduleChangeService
     * @param {?} router
     * @param {?} route
     * @param {?} messageService
     * @param {?} confirmationService
     * @param {?} formBuilder
     * @param {?} translate
     * @param {?} hotkeysService
     * @param {?} fieldCustomization
     * @param {?} focusService
     * @param {?} employeeService
     * @param {?} workscheduleService
     */
    constructor(workScheduleChangeService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, employeeService, workscheduleService) {
        this.workScheduleChangeService = workScheduleChangeService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.employeeService = employeeService;
        this.workscheduleService = workscheduleService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.loading = false;
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.workScheduleLookupDisplayFields = ["code", "name"];
        this.workScheduleAdvancedDisplayFields = ["code", "name"];
        this.workScheduleLookupSeparator = " - ";
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter((/**
             * @param {?} name
             * @return {?}
             */
            name => name === 'workScheduleChange'))).subscribe((/**
             * @return {?}
             */
            () => {
                this.onSave();
            }));
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((/**
             * @param {?} value
             * @return {?}
             */
            (value) => {
                this.loadLockedEmployee(value);
            }));
        }
        else {
            this.setHotkeys();
        }
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => this.onRouteParamsChange(params)));
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => this.onRouteDataChange(data)));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.workScheduleSearchFields = this.getWorkScheduleSearchFields();
        this.workScheduleSearchGridFields = this.getWorkScheduleSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLockedEmployee(value) {
        /** @type {?} */
        const employee = this.formGroup.controls['employee'].value;
        this.formGroup.reset();
        this.formGroup.controls['employee'].setValue(employee);
        if (this.formGroup.controls['employee'].value) {
            this.formGroup.controls['date'].setValue(moment$a(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((/**
             * @param {?} dto
             * @return {?}
             */
            (dto) => {
                this.onLoadFormSubject.next(false);
                /** @type {?} */
                const workScheduleChange = new WorkScheduleChange();
                workScheduleChange.date = moment$a(value.evaluationDate).toDate();
                workScheduleChange.employee = Employee.fromDto(dto.contents[0], "WorkScheduleChange");
                this.updateSuggestions(workScheduleChange);
                this.formGroup.patchValue(workScheduleChange);
                this.formGroup.controls['employee'].disable();
                this.loading = false;
            }));
        }
    }
    /**
     * @return {?}
     */
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", (/**
         * @return {?}
         */
        () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", (/**
         * @return {?}
         */
        () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", (/**
         * @return {?}
         */
        () => {
            this.onCancel();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    /**
     * @return {?}
     */
    isNew() {
        return this.routeParams.workScheduleChange == "new";
    }
    /**
     * @param {?} params
     * @return {?}
     */
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue(["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractTypeLabel"], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.toString().trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.workSchedule) {
            value.workSchedule.label = this.getSuggestionValue(["code", "name"], "workSchedule", value, this.workScheduleLookupSeparator);
            if (value.workSchedule.label.trim() === this.workScheduleLookupSeparator.trim()) {
                delete value.workSchedule.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    /**
     * @param {?} displayFields
     * @param {?} ownerEntity
     * @param {?} value
     * @param {?} separator
     * @return {?}
     */
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((/**
         * @param {?} field
         * @return {?}
         */
        field => this.getProp(value, `${ownerEntity}.${field}`)))
            .reduce((/**
         * @param {?} acc
         * @param {?} val
         * @return {?}
         */
        (acc, val) => `${acc}${separator}${val}`));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.workScheduleChange;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity) {
            /** @type {?} */
            const canEdit = this.permissions.editar;
            if (!canEdit)
                this.formGroup.disable();
            /** @type {?} */
            const value = WorkScheduleChange.fromDto(data.entity);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
        }
        else {
            this.formGroup.patchValue(new WorkScheduleChange());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    /**
     * @return {?}
     */
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    /**
     * @param {?} filesToDelete
     * @param {?} filesToCommit
     * @return {?}
     */
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /** @type {?} */
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    /**
     * @return {?}
     */
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        })))
            .subscribe((/**
         * @return {?}
         */
        () => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
             * @param {?} err
             * @return {?}
             */
            (err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            })))
                .subscribe((/**
             * @return {?}
             */
            () => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                if (this.lockedEmployee) {
                    this.onClose.next();
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            }));
        }));
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    /**
     * @return {?}
     */
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: (/**
             * @return {?}
             */
            () => this.getDeleteObservable()
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe()),
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    /**
     * @param {?} obj
     * @param {?} path
     * @return {?}
     */
    getProp(obj, path) {
        return path.split(".").reduce((/**
         * @param {?} result
         * @param {?} prop
         * @return {?}
         */
        (result, prop) => (result[prop] === undefined ? "" : result[prop])), obj);
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((/**
         * @param {?} r
         * @return {?}
         */
        r => r.value === value))[0].label;
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions.filter((/**
             * @param {?} r
             * @return {?}
             */
            r => {
                /** @type {?} */
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            }))
                .map((/**
             * @param {?} r
             * @return {?}
             */
            r => r.value));
        }
        return [];
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.employeeLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$a(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$a(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$a(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map((/**
                 * @param {?} enumConstant
                 * @return {?}
                 */
                enumConstant => `${name} eq '${enumConstant}'`)).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        filter => filter !== ''))
            .join(" or ");
        /** @type {?} */
        const displayFields = this.employeeLookupDisplayFields;
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                }))
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeLookupSuggestions = list.contents;
        }));
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$a(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$a(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$a(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" and ");
        /** @type {?} */
        const displayFields = this.employeeLookupDisplayFields;
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === 'employmentRelationship.contractType') { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onWorkScheduleLookupRequest(value) {
        /*{CA:ON_WORK_SCHEDULE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_WORK_SCHEDULE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.workScheduleLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        let filterQuery = this.getWorkScheduleSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$a(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$a(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$a(value).format()}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" or ");
        /** @type {?} */
        const date = moment$a(this.formGroup.value.date).format("YYYY-MM-DD");
        /** @type {?} */
        const filters = [`initialValidity <= '${date}' and finalValidity >= '${date}' or initialValidity is null and finalValidity > '${date}' or initialValidity < '${date}' and finalValidity is null or initialValidity is null and finalValidity is null`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        /** @type {?} */
        const displayFields = mergeUnique(["code", "name", "initialValidity", "finalValidity"], ["code", "name", "initialValidity", "finalValidity"]);
        this.workscheduleService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.workScheduleLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.workScheduleLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.workScheduleLookupSuggestions = list.contents;
        }));
        /*{CA:ON_WORK_SCHEDULE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_WORK_SCHEDULE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onWorkScheduleSearchRequest(event) {
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        let filterQuery = this.getWorkScheduleSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            // NOSONAR
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$a(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$a(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$a(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" and ");
        // NOSONAR
        /** @type {?} */
        const date = moment$a(this.formGroup.value.date).format("YYYY-MM-DD");
        /** @type {?} */
        const filters = [`initialValidity <= '${date}' and finalValidity >= '${date}' or initialValidity is null and finalValidity >= '${date}' or initialValidity <= '${date}' and finalValidity is null or initialValidity is null and finalValidity is null`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        /** @type {?} */
        const displayFields = mergeUnique(["code", "name", "initialValidity", "finalValidity"], ["code", "name", "initialValidity", "finalValidity"]);
        this.workscheduleService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.workScheduleLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.workScheduleLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.workScheduleSearchGridData = list.contents;
            this.workScheduleSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getFormGroup() {
        /** @type {?} */
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            date: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            workSchedule: [{ value: undefined, disabled: true }, Validators.compose([Validators.required])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        });
        formGroup.controls['date'].valueChanges.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.verifyWorkscheduleLookupDisabled(date);
        }));
        return formGroup;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    getWorkScheduleSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_WORK_SCHEDULE_SEARCH_FIELDS:START}*/
        /*{CA:GET_WORK_SCHEDULE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getWorkScheduleSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_WORK_SCHEDULE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_WORK_SCHEDULE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    goBack() {
        /** @type {?} */
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    /**
     * @private
     * @param {?} formGroup
     * @return {?}
     */
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((/**
         * @param {?} field
         * @return {?}
         */
        field => {
            /** @type {?} */
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        }));
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls['employee'].value;
        /** @type {?} */
        const workScheduleChangeDto = WorkScheduleChange.toDto(value);
        /** @type {?} */
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.workScheduleChangeService.insert(workScheduleChangeDto);
        }
        else {
            /** @type {?} */
            const id = this.routeParams.workScheduleChange;
            observable = this.workScheduleChangeService.update(id, workScheduleChangeDto);
        }
        return observable;
    }
    /**
     * @private
     * @return {?}
     */
    getDeleteObservable() {
        return this.workScheduleChangeService.delete(this.routeParams.workScheduleChange).pipe(tap((/**
         * @return {?}
         */
        () => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
            this.goBack(); // NOSONAR
        })));
    }
    /**
     * @param {?=} date
     * @return {?}
     */
    verifyWorkscheduleLookupDisabled(date = this.formGroup.controls.date.value) {
        if (date != null) {
            this.formGroup.controls.workSchedule.enable();
        }
        else {
            this.formGroup.controls.workSchedule.disable();
            this.formGroup.controls.workSchedule.setValue(null);
        }
    }
    /**
     * @private
     * @return {?}
     */
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        /** @type {?} */
        const toValidate = ["employee", "workschedule"];
        if (!toValidate.every((/**
         * @param {?} e
         * @return {?}
         */
        e => this.allPermissions[e] && this.allPermissions[e].visualizar))) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    /*{CA:CLASS_METHODS:END}*/
    /**
     * @private
     * @param {?} severity
     * @param {?} summary
     * @param {?} detail
     * @return {?}
     */
    addMessage(severity, summary, detail) {
        this.messageService.add({
            severity,
            summary: this.translate.instant(summary),
            detail: this.translate.instant(detail),
        });
    }
}
WorkScheduleChangeFormComponent.decorators = [
    { type: Component, args: [{
                template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\" \n            [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.work_schedule_change_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.work_schedule_change_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.work_schedule_change_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.work_schedule_change_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"date\">{{\"hcm_clocking_event_foundation.general.work_schedule_change_date\" | translate}}</label>\n                        <p-calendar #dateFormInput inputId=\"date\" name=\"date\" [showIcon]=\"true\" formControlName=\"date\" [locale]=\"localeConfig.calendar\"\n                            [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['date']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate}\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.workschedule.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"workSchedule\">{{\"hcm_clocking_event_foundation.general.work_schedule_change_work_schedule\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"workSchedule\" name=\"workSchedule\" formControlName=\"workSchedule\" [searchFields]=\"workScheduleSearchFields\"\n                            [searchGridFields]=\"workScheduleSearchGridFields\" [searchGridData]=\"workScheduleSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"workScheduleLookupSuggestions\" (onLookupRequest)=\"onWorkScheduleLookupRequest($event)\"\n                            (onSearchRequest)=\"onWorkScheduleSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=workScheduleSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.work_schedule_change_work_schedule_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\"\n                            [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: workScheduleSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['workSchedule']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"workScheduleChange\" *ngIf=\"formGroup.controls['custom']\"\n                formControlName=\"custom\" [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
                providers: [
                    ConfirmationService,
                ],
                /*{CA:COMPONENT_CONFIG:START}*/
                selector: 'cem-work-schedule-change-form'
                /*{CA:COMPONENT_CONFIG:END}*/
                ,
                styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
            }] }
];
/** @nocollapse */
WorkScheduleChangeFormComponent.ctorParameters = () => [
    { type: WorkScheduleChangeService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: EmployeeService },
    { type: WorkscheduleService }
];
WorkScheduleChangeFormComponent.propDecorators = {
    customTemplate: [{ type: ViewChild, args: ["customTemplate", { static: false },] }],
    customFormFields: [{ type: ViewChild, args: ["customFormFields", { static: false },] }],
    onSubmitObservable: [{ type: Input }],
    onLockedEmployeeChanges: [{ type: Input }],
    lockedEmployee: [{ type: Input }],
    onCloseObservable: [{ type: Output }],
    onLoadForm: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.localeConfig;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.currencyLocaleOptions;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.permissions;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.allPermissions;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.formGroup;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.loading;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.mainPanelCollapsed;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.contractTypeOptions;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.employeeLookupSuggestions;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.employeeLookupDisplayFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.employeeAdvancedDisplayFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.employeeLookupSeparator;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.employeeSearchFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.employeeSearchGridFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.employeeSearchGridData;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.employeeSearchTotalRecords;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.workScheduleLookupSuggestions;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.workScheduleLookupDisplayFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.workScheduleAdvancedDisplayFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.workScheduleLookupSeparator;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.workScheduleSearchFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.workScheduleSearchGridFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.workScheduleSearchGridData;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.workScheduleSearchTotalRecords;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.customTemplate;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.customFormFields;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.onSubmitObservable;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.onLockedEmployeeChanges;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.lockedEmployee;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.onClose;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.onLoadFormSubject;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.onCloseObservable;
    /** @type {?} */
    WorkScheduleChangeFormComponent.prototype.onLoadForm;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.routeParams;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.ngUnsubscribe;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.workScheduleChangeService;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.router;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.route;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.messageService;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.confirmationService;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.formBuilder;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.translate;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.hotkeysService;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.fieldCustomization;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.focusService;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.employeeService;
    /**
     * @type {?}
     * @private
     */
    WorkScheduleChangeFormComponent.prototype.workscheduleService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/work-schedule-change/work-schedule-change-form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkScheduleChangeFormModule {
}
WorkScheduleChangeFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    LocaleModule.forChild(),
                    SharedScheduleModule
                ],
                declarations: [
                    WorkScheduleChangeFormComponent
                ],
                exports: [
                    WorkScheduleChangeFormComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/overtime-authorization/overtime-authorization.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/** @type {?} */
const moment$b = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class OvertimeAuthorization {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} overtimeAuthorizationDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(overtimeAuthorizationDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, overtimeAuthorizationDto);
        model.startDateTime = model.startDateTime && moment$b(model.startDateTime).toDate();
        model.endDateTime = model.endDateTime && moment$b(model.endDateTime).toDate();
        model.createdDate = model.createdDate && moment$b(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$b(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "startDateTime",
            "endDateTime",
            "authorizer.code",
            "authorizer.person.nomPes",
            "observation",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "OvertimeAuthorization");
        if (originEntity !== "Employee" && model.authorizer)
            model.authorizer = Employee.fromDto(model.authorizer, "OvertimeAuthorization");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} overtimeAuthorization
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(overtimeAuthorization, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, overtimeAuthorization);
        dto.startDateTime = dto.startDateTime && moment$b(dto.startDateTime).format();
        dto.endDateTime = dto.endDateTime && moment$b(dto.endDateTime).format();
        dto.createdDate = dto.createdDate && moment$b(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$b(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "OvertimeAuthorization");
        if (originEntity !== "Employee" && dto.authorizer)
            dto.authorizer = Employee.toDto(dto.authorizer, "OvertimeAuthorization");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    OvertimeAuthorization.prototype.id;
    /** @type {?} */
    OvertimeAuthorization.prototype.employee;
    /** @type {?} */
    OvertimeAuthorization.prototype.startDateTime;
    /** @type {?} */
    OvertimeAuthorization.prototype.endDateTime;
    /** @type {?} */
    OvertimeAuthorization.prototype.authorizer;
    /** @type {?} */
    OvertimeAuthorization.prototype.observation;
    /** @type {?} */
    OvertimeAuthorization.prototype.createdBy;
    /** @type {?} */
    OvertimeAuthorization.prototype.createdDate;
    /** @type {?} */
    OvertimeAuthorization.prototype.lastModifiedBy;
    /** @type {?} */
    OvertimeAuthorization.prototype.lastModifiedDate;
    /** @type {?} */
    OvertimeAuthorization.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/overtime-authorization/overtime-authorization.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class OvertimeAuthorizationService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/overtimeAuthorization`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
OvertimeAuthorizationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
OvertimeAuthorizationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    OvertimeAuthorizationService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    OvertimeAuthorizationService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    OvertimeAuthorizationService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/overtime-authorization/form/overtime-authorization-form.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/** @type {?} */
const moment$c = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class OvertimeAuthorizationFormComponent {
    /**
     * @param {?} overtimeAuthorizationService
     * @param {?} router
     * @param {?} route
     * @param {?} messageService
     * @param {?} confirmationService
     * @param {?} formBuilder
     * @param {?} translate
     * @param {?} hotkeysService
     * @param {?} fieldCustomization
     * @param {?} focusService
     * @param {?} renderer
     * @param {?} employeeService
     */
    constructor(overtimeAuthorizationService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, renderer, employeeService) {
        this.overtimeAuthorizationService = overtimeAuthorizationService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.renderer = renderer;
        this.employeeService = employeeService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"),
                value: "EMPLOYEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"),
                value: "DIRECTOR",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"),
                value: "TRAINEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"),
                value: "APRENTICE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"),
                value: "THIRD_PARTY",
            },
        ];
        this.employeeLookupDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType"
        ];
        this.employeeAdvancedDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType"
        ];
        this.employeeLookupSeparator = " - ";
        this.authorizerLookupDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType",
        ];
        this.authorizerAdvancedDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType"
        ];
        this.authorizerLookupSeparator = " - ";
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter((/**
             * @param {?} name
             * @return {?}
             */
            name => name === 'overtimeAuthorization'))).subscribe((/**
             * @return {?}
             */
            () => {
                this.onSave();
            }));
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((/**
             * @param {?} value
             * @return {?}
             */
            (value) => {
                this.loadLockedEmployee(value);
            }));
        }
        else {
            this.setHotkeys();
        }
        this.route.params
            .pipe(takeUntil(this.ngUnsubscribe))
            .subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => this.onRouteParamsChange(params)));
        this.route.data
            .pipe(takeUntil(this.ngUnsubscribe))
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => this.onRouteDataChange(data)));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.authorizerSearchFields = this.getAuthorizerSearchFields();
        this.authorizerSearchGridFields = this.getAuthorizerSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    /**
     * @return {?}
     */
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", (/**
         * @return {?}
         */
        () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", (/**
         * @return {?}
         */
        () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", (/**
         * @return {?}
         */
        () => {
            this.onCancel();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    /**
     * @return {?}
     */
    isNew() {
        return this.routeParams.overtimeAuthorization == "new";
    }
    /**
     * @param {?} params
     * @return {?}
     */
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue([
                "employer.codEmp",
                "code",
                "person.nomPes",
                "employmentRelationship.contractTypeLabel",
            ], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.authorizer) {
            value.authorizer.label = this.getSuggestionValue(["code", "person.nomPes"], "authorizer", value, this.authorizerLookupSeparator);
            if (value.authorizer.label.trim() === this.authorizerLookupSeparator.trim()) {
                delete value.authorizer.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    /**
     * @param {?} displayFields
     * @param {?} ownerEntity
     * @param {?} value
     * @param {?} separator
     * @return {?}
     */
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => this.getProp(value, `${ownerEntity}.${field}`)))
            .reduce((/**
         * @param {?} acc
         * @param {?} val
         * @return {?}
         */
        (acc, val) => `${acc}${separator}${val}`));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.overtimeAuthorization;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (data.entity) {
            /** @type {?} */
            const canEdit = this.permissions.editar;
            if (!canEdit)
                this.formGroup.disable();
            /** @type {?} */
            const value = OvertimeAuthorization.fromDto(data.entity);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
        }
        else {
            this.formGroup.patchValue(new OvertimeAuthorization());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    /**
     * @return {?}
     */
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    /**
     * @param {?} filesToDelete
     * @param {?} filesToCommit
     * @return {?}
     */
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /** @type {?} */
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    /**
     * @return {?}
     */
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        })))
            .subscribe((/**
         * @return {?}
         */
        () => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
             * @param {?} err
             * @return {?}
             */
            (err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            })))
                .subscribe((/**
             * @return {?}
             */
            () => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                if (this.lockedEmployee) {
                    this.onClose.next(true);
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            }));
        }));
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    /**
     * @return {?}
     */
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: (/**
             * @return {?}
             */
            () => this.getDeleteObservable().pipe(takeUntil(this.ngUnsubscribe)).subscribe()),
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    /**
     * @param {?} obj
     * @param {?} path
     * @return {?}
     */
    getProp(obj, path) {
        return path
            .split(".")
            .reduce((/**
         * @param {?} result
         * @param {?} prop
         * @return {?}
         */
        (result, prop) => (result[prop] === undefined ? "" : result[prop])), obj);
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((/**
         * @param {?} r
         * @return {?}
         */
        (r) => r.value === value))[0].label;
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions
                .filter((/**
             * @param {?} r
             * @return {?}
             */
            (r) => {
                /** @type {?} */
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            }))
                .map((/**
             * @param {?} r
             * @return {?}
             */
            (r) => r.value));
        }
        return [];
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.employeeLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$c(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$c(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$c(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value)
                    .map((/**
                 * @param {?} enumConstant
                 * @return {?}
                 */
                (enumConstant) => `${name} eq '${enumConstant}'`))
                    .join(" or ");
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        (filter) => filter !== ""))
            .join(" or ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                (field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeLookupSuggestions = list.contents;
        }));
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$c(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$c(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$c(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" and ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                (field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onAuthorizerLookupRequest(value) {
        /*{CA:ON_AUTHORIZER_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_AUTHORIZER_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.authorizerLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getAuthorizerSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date) // NOSONAR
                return `${name} eq '${moment$c(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time) // NOSONAR
                return `${name} eq '${moment$c(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime) // NOSONAR
                return `${name} eq '${moment$c(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum) // NOSONAR
                return this.loadEnumFromLabel(value) // NOSONAR
                    .map((/**
                 * @param {?} enumConstant
                 * @return {?}
                 */
                (enumConstant) => `${name} eq '${enumConstant}'`)) // NOSONAR
                    .join(" or "); // NOSONAR
            else if (type == FieldType.String) // NOSONAR
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }))
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        (filter) => filter !== ""))
            .join(" or ");
        /** @type {?} */
        const displayFields = mergeUnique(this.authorizerLookupDisplayFields, this.authorizerAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.authorizerLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                (field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.authorizerLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.authorizerLookupSuggestions = list.contents;
        }));
        /*{CA:ON_AUTHORIZER_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_AUTHORIZER_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onAuthorizerSearchRequest(event) {
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getAuthorizerSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            // NOSONAR
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date) // NOSONAR
                return `${name} eq '${moment$c(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time) // NOSONAR
                return `${name} eq '${moment$c(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime) // NOSONAR
                return `${name} eq '${moment$c(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String) // NOSONAR
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" and ");
        // NOSONAR
        /** @type {?} */
        const displayFields = mergeUnique(this.authorizerLookupDisplayFields, this.authorizerAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.authorizerLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                (field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.authorizerLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.authorizerSearchGridData = list.contents;
            this.authorizerSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getFormGroup() {
        /** @type {?} */
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            startDateTime: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            endDateTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            authorizer: [{ value: undefined, disabled: false }, Validators.compose([])],
            observation: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.maxLength(255)]),
            ],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.startDateTimeIsBeforeEndDateTime(),
            ],
        });
        /*{CA:GET_FORM_CONTROLS:START}*/
        /*{CA:GET_FORM_CONTROLS:END}*/
        return formGroup;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions,
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    getAuthorizerSearchFields() {
        // NOSONAR
        /** @type {?} */
        const searchFields = [
            new FormField({
                // NOSONAR
                name: "employer.codEmp",
                // NOSONAR
                label: this.translate.instant(// NOSONAR
                "hcm_clocking_event_foundation.general.employee_employer_cod_emp" // NOSONAR
                ),
                // NOSONAR
                type: FieldType.Integer,
            }),
            new FormField({
                // NOSONAR
                name: "code",
                // NOSONAR
                label: this.translate.instant(// NOSONAR
                "hcm_clocking_event_foundation.general.employee_code" // NOSONAR
                ),
                // NOSONAR
                type: FieldType.Integer,
            }),
            new FormField({
                // NOSONAR
                name: "person.nomPes",
                // NOSONAR
                label: this.translate.instant(// NOSONAR
                "hcm_clocking_event_foundation.general.employee_person_nom_pes" // NOSONAR
                ),
                // NOSONAR
                type: FieldType.String,
            }),
            new FormField({
                // NOSONAR
                name: "employmentRelationship.contractType",
                // NOSONAR
                label: this.translate.instant(// NOSONAR
                "hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type" // NOSONAR
                ),
                // NOSONAR
                type: FieldType.Enum,
                // NOSONAR
                options: this.contractTypeOptions,
            }),
        ];
        /*{CA:GET_AUTHORIZER_SEARCH_FIELDS:START}*/
        /*{CA:GET_AUTHORIZER_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getAuthorizerSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                // NOSONAR
                name: "employer.codEmp",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                // NOSONAR
                type: FieldType.Integer,
            }),
            new FormField({
                // NOSONAR
                name: "code",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                // NOSONAR
                type: FieldType.Integer,
            }),
            new FormField({
                // NOSONAR
                name: "person.nomPes",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                // NOSONAR
                type: FieldType.String,
            }),
            new FormField({
                // NOSONAR
                name: "employmentRelationship.contractType",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                // NOSONAR
                type: FieldType.Enum,
                // NOSONAR
                options: this.contractTypeOptions // NOSONAR
            }),
        ];
        /*{CA:GET_AUTHORIZER_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_AUTHORIZER_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    goBack() {
        /** @type {?} */
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    /**
     * @private
     * @param {?} formGroup
     * @return {?}
     */
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((/**
         * @param {?} field
         * @return {?}
         */
        (field) => {
            /** @type {?} */
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        }));
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls['employee'].value;
        /** @type {?} */
        const overtimeAuthorizationDto = OvertimeAuthorization.toDto(value);
        /** @type {?} */
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.overtimeAuthorizationService.insert(overtimeAuthorizationDto);
        }
        else {
            /** @type {?} */
            const id = this.routeParams.overtimeAuthorization;
            observable = this.overtimeAuthorizationService.update(id, overtimeAuthorizationDto);
        }
        return observable;
    }
    /**
     * @private
     * @return {?}
     */
    getDeleteObservable() {
        return this.overtimeAuthorizationService
            .delete(this.routeParams.overtimeAuthorization)
            .pipe(tap((/**
         * @return {?}
         */
        () => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
            this.goBack(); // NOSONAR
        })) // NOSONAR
        ); // NOSONAR
    }
    /**
     * @private
     * @return {?}
     */
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        /** @type {?} */
        const toValidate = ["employee"];
        if (!toValidate.every((/**
         * @param {?} e
         * @return {?}
         */
        (e) => this.allPermissions[e] && this.allPermissions[e].visualizar))) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    /**
     * @private
     * @return {?}
     */
    startDateTimeIsBeforeEndDateTime() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const startDateTime = control.get("startDateTime");
            /** @type {?} */
            const endDateTime = control.get("endDateTime");
            return startDateTimeIsBeforeEndDateTimeValidator(startDateTime, endDateTime);
        });
    }
    /*{CA:CLASS_METHODS:END}*/
    /**
     * @private
     * @param {?} severity
     * @param {?} summary
     * @param {?} detail
     * @return {?}
     */
    addMessage(severity, summary, detail) {
        this.messageService.add({
            severity,
            summary: this.translate.instant(summary),
            detail: this.translate.instant(detail),
        });
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLockedEmployee(value) {
        /** @type {?} */
        const employee = this.formGroup.controls['employee'].value;
        this.formGroup.reset();
        this.formGroup.controls['employee'].setValue(employee);
        if (this.formGroup.controls['employee'].value) {
            this.formGroup.controls['startDateTime'].setValue(moment$c(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((/**
             * @param {?} dto
             * @return {?}
             */
            (dto) => {
                this.onLoadFormSubject.next(false);
                /** @type {?} */
                const overtimeAuthorization = new OvertimeAuthorization();
                overtimeAuthorization.startDateTime = moment$c(value.evaluationDate).toDate();
                overtimeAuthorization.employee = Employee.fromDto(dto.contents[0], "OvertimeAuthorization");
                this.updateSuggestions(overtimeAuthorization);
                this.formGroup.patchValue(overtimeAuthorization);
                this.formGroup.controls['employee'].disable();
                this.loading = false;
            }));
        }
    }
}
OvertimeAuthorizationFormComponent.decorators = [
    { type: Component, args: [{
                template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\"  [toggleable]=\"false\"\n        [showHeader]=\"!lockedEmployee\" [collapsed]=\"mainPanelCollapsed\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.overtime_authorization_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.overtime_authorization_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                            <s-control-errors [control]=\"formGroup.controls['employee']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"authorizer\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_authorizer\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"authorizer\" name=\"authorizer\" formControlName=\"authorizer\" [searchFields]=\"authorizerSearchGridFields\"\n                            [searchGridFields]=\"authorizerSearchGridFields\" [searchGridData]=\"authorizerSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"authorizerLookupSuggestions\" (onLookupRequest)=\"onAuthorizerLookupRequest($event)\"\n                            (onSearchRequest)=\"onAuthorizerSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=authorizerSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.overtime_authorization_authorizer_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: authorizerSearchTotalRecords}\"></s-lookup>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"startDateTime\">{{\"hcm_clocking_event_foundation.general.readiness_start_date_time\" | translate}}</label>\n                        <p-calendar #startDateTimeFormInput inputId=\"startDateTime\" name=\"startDateTime\" [showIcon]=\"true\" [showTime]=\"true\" formControlName=\"startDateTime\" [locale]=\"localeConfig.calendar\"\n                            [dateFormat]=\"localeConfig.calendar.dateFormat\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDateTime']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                dateIsAfterHireDate: 'hcm_clocking_event_foundation.general.error_start_date_time_is_before_hire_date' | translate,\n                                startDateTimeIsBeforeEndDateTime: 'hcm_clocking_event_foundation.general.error_start_date_after_end_date_to_start_date' | translate\n                            }\"\n\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"endDateTime\">{{\"hcm_clocking_event_foundation.general.readiness_end_date_time\" | translate}}</label>\n                        <p-calendar #endDateTimeFormInput inputId=\"endDateTime\" name=\"endDateTime\" [showIcon]=\"true\" [showTime]=\"true\" formControlName=\"endDateTime\" [locale]=\"localeConfig.calendar\"\n                            [dateFormat]=\"localeConfig.calendar.dateFormat\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['endDateTime']\"\n                        [errorMessages]=\"{\n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            startDateTimeIsBeforeEndDateTime: 'hcm_clocking_event_foundation.general.error_start_date_after_end_date_to_end_date' | translate\n                        }\"\n                        ></s-control-errors>\n                    </div>\n\n                    <div class=\"ui-g-12 ui-md-12\">\n                        <label for=\"observation\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_observation\" | translate}}</label>\n                        <textarea #observationFormInput type=\"text\" id=\"observation\" name=\"observation\" pInputTextarea formControlName=\"observation\" rows=\"5\" autocomplete=\"off\"></textarea>\n                            <s-control-errors [control]=\"formGroup.controls['observation']\" [errorMessages]=\"{ maxlength: 'hcm_clocking_event_foundation.general.error_max_length' | translate: {value: '255'} }\"></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"overtimeAuthorization\"\n                formControlName=\"custom\" [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
                providers: [
                    ConfirmationService,
                ],
                selector: "cem-overtime-authorization-form",
                styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}#observation{max-width:100%!important}"]
            }] }
];
/** @nocollapse */
OvertimeAuthorizationFormComponent.ctorParameters = () => [
    { type: OvertimeAuthorizationService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: Renderer2 },
    { type: EmployeeService }
];
OvertimeAuthorizationFormComponent.propDecorators = {
    customTemplate: [{ type: ViewChild, args: ["customTemplate", { static: false },] }],
    customFormFields: [{ type: ViewChild, args: ["customFormFields", { static: false },] }],
    onSubmitObservable: [{ type: Input }],
    onLockedEmployeeChanges: [{ type: Input }],
    lockedEmployee: [{ type: Input }],
    onCloseObservable: [{ type: Output }],
    onLoadForm: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.localeConfig;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.currencyLocaleOptions;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.permissions;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.allPermissions;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.formGroup;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.loading;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.mainPanelCollapsed;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.contractTypeOptions;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.employeeLookupSuggestions;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.employeeLookupDisplayFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.employeeAdvancedDisplayFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.employeeLookupSeparator;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.employeeSearchFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.employeeSearchGridFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.employeeSearchGridData;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.employeeSearchTotalRecords;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.authorizerLookupSuggestions;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.authorizerLookupDisplayFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.authorizerAdvancedDisplayFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.authorizerLookupSeparator;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.authorizerSearchFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.authorizerSearchGridFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.authorizerSearchGridData;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.authorizerSearchTotalRecords;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.customTemplate;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.customFormFields;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.onSubmitObservable;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.onLockedEmployeeChanges;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.lockedEmployee;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.onClose;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.onLoadFormSubject;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.onCloseObservable;
    /** @type {?} */
    OvertimeAuthorizationFormComponent.prototype.onLoadForm;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.routeParams;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.ngUnsubscribe;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.overtimeAuthorizationService;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.router;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.route;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.messageService;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.confirmationService;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.formBuilder;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.translate;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.hotkeysService;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.fieldCustomization;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.focusService;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.renderer;
    /**
     * @type {?}
     * @private
     */
    OvertimeAuthorizationFormComponent.prototype.employeeService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/overtime-authorization/overtime-authorization-form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OvertimeAuthorizationFormModule {
}
OvertimeAuthorizationFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    LocaleModule.forChild(),
                    SharedScheduleModule
                ],
                declarations: [
                    OvertimeAuthorizationFormComponent
                ],
                exports: [
                    OvertimeAuthorizationFormComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift/workshift.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$d = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class Workshift {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} workshiftDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(workshiftDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, workshiftDto);
        model.createdDate = model.createdDate && moment$d(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$d(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "code",
            "workshiftType",
            "shortName",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} workshift
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(workshift, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, workshift);
        dto.createdDate = dto.createdDate && moment$d(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$d(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Workshift.prototype.id;
    /** @type {?} */
    Workshift.prototype.code;
    /** @type {?} */
    Workshift.prototype.shortName;
    /** @type {?} */
    Workshift.prototype.workshiftType;
    /** @type {?} */
    Workshift.prototype.deleted;
    /** @type {?} */
    Workshift.prototype.extIntSts;
    /** @type {?} */
    Workshift.prototype.extIntMsg;
    /** @type {?} */
    Workshift.prototype.createdBy;
    /** @type {?} */
    Workshift.prototype.createdDate;
    /** @type {?} */
    Workshift.prototype.lastModifiedBy;
    /** @type {?} */
    Workshift.prototype.lastModifiedDate;
    /** @type {?} */
    Workshift.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-group/workshift-group.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$e = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftGroup {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} workshiftGroupDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(workshiftGroupDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, workshiftGroupDto);
        model.baseDate = model.baseDate && moment$e(model.baseDate).toDate();
        model.createdDate = model.createdDate && moment$e(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$e(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "code",
            "baseDate",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} workshiftGroup
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(workshiftGroup, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, workshiftGroup);
        dto.baseDate = dto.baseDate && moment$e(dto.baseDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$e(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$e(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    WorkshiftGroup.prototype.id;
    /** @type {?} */
    WorkshiftGroup.prototype.code;
    /** @type {?} */
    WorkshiftGroup.prototype.baseDate;
    /** @type {?} */
    WorkshiftGroup.prototype.deleted;
    /** @type {?} */
    WorkshiftGroup.prototype.extIntSts;
    /** @type {?} */
    WorkshiftGroup.prototype.extIntMsg;
    /** @type {?} */
    WorkshiftGroup.prototype.createdBy;
    /** @type {?} */
    WorkshiftGroup.prototype.createdDate;
    /** @type {?} */
    WorkshiftGroup.prototype.lastModifiedBy;
    /** @type {?} */
    WorkshiftGroup.prototype.lastModifiedDate;
    /** @type {?} */
    WorkshiftGroup.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-change/workshift-change.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$f = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftChange {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} workshiftChangeDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(workshiftChangeDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, workshiftChangeDto);
        model.startDate = model.startDate && moment$f(model.startDate).toDate();
        model.endDate = model.endDate && moment$f(model.endDate).toDate();
        model.createdDate = model.createdDate && moment$f(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$f(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "startDate",
            "endDate",
            "workshift.code",
            "workshift.workshiftType",
            "workshift.shortName",
            "workshiftGroup.code",
            "workshiftGroup.baseDate",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "WorkshiftChange");
        if (originEntity !== "Workshift" && model.workshift)
            model.workshift = Workshift.fromDto(model.workshift, "WorkshiftChange");
        if (originEntity !== "WorkshiftGroup" && model.workshiftGroup)
            model.workshiftGroup = WorkshiftGroup.fromDto(model.workshiftGroup, "WorkshiftChange");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} workshiftChange
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(workshiftChange, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, workshiftChange);
        dto.startDate = dto.startDate && moment$f(dto.startDate).format("YYYY-MM-DD");
        dto.endDate = dto.endDate && moment$f(dto.endDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$f(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$f(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "WorkshiftChange");
        if (originEntity !== "Workshift" && dto.workshift)
            dto.workshift = Workshift.toDto(dto.workshift, "WorkshiftChange");
        if (originEntity !== "WorkshiftGroup" && dto.workshiftGroup)
            dto.workshiftGroup = WorkshiftGroup.toDto(dto.workshiftGroup, "WorkshiftChange");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    WorkshiftChange.prototype.id;
    /** @type {?} */
    WorkshiftChange.prototype.employee;
    /** @type {?} */
    WorkshiftChange.prototype.startDate;
    /** @type {?} */
    WorkshiftChange.prototype.endDate;
    /** @type {?} */
    WorkshiftChange.prototype.workshift;
    /** @type {?} */
    WorkshiftChange.prototype.workshiftGroup;
    /** @type {?} */
    WorkshiftChange.prototype.createdBy;
    /** @type {?} */
    WorkshiftChange.prototype.createdDate;
    /** @type {?} */
    WorkshiftChange.prototype.lastModifiedBy;
    /** @type {?} */
    WorkshiftChange.prototype.lastModifiedDate;
    /** @type {?} */
    WorkshiftChange.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-change/workshift-change.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftChangeService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/workshiftChange`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
WorkshiftChangeService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
WorkshiftChangeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    WorkshiftChangeService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    WorkshiftChangeService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    WorkshiftChangeService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-group/workshift-group.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftGroupService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_foundation/work_schedule/entities/workshiftGroup`, `hcm_foundation/work_schedule/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
WorkshiftGroupService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
WorkshiftGroupService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    WorkshiftGroupService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    WorkshiftGroupService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    WorkshiftGroupService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift/workshift.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_foundation/work_schedule/entities/workshift`, `hcm_foundation/work_schedule/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    /**
     * @param {?} employeeId
     * @return {?}
     */
    getCurrentWorkShiftIdByEmployeeId(employeeId) {
        return this.http.get(`hcm_contract/employment_contract_processor/queries/getCurrentWorkShiftByEmployeeId?employeeId=${employeeId}`);
    }
}
WorkshiftService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
WorkshiftService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    WorkshiftService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    WorkshiftService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    WorkshiftService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/workshift-change/form/workshift-change-form.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$g = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftChangeFormComponent {
    /**
     * @param {?} workshiftChangeService
     * @param {?} router
     * @param {?} route
     * @param {?} messageService
     * @param {?} confirmationService
     * @param {?} formBuilder
     * @param {?} translate
     * @param {?} hotkeysService
     * @param {?} fieldCustomization
     * @param {?} focusService
     * @param {?} workshiftGroupService
     * @param {?} workshiftService
     * @param {?} employeeService
     * @param {?} companyClockingEventIndicationsService
     */
    constructor(workshiftChangeService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, workshiftGroupService, workshiftService, employeeService, companyClockingEventIndicationsService) {
        this.workshiftChangeService = workshiftChangeService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.workshiftGroupService = workshiftGroupService;
        this.workshiftService = workshiftService;
        this.employeeService = employeeService;
        this.companyClockingEventIndicationsService = companyClockingEventIndicationsService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.workshiftGroupLookupDisplayFields = ["code", "baseDate"];
        this.workshiftGroupAdvancedDisplayFields = ["code", "baseDate"];
        this.workshiftGroupLookupSeparator = " - ";
        this.workshiftLookupDisplayFields = ["code", "shortName"];
        this.workshiftAdvancedDisplayFields = ["code", "shortName", "workshiftType"];
        this.workshiftLookupSeparator = " - ";
        this.selectedWorkshiftId = '';
        this.workshiftType = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_change_workshift_type_permanent"), value: "PERMANENT" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_change_workshift_type_automatic_search"), value: "AUTOMATIC_SEARCH" },
        ];
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType", "hireDate", "dismissalDate"];
        this.employeeLabelDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.indications = new Array();
        /*{CA:CLASS_ATTRIBUTES:START}*/
        this.cacheLimitDaysBackwardScheduling = new Map();
        this.requiredChecker = {
            isRequired: false,
        };
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter((/**
             * @param {?} name
             * @return {?}
             */
            name => name === 'workshiftChange'))).subscribe((/**
             * @return {?}
             */
            () => {
                this.confirmBeforeSave();
            }));
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((/**
             * @param {?} value
             * @return {?}
             */
            (value) => {
                this.loadLockedEmployee(value);
            }));
        }
        else {
            this.setHotkeys();
        }
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => this.onRouteParamsChange(params)));
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => this.onRouteDataChange(data)));
        this.workshiftGroupSearchFields = this.getWorkshiftGroupSearchFields();
        this.workshiftGroupSearchGridFields = this.getWorkshiftGroupSearchGridFields();
        this.workshiftSearchFields = this.getWorkshiftSearchFields();
        this.workshiftSearchGridFields = this.getWorkshiftSearchGridFields();
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLockedEmployee(value) {
        /** @type {?} */
        const employee = this.formGroup.controls['employee'].value;
        this.formGroup.reset();
        this.formGroup.controls['employee'].setValue(employee);
        if (this.formGroup.controls['employee'].value) {
            this.formGroup.controls['startDate'].setValue(moment$g(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((/**
             * @param {?} dto
             * @return {?}
             */
            (dto) => {
                this.onLoadFormSubject.next(false);
                /** @type {?} */
                const workScheduleChange = new WorkshiftChange();
                workScheduleChange.startDate = moment$g(value.evaluationDate).toDate();
                workScheduleChange.employee = Employee.fromDto(dto.contents[0], "WorkshiftChange");
                this.updateSuggestions(workScheduleChange);
                this.formGroup.patchValue(workScheduleChange);
                this.formGroup.controls['employee'].disable();
                this.loading = false;
            }));
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        this.cacheLimitDaysBackwardScheduling.clear();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    /**
     * @return {?}
     */
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", (/**
         * @return {?}
         */
        () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", (/**
         * @return {?}
         */
        () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", (/**
         * @return {?}
         */
        () => {
            this.onCancel();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    /**
     * @return {?}
     */
    isNew() {
        return this.routeParams.workshiftChange == "new";
    }
    /**
     * @param {?} params
     * @return {?}
     */
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.workshiftGroup) {
            value.workshiftGroup.label = this.getSuggestionValue(["code"], "workshiftGroup", value, this.workshiftGroupLookupSeparator);
            if (value.workshiftGroup.label.toString().trim() === this.workshiftGroupLookupSeparator.trim()) {
                delete value.workshiftGroup.label;
            }
        }
        if (value.workshift) {
            value.workshift.label = this.getSuggestionValue(["code", "shortName", "workshiftType"], "workshift", value, this.workshiftLookupSeparator);
            if (value.workshift.label.toString().trim() === this.workshiftLookupSeparator.trim()) {
                delete value.workshift.label;
            }
        }
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue(["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractTypeLabel"], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.toString().trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    /**
     * @param {?} displayFields
     * @param {?} ownerEntity
     * @param {?} value
     * @param {?} separator
     * @return {?}
     */
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((/**
         * @param {?} field
         * @return {?}
         */
        field => this.getProp(value, `${ownerEntity}.${field}`)))
            .reduce((/**
         * @param {?} acc
         * @param {?} val
         * @return {?}
         */
        (acc, val) => `${acc}${separator}${val}`));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.workshiftChange;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity && data.entity[0]) {
            /** @type {?} */
            const canEdit = this.permissions.editar;
            if (!canEdit)
                this.formGroup.disable();
            /** @type {?} */
            const value = WorkshiftChange.fromDto(data.entity[0]);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
            this.workShiftId = data.entity[0].workshift.id;
            this.employeeId = data.entity[0].employee.id;
            /** @type {?} */
            let limitDate = new Date();
            limitDate.setDate(limitDate.getDate() - data.entity[1].timeEvaluationDefinition.limitDaysBackwardScheduling);
            this.cacheLimitDaysBackwardScheduling.set(data.entity[1].id, limitDate);
            this.indications.push(data.entity[1]);
        }
        else {
            this.formGroup.patchValue(new WorkshiftChange());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    /**
     * @return {?}
     */
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    /**
     * @param {?} filesToDelete
     * @param {?} filesToCommit
     * @return {?}
     */
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /** @type {?} */
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    /**
     * @return {?}
     */
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        })))
            .subscribe((/**
         * @return {?}
         */
        () => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
             * @param {?} err
             * @return {?}
             */
            (err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            })))
                .subscribe((/**
             * @return {?}
             */
            () => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                if (this.lockedEmployee) {
                    this.onClose.next();
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            }));
        }));
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    /**
     * @return {?}
     */
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: (/**
             * @return {?}
             */
            () => this.getDeleteObservable()
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe()),
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    /**
     * @param {?} obj
     * @param {?} path
     * @return {?}
     */
    getProp(obj, path) {
        return path.split(".").reduce((/**
         * @param {?} result
         * @param {?} prop
         * @return {?}
         */
        (result, prop) => (result[prop] === undefined ? "" : result[prop])), obj);
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((/**
         * @param {?} r
         * @return {?}
         */
        r => r.value === value))[0].label;
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions.filter((/**
             * @param {?} r
             * @return {?}
             */
            r => {
                /** @type {?} */
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            }))
                .map((/**
             * @param {?} r
             * @return {?}
             */
            r => r.value));
        }
        return [];
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onWorkshiftGroupLookupRequest(value) {
        /*{CA:ON_WORKSHIFT_GROUP_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = ["code"].map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        let filterQuery = this.getWorkshiftGroupSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" or ");
        /** @type {?} */
        let filters = [`workshift eq '${this.selectedWorkshiftId}'`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        /** @type {?} */
        const displayFields = mergeUnique(this.workshiftGroupLookupDisplayFields, this.workshiftGroupAdvancedDisplayFields);
        this.workshiftGroupService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.workshiftGroupLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => this.formatWorkshiftGroupBaseDate(item, field)))
                    .join(this.workshiftGroupLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.workshiftGroupLookupSuggestions = list.contents;
        }));
        /*{CA:ON_WORKSHIFT_GROUP_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onWorkshiftGroupSearchRequest(event) {
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        let filterQuery = this.getWorkshiftGroupSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" and ");
        /** @type {?} */
        let filters = [`workshift eq '${this.selectedWorkshiftId}'`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        /** @type {?} */
        const displayFields = mergeUnique(this.workshiftGroupLookupDisplayFields, this.workshiftGroupAdvancedDisplayFields);
        this.workshiftGroupService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.workshiftGroupLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => this.formatWorkshiftGroupBaseDate(item, field)))
                    .join(this.workshiftGroupLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.workshiftGroupSearchGridData = list.contents;
            this.workshiftGroupSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onWorkshiftLookupRequest(value) {
        /*{CA:ON_WORKSHIFT_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.workshiftLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        let filterQuery = this.getWorkshiftSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value) && type !== FieldType.Enum))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        filter => filter !== ''))
            .join(" or ");
        // NOSONAR
        /** @type {?} */
        const startDate = moment$g(this.formGroup.value.startDate).format("YYYY-MM-DD");
        /** @type {?} */
        const endDate = moment$g(this.formGroup.value.endDate).format("YYYY-MM-DD");
        /** @type {?} */
        const filters = [
            `initialValidity <= '${startDate}' and finalValidity >= '${endDate}'
            or initialValidity is null and finalValidity >= '${endDate}'
            or initialValidity <= '${startDate}' and finalValidity is null
            or initialValidity is null and finalValidity is null`,
        ];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        /** @type {?} */
        const displayFields = mergeUnique(["code", "shortName", "initialValidity", "finalValidity"], ["code", "shortName", "workshiftType", "initialValidity", "finalValidity"]);
        this.workshiftService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.workshiftLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.workshiftLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.workshiftLookupSuggestions = list.contents;
        }));
        /*{CA:ON_WORKSHIFT_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_WORKSHIFT_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onWorkshiftSearchRequest(event) {
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        let filterQuery = this.getWorkshiftSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            // NOSONAR
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" and ");
        // NOSONAR
        /** @type {?} */
        const startDate = moment$g(this.formGroup.value.startDate).format("YYYY-MM-DD");
        /** @type {?} */
        const endDate = moment$g(this.formGroup.value.endDate).format("YYYY-MM-DD");
        /** @type {?} */
        const filters = [
            `initialValidity <= '${startDate}' and finalValidity >= '${endDate}'
            or initialValidity is null and finalValidity >= '${endDate}'
            or initialValidity <= '${startDate}' and finalValidity is null
            or initialValidity is null and finalValidity is null`,
        ];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        /** @type {?} */
        const displayFields = mergeUnique(["code", "shortName", "initialValidity", "finalValidity"], ["code", "shortName", "workshiftType", "initialValidity", "finalValidity"]);
        this.workshiftService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.workshiftLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.workshiftLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.workshiftSearchGridData = list.contents;
            this.workshiftSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.employeeLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map((/**
                 * @param {?} enumConstant
                 * @return {?}
                 */
                enumConstant => `${name} eq '${enumConstant}'`)).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        filter => filter !== ''))
            .join(" or ");
        /** @type {?} */
        const displayFields = this.employeeLookupDisplayFields;
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLabelDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                }))
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeLookupSuggestions = list.contents;
        }));
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            // NOSONAR
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" and ");
        // NOSONAR
        /** @type {?} */
        const displayFields = this.employeeLookupDisplayFields;
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLabelDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === 'employmentRelationship.contractType') { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getFormGroup() {
        /** @type {?} */
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            workshift: [{ value: undefined, disabled: true }, Validators.compose([Validators.required])],
            workshiftGroup: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.startDateIsBeforeEndDate(),
                this.validLimitDaysBackwardScheduling(),
            ]
        });
        /*{CA:GET_FORM_CONTROLS:START}*/
        formGroup.controls.employee.valueChanges.subscribe((/**
         * @param {?} employee
         * @return {?}
         */
        employee => {
            if (employee) {
                /** @type {?} */
                let limitDaysBackwardScheduling = this.cacheLimitDaysBackwardScheduling.get(employee.employer.id);
                if (limitDaysBackwardScheduling === undefined) {
                    this.companyClockingEventIndicationsService
                        .list({
                        filterQuery: `id eq '${employee.employer.id}'`,
                        displayFields: ['timeEvaluationDefinition.limitDaysBackwardScheduling']
                    })
                        .pipe(map((/**
                     * @param {?} data
                     * @return {?}
                     */
                    (data) => data.contents[0])), catchError((/**
                     * @param {?} error
                     * @return {?}
                     */
                    error => {
                        formGroup.controls.employee.setErrors({ hasNotCompanyClockingEventIndications: { value: error } });
                        return throwError(error);
                    }))).subscribe((/**
                     * @param {?} companyClockingEventIndications
                     * @return {?}
                     */
                    (companyClockingEventIndications) => {
                        /** @type {?} */
                        let limitDate = new Date();
                        limitDate.setDate(limitDate.getDate() - companyClockingEventIndications.timeEvaluationDefinition.limitDaysBackwardScheduling);
                        this.cacheLimitDaysBackwardScheduling.set(companyClockingEventIndications.id, limitDate);
                    }));
                }
            }
        }));
        formGroup.controls.workshift.valueChanges.subscribe((/**
         * @param {?} workshift
         * @return {?}
         */
        workshift => {
            this.selectedWorkshiftId = workshift ? workshift.id : null;
            this.setWorkshiftGroupMandatory(this.requiredChecker.isRequired, formGroup);
            formGroup.controls.workshiftGroup.setValue(null);
        }));
        formGroup.controls.startDate.valueChanges.subscribe((/**
         * @param {?} startDate
         * @return {?}
         */
        startDate => {
            this.verifyWorkshiftLookupDisabled(startDate, this.formGroup.value.endDate);
        }));
        formGroup.controls.endDate.valueChanges.subscribe((/**
         * @param {?} endDate
         * @return {?}
         */
        endDate => {
            this.verifyWorkshiftLookupDisabled(this.formGroup.value.startDate, endDate);
        }));
        /*{CA:GET_FORM_CONTROLS:END}*/
        return formGroup;
    }
    /**
     * @private
     * @return {?}
     */
    getWorkshiftGroupSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_group_code"),
                type: FieldType.Integer,
            })
        ];
        /*{CA:GET_WORKSHIFT_GROUP_SEARCH_FIELDS:START}*/
        /*{CA:GET_WORKSHIFT_GROUP_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getWorkshiftGroupSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_group_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "baseDate",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_group_base_date"),
                type: FieldType.Date,
            }),
        ];
        /*{CA:GET_WORKSHIFT_GROUP_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_WORKSHIFT_GROUP_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    getWorkshiftSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "shortName",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_short_name"),
                type: FieldType.String,
            }),
            new FormField({
                name: "workshiftType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_change_workshift_type"),
                type: FieldType.Enum,
                options: this.workshiftType,
            }),
        ];
        /*{CA:GET_WORKSHIFT_SEARCH_FIELDS:START}*/
        /*{CA:GET_WORKSHIFT_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getWorkshiftSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "shortName",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_short_name"),
                type: FieldType.String,
            }),
            new FormField({
                name: "workshiftType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_change_workshift_type"),
                type: FieldType.Enum,
                options: this.workshiftType,
            }),
        ];
        /*{CA:GET_WORKSHIFT_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_WORKSHIFT_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    goBack() {
        /** @type {?} */
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    /**
     * @private
     * @param {?} formGroup
     * @return {?}
     */
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((/**
         * @param {?} field
         * @return {?}
         */
        field => {
            /** @type {?} */
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        }));
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls['employee'].value;
        /** @type {?} */
        const workshiftChangeDto = WorkshiftChange.toDto(value);
        /** @type {?} */
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.workshiftChangeService.insert(workshiftChangeDto);
        }
        else {
            /** @type {?} */
            const id = this.routeParams.workshiftChange;
            observable = this.workshiftChangeService.update(id, workshiftChangeDto);
        }
        return observable;
    }
    /**
     * @private
     * @return {?}
     */
    getDeleteObservable() {
        return this.workshiftChangeService.delete(this.routeParams.workshiftChange).pipe(tap((/**
         * @return {?}
         */
        () => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
            this.goBack(); // NOSONAR
        })));
    }
    /**
     * @private
     * @return {?}
     */
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        /** @type {?} */
        const toValidate = ["employee", "workshift"];
        if (!toValidate.every((/**
         * @param {?} e
         * @return {?}
         */
        e => this.allPermissions[e] && this.allPermissions[e].visualizar))) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    /**
     * @private
     * @return {?}
     */
    startDateIsBeforeEndDate() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const startDate = control.get('startDate');
            /** @type {?} */
            const endDate = control.get('endDate');
            return startDateIsBeforeOrEqualToEndDateValidator(startDate, endDate);
        });
    }
    /**
     * @private
     * @return {?}
     */
    validLimitDaysBackwardScheduling() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const startDate = control.get('startDate');
            /** @type {?} */
            const employee = control.get('employee');
            if (employee.value && startDate.value) {
                /** @type {?} */
                const limitDate = this.cacheLimitDaysBackwardScheduling.get(employee.value.employer.id);
                if (limitDate && moment$g(startDate.value).isBefore(limitDate, 'day')) {
                    startDate.setErrors({ exceededLimit: { value: startDate.value } });
                }
                else {
                    removeErrorFromField(startDate, 'exceededLimit');
                }
            }
            else {
                removeErrorFromField(startDate, 'exceededLimit');
            }
            return null;
        });
    }
    /**
     * @return {?}
     */
    confirmBeforeSave() {
        this.loading = true;
        if (!this.formGroup.valid) {
            this.loading = false;
            return this.validateAllFormFields(this.formGroup);
        }
        this.workshiftService.getCurrentWorkShiftIdByEmployeeId(this.formGroup.controls.employee.value.id).subscribe((/**
         * @param {?} dto
         * @return {?}
         */
        (dto) => {
            this.loading = false;
            if ((this.formGroup.controls.workshift.value.id != this.workShiftId || this.formGroup.controls.employee.value.id != this.employeeId) && this.formGroup.controls.workshift.value.id == dto.workShiftId) {
                this.confirmationService.confirm({
                    key: "customized",
                    message: this.translate.instant("hcm_clocking_event_foundation.general.validation_employee_has_currently_this_work_shift"),
                    accept: (/**
                     * @return {?}
                     */
                    () => this.onSave()),
                    reject: (/**
                     * @return {?}
                     */
                    () => this.loading = false)
                });
            }
            else {
                this.onSave();
            }
        }));
    }
    /**
     * @private
     * @param {?} isEnabled
     * @param {?} formGroup
     * @return {?}
     */
    setWorkshiftGroupMandatory(isEnabled, formGroup) {
        /** @type {?} */
        const workshift = formGroup.controls.workshift;
        /** @type {?} */
        const workshiftGroup = formGroup.controls.workshiftGroup;
        if (workshift.value == null) {
            this.requiredChecker.isRequired = false;
            workshiftGroup.disable();
            workshiftGroup.setValue(null);
        }
        else {
            this.requiredChecker.isRequired = true;
            workshiftGroup.enable();
            workshiftGroup.setValidators(Validators.required);
        }
    }
    /*{CA:CLASS_METHODS:END}*/
    /**
     * @private
     * @param {?} severity
     * @param {?} summary
     * @param {?} detail
     * @return {?}
     */
    addMessage(severity, summary, detail) {
        this.messageService.add({
            severity,
            summary: this.translate.instant(summary),
            detail: this.translate.instant(detail),
        });
    }
    /**
     * @return {?}
     */
    getWorkshiftGroup() {
        return (/** @type {?} */ (this.translate.instant('hcm_clocking_event_foundation.general.workshift_change_workshift_group_info_sign')));
    }
    /**
     * @private
     * @param {?} item
     * @param {?} field
     * @return {?}
     */
    formatWorkshiftGroupBaseDate(item, field) {
        if (field.indexOf(".") > 0)
            return this.getProp(item, field);
        if (field === 'baseDate') {
            return moment$g(item[field]).format(this.localeConfig.calendar.dateFormat.replace('yy', 'YYYY').toUpperCase());
        }
        return item[field];
    }
    /**
     * @param {?=} startDate
     * @param {?=} endDate
     * @return {?}
     */
    verifyWorkshiftLookupDisabled(startDate = this.formGroup.controls.startDate.value, endDate = this.formGroup.controls.endDate.value) {
        if (startDate != null && endDate != null) {
            this.formGroup.controls.workshift.enable();
        }
        else {
            this.formGroup.controls.workshift.disable();
            this.formGroup.controls.workshift.setValue(null);
        }
    }
}
WorkshiftChangeFormComponent.decorators = [
    { type: Component, args: [{
                template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\" [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.workshift_change_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.workshift_change_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 required\" [ngClass]=\"lockedEmployee ? '' : 'ui-md-12 ui-lg-6'\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.workshift_change_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\" [multiple]=\"false\" \n                            [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.workshift_change_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n\n                        <s-control-errors [control]=\"formGroup.controls['employee']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div  class=\"ui-g-12 ui-md-6 required\" [ngClass]=\"lockedEmployee ? '' : 'ui-md-6 ui-lg-3'\">\n                        <label for=\"startDate\">{{\"hcm_clocking_event_foundation.general.workshift_change_start_date\" | translate}}</label>\n                        <p-calendar #startDateFormInput inputId=\"startDate\" name=\"startDate\" [showIcon]=\"true\" formControlName=\"startDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDate']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate, startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_start_date_after_end_date' | translate, exceededLimit: 'hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling' | translate }\">\n                        </s-control-errors>\n                    </div>\n                    <div  class=\"ui-g-12 ui-md-6 required\" [ngClass]=\"lockedEmployee ? '' : 'ui-md-6 ui-lg-3'\">\n                        <label for=\"endDate\">{{\"hcm_clocking_event_foundation.general.workshift_change_end_date\" | translate}}</label>\n                        <p-calendar #endDateFormInput inputId=\"endDate\" name=\"endDate\" [showIcon]=\"true\" formControlName=\"endDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['endDate']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate, startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_end_date_before_start_date' | translate }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.workshift.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"workshift\">{{\"hcm_clocking_event_foundation.general.workshift_change_workshift\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"workshift\" name=\"workshift\" formControlName=\"workshift\" [searchFields]=\"workshiftSearchFields\"\n                            [searchGridFields]=\"workshiftSearchGridFields\" [searchGridData]=\"workshiftSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"workshiftLookupSuggestions\" (onLookupRequest)=\"onWorkshiftLookupRequest($event)\"\n                            (onSearchRequest)=\"onWorkshiftSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=workshiftSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.workshift_change_workshift_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\"\n                            [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: workshiftSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['workshift']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.workshiftGroup.visualizar\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"workshiftGroup\">{{\"hcm_clocking_event_foundation.general.workshift_change_workshift_group\" | translate}}\n                            <span [ngClass]=\"requiredChecker.isRequired ? 'required' : ' '\">\n                                <label style=\"display: inline\"></label>\n                            </span>\n                            <span *sInfoSign=\"getWorkshiftGroup()\"></span>\n                        </label>\n                        <s-lookup dataKey=\"id\" id=\"workshiftGroup\" name=\"workshiftGroup\" formControlName=\"workshiftGroup\" [searchFields]=\"workshiftGroupSearchFields\"\n                            [searchGridFields]=\"workshiftGroupSearchGridFields\" [searchGridData]=\"workshiftGroupSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"workshiftGroupLookupSuggestions\" (onLookupRequest)=\"onWorkshiftGroupLookupRequest($event)\"\n                            (onSearchRequest)=\"onWorkshiftGroupSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=workshiftGroupSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.workshift_change_workshift_group_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: workshiftGroupSearchTotalRecords}\"></s-lookup>\n                            <s-control-errors [control]=\"formGroup.controls['workshiftGroup']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"workshiftChange\" formControlName=\"custom\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"confirmBeforeSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<p-confirmDialog key=\"customized\" #customized header=\"{{ 'hcm_clocking_event_foundation.general.generic_confirm' | translate }}\" appendTo=\"body\">\n    <p-footer>\n        <s-button label=\"{{ 'hcm_clocking_event_foundation.general.generic_yes' | translate }}\" (onClick)=\"customized.accept()\" priority=\"primary\" [disabled]=\"false\"\n            [auxiliary]=\"false\">\n        </s-button>\n        <s-button label=\"{{ 'hcm_clocking_event_foundation.general.generic_no' | translate }}\" (onClick)=\"customized.reject()\" priority=\"secondary\" [disabled]=\"false\"\n            [auxiliary]=\"false\">\n        </s-button>\n    </p-footer>\n</p-confirmDialog>\n<!--{CA:FILE_CONTENTS:END}-->\n",
                providers: [
                    ConfirmationService,
                ],
                /*{CA:COMPONENT_CONFIG:START}*/
                selector: 'cem-workshift-change-form'
                /*{CA:COMPONENT_CONFIG:END}*/
                ,
                styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
            }] }
];
/** @nocollapse */
WorkshiftChangeFormComponent.ctorParameters = () => [
    { type: WorkshiftChangeService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: WorkshiftGroupService },
    { type: WorkshiftService },
    { type: EmployeeService },
    { type: CompanyClockingEventIndicationsService }
];
WorkshiftChangeFormComponent.propDecorators = {
    customTemplate: [{ type: ViewChild, args: ["customTemplate", { static: false },] }],
    customFormFields: [{ type: ViewChild, args: ["customFormFields", { static: false },] }],
    onSubmitObservable: [{ type: Input }],
    onLockedEmployeeChanges: [{ type: Input }],
    lockedEmployee: [{ type: Input }],
    onCloseObservable: [{ type: Output }],
    onLoadForm: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.localeConfig;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.currencyLocaleOptions;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.permissions;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.allPermissions;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.formGroup;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.loading;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.mainPanelCollapsed;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftGroupLookupSuggestions;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftGroupLookupDisplayFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftGroupAdvancedDisplayFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftGroupLookupSeparator;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftGroupSearchFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftGroupSearchGridFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftGroupSearchGridData;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftGroupSearchTotalRecords;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftLookupSuggestions;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftLookupDisplayFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftAdvancedDisplayFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftLookupSeparator;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftSearchFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftSearchGridFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftSearchGridData;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftSearchTotalRecords;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.selectedWorkshiftId;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.workshiftType;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.contractTypeOptions;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.employeeLookupSuggestions;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.employeeLookupDisplayFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.employeeLabelDisplayFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.employeeLookupSeparator;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.employeeSearchFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.employeeSearchGridFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.employeeSearchGridData;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.employeeSearchTotalRecords;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.indications;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.customTemplate;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.customFormFields;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.cacheLimitDaysBackwardScheduling;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.workShiftId;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.employeeId;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.requiredChecker;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.onSubmitObservable;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.onLockedEmployeeChanges;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.lockedEmployee;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.onClose;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.onLoadFormSubject;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.onCloseObservable;
    /** @type {?} */
    WorkshiftChangeFormComponent.prototype.onLoadForm;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.routeParams;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.ngUnsubscribe;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.workshiftChangeService;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.router;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.route;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.messageService;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.confirmationService;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.formBuilder;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.translate;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.hotkeysService;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.fieldCustomization;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.focusService;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.workshiftGroupService;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.workshiftService;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.employeeService;
    /**
     * @type {?}
     * @private
     */
    WorkshiftChangeFormComponent.prototype.companyClockingEventIndicationsService;
}
/**
 * @record
 */
function WorkshiftTypeWorkshiftGroup() { }
if (false) {
    /** @type {?} */
    WorkshiftTypeWorkshiftGroup.prototype.isRequired;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/workshift-change/workshift-change-form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkshiftChangeFormModule {
}
WorkshiftChangeFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    LocaleModule.forChild(),
                    SharedScheduleModule,
                    InfoSignModule
                ],
                declarations: [
                    WorkshiftChangeFormComponent
                ],
                exports: [
                    WorkshiftChangeFormComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/compensation-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const CompensationType = {
    V1: "V1",
    V2: "V2",
    V4: "V4",
    V5: "V5",
    V6: "V6",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/period-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const PeriodType = {
    V1: "V1",
    V2: "V2",
    V3: "V3",
    V4: "V4",
    V5: "V5",
    V6: "V6",
    V7: "V7",
    V8: "V8",
    V9: "V9",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason/adjustment-reason.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/** @type {?} */
const moment$h = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class AdjustmentReason {
    constructor() {
        this.mandatoryObservation = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} adjustmentReasonDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(adjustmentReasonDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, adjustmentReasonDto);
        model.createdDate = model.createdDate && moment$h(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$h(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "code",
            "name",
            "mandatoryObservation",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} adjustmentReason
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(adjustmentReason, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, adjustmentReason);
        dto.createdDate = dto.createdDate && moment$h(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$h(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    AdjustmentReason.prototype.id;
    /** @type {?} */
    AdjustmentReason.prototype.code;
    /** @type {?} */
    AdjustmentReason.prototype.name;
    /** @type {?} */
    AdjustmentReason.prototype.mandatoryObservation;
    /** @type {?} */
    AdjustmentReason.prototype.createdBy;
    /** @type {?} */
    AdjustmentReason.prototype.createdDate;
    /** @type {?} */
    AdjustmentReason.prototype.lastModifiedBy;
    /** @type {?} */
    AdjustmentReason.prototype.lastModifiedDate;
    /** @type {?} */
    AdjustmentReason.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/situation-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function SituationDto() { }
if (false) {
    /** @type {?|undefined} */
    SituationDto.prototype.id;
    /** @type {?} */
    SituationDto.prototype.code;
    /** @type {?} */
    SituationDto.prototype.name;
    /** @type {?|undefined} */
    SituationDto.prototype.deleted;
    /** @type {?|undefined} */
    SituationDto.prototype.extIntSts;
    /** @type {?|undefined} */
    SituationDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    SituationDto.prototype.createdBy;
    /** @type {?|undefined} */
    SituationDto.prototype.createdDate;
    /** @type {?|undefined} */
    SituationDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    SituationDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    SituationDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workschedule/workschedule-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function WorkscheduleDto() { }
if (false) {
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.id;
    /** @type {?} */
    WorkscheduleDto.prototype.code;
    /** @type {?} */
    WorkscheduleDto.prototype.name;
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.deleted;
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.extIntSts;
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.createdBy;
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.createdDate;
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    WorkscheduleDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workschedule/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/compensation/compensation.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:END}*/
/** @type {?} */
const moment$i = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class Compensation {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} compensationDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(compensationDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, compensationDto);
        model.startDate = model.startDate && moment$i(model.startDate).toDate();
        model.endDate = model.endDate && moment$i(model.endDate).toDate();
        model.intervalStart = model.intervalStart && moment$i(model.intervalStart, "HH:mm:ss").toDate();
        model.intervalEnd = model.intervalEnd && moment$i(model.intervalEnd, "HH:mm:ss").toDate();
        model.createdDate = model.createdDate && moment$i(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$i(model.lastModifiedDate).toDate();
        if (model.numberOfHours) {
            model.numberOfHours = this.convertMinuteToTime(model.numberOfHours);
        }
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "employee.code",
            "employee.person.nomPes",
            "startDate",
            "compensationType",
            "periodType",
            "endDate",
            "situation.code",
            "situation.name",
            "situation.situationType",
            "workschedule.code",
            "workschedule.name",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee) {
            model.employee = Employee.fromDto(model.employee, "Compensation");
        }
        if (originEntity !== "Situation" && model.situation) {
            model.situation = Situation.fromDto(model.situation, "Compensation");
        }
        if (originEntity !== "Workschedule" && model.workschedule) {
            model.workschedule = Workschedule.fromDto(model.workschedule, "Compensation");
        }
        if (originEntity !== "AdjustmentReason" && model.adjustmentReason) {
            model.adjustmentReason = AdjustmentReason.fromDto(model.adjustmentReason, "Compensation");
        }
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} compensation
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(compensation, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, compensation);
        dto.startDate = dto.startDate && moment$i(dto.startDate).format("YYYY-MM-DD");
        dto.endDate = dto.endDate && moment$i(dto.endDate).format("YYYY-MM-DD");
        dto.intervalStart = dto.intervalStart && moment$i(dto.intervalStart).format("HH:mm:ss");
        dto.intervalEnd = dto.intervalEnd && moment$i(dto.intervalEnd).format("HH:mm:ss");
        dto.createdDate = dto.createdDate && moment$i(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$i(dto.lastModifiedDate).format();
        dto.numberOfHours = convertTimeToMinutes(dto.numberOfHours);
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee) {
            dto.employee = Employee.toDto(dto.employee, "Compensation");
        }
        if (originEntity !== "Situation" && dto.situation) {
            dto.situation = Situation.toDto(dto.situation, "Compensation");
        }
        if (originEntity !== "Workschedule" && dto.workschedule) {
            dto.workschedule = Workschedule.toDto(dto.workschedule, "Compensation");
        }
        if (originEntity !== "AdjustmentReason" && dto.adjustmentReason) {
            dto.adjustmentReason = AdjustmentReason.toDto(dto.adjustmentReason, "Compensation");
        }
        return dto;
    }
    /*{CA:CLASS_METHODS:START}*/
    /**
     * @private
     * @param {?} minutes
     * @param {?=} monthMinute
     * @return {?}
     */
    static convertMinuteToTime(minutes, monthMinute) {
        /** @type {?} */
        const minute = minutes.toString();
        return convertMinutesToTime(minute, monthMinute);
    }
}
if (false) {
    /** @type {?} */
    Compensation.prototype.id;
    /** @type {?} */
    Compensation.prototype.employee;
    /** @type {?} */
    Compensation.prototype.startDate;
    /** @type {?} */
    Compensation.prototype.endDate;
    /** @type {?} */
    Compensation.prototype.intervalStart;
    /** @type {?} */
    Compensation.prototype.intervalEnd;
    /** @type {?} */
    Compensation.prototype.compensationType;
    /** @type {?} */
    Compensation.prototype.periodType;
    /** @type {?} */
    Compensation.prototype.numberOfHours;
    /** @type {?} */
    Compensation.prototype.situation;
    /** @type {?} */
    Compensation.prototype.workschedule;
    /** @type {?} */
    Compensation.prototype.adjustmentReason;
    /** @type {?} */
    Compensation.prototype.createdBy;
    /** @type {?} */
    Compensation.prototype.createdDate;
    /** @type {?} */
    Compensation.prototype.lastModifiedBy;
    /** @type {?} */
    Compensation.prototype.lastModifiedDate;
    /** @type {?} */
    Compensation.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/compensation/compensation.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class CompensationService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/compensation`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
CompensationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
CompensationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    CompensationService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    CompensationService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    CompensationService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason-situation/adjustment-reason-situation.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class AdjustmentReasonSituationService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/adjustmentReasonSituation`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
AdjustmentReasonSituationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AdjustmentReasonSituationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    AdjustmentReasonSituationService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    AdjustmentReasonSituationService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    AdjustmentReasonSituationService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/situation-clocking-event.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SituationClockingEventService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/situationClockingEvent`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
SituationClockingEventService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SituationClockingEventService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    SituationClockingEventService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    SituationClockingEventService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    SituationClockingEventService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/compensation/form/compensation-form.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/** @type {?} */
const moment$j = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class CompensationFormComponent {
    /**
     * @param {?} companyClockingEventIndicationsService
     * @param {?} compensationService
     * @param {?} router
     * @param {?} route
     * @param {?} messageService
     * @param {?} confirmationService
     * @param {?} formBuilder
     * @param {?} translate
     * @param {?} hotkeysService
     * @param {?} fieldCustomization
     * @param {?} focusService
     * @param {?} adjustmentReasonSituationService
     * @param {?} workscheduleService
     * @param {?} employeeService
     * @param {?} situationService
     * @param {?} situationClockingEventService
     */
    constructor(companyClockingEventIndicationsService, compensationService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, adjustmentReasonSituationService, workscheduleService, employeeService, situationService, situationClockingEventService) {
        this.companyClockingEventIndicationsService = companyClockingEventIndicationsService;
        this.compensationService = compensationService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.adjustmentReasonSituationService = adjustmentReasonSituationService;
        this.workscheduleService = workscheduleService;
        this.employeeService = employeeService;
        this.situationService = situationService;
        this.situationClockingEventService = situationClockingEventService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.compensationType = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_1"), value: CompensationType.V1 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_2"), value: CompensationType.V2 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_4"), value: CompensationType.V4 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_5"), value: CompensationType.V5 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_6"), value: CompensationType.V6 },
        ];
        this.adjustmentReasonLookupDisplayFields = ["adjustmentReason.code", "adjustmentReason.name"];
        this.adjustmentReasonAdvancedDisplayFields = ["adjustmentReason.code", "adjustmentReason.name"];
        this.adjustmentReasonLookupSeparator = " - ";
        this.workscheduleLookupDisplayFields = ["code", "name"];
        this.workscheduleAdvancedDisplayFields = ["code", "name"];
        this.workscheduleLookupSeparator = " - ";
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.situationLookupDisplayFields = ["code", "name"];
        this.situationAdvancedDisplayFields = ["code", "name", "situationType"];
        this.situationLookupSeparator = " - ";
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.selectedSituationId = "";
        this.controlAdjustmentReason = false;
        this.mandatoryAdjustmentReasonBySituation = new Map();
        this.mandatoryAdjustmentReason = false;
        this.cacheAdjustmentReasonIsEnable = new Map();
        this.cacheLimitDaysBackwardScheduling = new Map();
        this.enablePeriods = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_1"), value: PeriodType.V1 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_2"), value: PeriodType.V2 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_3"), value: PeriodType.V3 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_4"), value: PeriodType.V4 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_5"), value: PeriodType.V5 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_6"), value: PeriodType.V6 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_7"), value: PeriodType.V7 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_8"), value: PeriodType.V8 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_9"), value: PeriodType.V9 },
        ];
        this.enableFileds = {
            interval: true,
            numberOfHours: true,
            workSchedule: true,
            periods: this.enablePeriods
        };
        this.controlOfFormFields = new Map([
            [CompensationType.V1, {
                    interval: false,
                    numberOfHours: true,
                    workSchedule: false,
                    periods: [
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_1"), value: PeriodType.V1 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_2"), value: PeriodType.V2 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_3"), value: PeriodType.V3 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_4"), value: PeriodType.V4 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_5"), value: PeriodType.V5 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_6"), value: PeriodType.V6 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_7"), value: PeriodType.V7 },
                    ]
                }],
            [CompensationType.V2, {
                    interval: false,
                    numberOfHours: true,
                    workSchedule: false,
                    periods: [
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_1"), value: PeriodType.V1 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_2"), value: PeriodType.V2 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_3"), value: PeriodType.V3 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_4"), value: PeriodType.V4 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_5"), value: PeriodType.V5 },
                    ]
                }],
            [CompensationType.V4, {
                    interval: false,
                    numberOfHours: false,
                    workSchedule: false,
                    periods: [
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_8"), value: PeriodType.V8 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_9"), value: PeriodType.V9 },
                    ]
                }],
            [CompensationType.V5, {
                    interval: true,
                    numberOfHours: false,
                    workSchedule: false,
                    periods: []
                }],
            [CompensationType.V6, {
                    interval: true,
                    numberOfHours: false,
                    workSchedule: true,
                    periods: []
                }]
        ]);
        this.adjustmentReasonIsRequired = false;
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter((/**
             * @param {?} name
             * @return {?}
             */
            name => name === "compensation"))).subscribe((/**
             * @return {?}
             */
            () => {
                this.onSave();
            }));
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((/**
             * @param {?} value
             * @return {?}
             */
            (value) => {
                this.loadLockedEmployee(value);
            }));
        }
        else {
            this.setHotkeys();
        }
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => this.onRouteParamsChange(params)));
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => this.onRouteDataChange(data)));
        this.adjustmentReasonSearchFields = this.getAdjustmentReasonSearchFields();
        this.adjustmentReasonSearchGridFields = this.getAdjustmentReasonSearchGridFields();
        this.workscheduleSearchFields = this.getWorkscheduleSearchFields();
        this.workscheduleSearchGridFields = this.getWorkscheduleSearchGridFields();
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.situationSearchFields = this.getSituationSearchFields();
        this.situationSearchGridFields = this.getSituationSearchGridFields();
        this.setHotkeys();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        this.cacheLimitDaysBackwardScheduling.clear();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    /**
     * @return {?}
     */
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", (/**
         * @return {?}
         */
        () => {
            if (this.permissions.excluir) {
                this.onDelete();
            }
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", (/**
         * @return {?}
         */
        () => {
            if (this.isNew() || this.permissions.editar) {
                this.onSave();
            }
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", (/**
         * @return {?}
         */
        () => {
            this.onCancel();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    /**
     * @return {?}
     */
    isNew() {
        return this.routeParams.compensation === "new";
    }
    /**
     * @param {?} params
     * @return {?}
     */
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.adjustmentReason) {
            value.adjustmentReason.label = this.getSuggestionValue(["code", "name"], "adjustmentReason", value, this.adjustmentReasonLookupSeparator);
            if (value.adjustmentReason.label.trim() === this.adjustmentReasonLookupSeparator.trim()) {
                delete value.adjustmentReason.label;
            }
        }
        if (value.workschedule) {
            value.workschedule.label = this.getSuggestionValue(["code", "name"], "workschedule", value, this.workscheduleLookupSeparator);
            if (value.workschedule.label.trim() === this.workscheduleLookupSeparator.trim()) {
                delete value.workschedule.label;
            }
        }
        if (value.employee) {
            /** @type {?} */
            const contractType = value.employee.employmentRelationship.contractType;
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(contractType);
            value.employee.label = this.getSuggestionValue(["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractTypeLabel"], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.situation) {
            value.situation.label = this.getSuggestionValue(["code", "name"], "situation", value, this.situationLookupSeparator);
            if (value.situation.label.trim() === this.situationLookupSeparator.trim()) {
                delete value.situation.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    /**
     * @param {?} displayFields
     * @param {?} ownerEntity
     * @param {?} value
     * @param {?} separator
     * @return {?}
     */
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((/**
         * @param {?} field
         * @return {?}
         */
        field => this.getProp(value, `${ownerEntity}.${field}`)))
            .reduce((/**
         * @param {?} acc
         * @param {?} val
         * @return {?}
         */
        (acc, val) => `${acc}${separator}${val}`));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.compensation;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity && data.entity[0]) {
            /** @type {?} */
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
            /** @type {?} */
            const value = Compensation.fromDto(data.entity[0]);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
            /** @type {?} */
            const timeEvaluationDefinition = data.entity[1].timeEvaluationDefinition;
            this.controlAdjustmentReason = timeEvaluationDefinition.controlAdjustmentReason;
            this.cacheAdjustmentReasonIsEnable.set(data.entity[1].company.id, timeEvaluationDefinition.controlAdjustmentReason);
            this.mandatoryAdjustmentReasonValidator(this.formGroup);
            this.setCahceLimmitDays(data.entity[1].company.id, timeEvaluationDefinition.limitDaysBackwardScheduling);
        }
        else {
            this.formGroup.patchValue(new Compensation());
            this.mandatoryAdjustmentReasonValidator(this.formGroup);
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    /**
     * @return {?}
     */
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    /**
     * @param {?} filesToDelete
     * @param {?} filesToCommit
     * @return {?}
     */
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /** @type {?} */
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    /**
     * @return {?}
     */
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        })))
            .subscribe((/**
         * @return {?}
         */
        () => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
             * @param {?} err
             * @return {?}
             */
            (err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            })))
                .subscribe((/**
             * @return {?}
             */
            () => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                if (this.lockedEmployee) {
                    this.onClose.next(true);
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            }));
        }));
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    /**
     * @return {?}
     */
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: (/**
             * @return {?}
             */
            () => this.getDeleteObservable()
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe()),
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    /**
     * @param {?} obj
     * @param {?} path
     * @return {?}
     */
    getProp(obj, path) {
        return path.split(".").reduce((/**
         * @param {?} result
         * @param {?} prop
         * @return {?}
         */
        (result, prop) => (result[prop] === undefined ? "" : result[prop])), obj);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onAdjustmentReasonLookupRequest(value) {
        /*{CA:ON_ADJUSTMENT_REASON_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = ["adjustmentReason.code"].map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        let filterQuery = this.getAdjustmentReasonSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" or ");
        /** @type {?} */
        let filters = [`situation eq '${this.selectedSituationId}'`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        /** @type {?} */
        const displayFields = mergeUnique(this.adjustmentReasonLookupDisplayFields, this.adjustmentReasonAdvancedDisplayFields);
        this.adjustmentReasonSituationService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.adjustmentReasonLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.adjustmentReasonLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.adjustmentReasonLookupSuggestions = list.contents;
        }));
        /*{CA:ON_ADJUSTMENT_REASON_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onAdjustmentReasonSearchRequest(event) {
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        let filterQuery = this.getAdjustmentReasonSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" and ");
        /** @type {?} */
        let filters = [`situation eq '${this.selectedSituationId}'`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        this.adjustmentReasonSituationService
            .list({ page, sort, filterQuery })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.adjustmentReasonLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.adjustmentReasonLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.adjustmentReasonSearchGridData = list.contents;
            this.adjustmentReasonSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onWorkscheduleLookupRequest(value) {
        /*{CA:ON_WORKSCHEDULE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_WORKSCHEDULE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.workscheduleLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getWorkscheduleSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" or ");
        // NOSONAR
        /** @type {?} */
        const displayFields = mergeUnique(this.workscheduleLookupDisplayFields, this.workscheduleAdvancedDisplayFields);
        this.workscheduleService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.workscheduleLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.workscheduleLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.workscheduleLookupSuggestions = list.contents;
        }));
        /*{CA:ON_WORKSCHEDULE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_WORKSCHEDULE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onWorkscheduleSearchRequest(event) {
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getWorkscheduleSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            // NOSONAR
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" and ");
        // NOSONAR
        /** @type {?} */
        const displayFields = mergeUnique(this.workscheduleLookupDisplayFields, this.workscheduleAdvancedDisplayFields);
        this.workscheduleService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.workscheduleLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.workscheduleLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.workscheduleSearchGridData = list.contents;
            this.workscheduleSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.employeeLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map((/**
                 * @param {?} enumConstant
                 * @return {?}
                 */
                enumConstant => `${name} eq '${enumConstant}'`)).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        filter => filter !== ''))
            .join(" or ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat('hireDate', 'dismissalDate');
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                }))
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeLookupSuggestions = list.contents;
        }));
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            // NOSONAR
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" and ");
        // NOSONAR
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat('hireDate', 'dismissalDate');
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                }))
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onSituationLookupRequest(value) {
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.situationLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getSituationSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" or ");
        // NOSONAR
        /** @type {?} */
        const displayFields = mergeUnique(this.situationLookupDisplayFields, this.situationAdvancedDisplayFields).concat("situationClockingEvent.mandatoryAdjustmentReason");
        this.situationService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.situationLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.situationLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.situationLookupSuggestions = list.contents;
        }));
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSituationSearchRequest(event) {
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getSituationSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            // NOSONAR
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })) // NOSONAR
            .join(" and ");
        // NOSONAR
        /** @type {?} */
        const displayFields = mergeUnique(this.situationLookupDisplayFields, this.situationAdvancedDisplayFields).concat("situationClockingEvent.mandatoryAdjustmentReason");
        this.situationService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.situationLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                }))
                    .join(this.situationLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.situationSearchGridData = list.contents;
            this.situationSearchTotalRecords = list.totalElements;
        }));
        /*{CA:ON_SITUATION_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getFormGroup() {
        /** @type {?} */
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            intervalStart: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            intervalEnd: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            compensationType: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            periodType: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            numberOfHours: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required, Validators.max(5999), Validators.pattern(/^([0-9]{1,3}):[0-5][0-9]$/)]),
            ],
            situation: [{ value: undefined, disabled: false }, [Validators.compose([Validators.required])]],
            workschedule: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            adjustmentReason: [{ value: undefined, disabled: false }, Validators.compose([])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.validLimitDaysBackwardScheduling(),
                this.startDateIsBeforeOrEqualToEndDate()
            ]
        });
        /*{CA:GET_FORM_CONTROLS:START}*/
        formGroup.controls.employee.valueChanges.subscribe((/**
         * @param {?} employee
         * @return {?}
         */
        employee => {
            if (employee) {
                /** @type {?} */
                let limitDaysBackwardScheduling = this.cacheLimitDaysBackwardScheduling.get(employee.employer.id);
                if (limitDaysBackwardScheduling === undefined) {
                    this.companyClockingEventIndicationsService.get(employee.employer.id).pipe(catchError((/**
                     * @param {?} error
                     * @return {?}
                     */
                    error => {
                        formGroup.controls.employee.setErrors({ 'hasNotCompanyClockingEventIndications': { value: error } });
                        return throwError(error);
                    }))).subscribe((/**
                     * @param {?} companyClockingEventIndications
                     * @return {?}
                     */
                    (companyClockingEventIndications) => {
                        removeErrorFromField(formGroup.controls.employee, 'hasNotCompanyClockingEventIndications');
                        this.controlAdjustmentReason = companyClockingEventIndications.timeEvaluationDefinition.controlAdjustmentReason;
                        this.cacheAdjustmentReasonIsEnable.set(companyClockingEventIndications.id, companyClockingEventIndications.timeEvaluationDefinition.controlAdjustmentReason);
                        this.setCahceLimmitDays(companyClockingEventIndications.id, companyClockingEventIndications.timeEvaluationDefinition.limitDaysBackwardScheduling);
                        this.mandatoryAdjustmentReasonValidator(formGroup);
                    }));
                }
                else {
                    this.mandatoryAdjustmentReasonValidator(formGroup);
                }
            }
            else {
                this.mandatoryAdjustmentReasonValidator(formGroup);
            }
        }));
        formGroup.controls.compensationType.valueChanges.subscribe((/**
         * @param {?} compensationType
         * @return {?}
         */
        compensationType => {
            if (compensationType) {
                this.enableFileds = this.controlOfFormFields.get(compensationType);
                this.enableAndDisableFields(formGroup);
            }
        }));
        formGroup.controls.situation.valueChanges.subscribe((/**
         * @return {?}
         */
        () => this.mandatoryAdjustmentReasonValidator(formGroup)));
        /*{CA:GET_FORM_CONTROLS:END}*/
        return formGroup;
    }
    /**
     * @private
     * @return {?}
     */
    getAdjustmentReasonSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "adjustmentReason.code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.adjustment_reason_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "adjustmentReason.name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.adjustment_reason_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_ADJUSTMENT_REASON_SEARCH_FIELDS:START}*/
        /*{CA:GET_ADJUSTMENT_REASON_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getAdjustmentReasonSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "adjustmentReason.code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.adjustment_reason_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "adjustmentReason.name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.adjustment_reason_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_ADJUSTMENT_REASON_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_ADJUSTMENT_REASON_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    getWorkscheduleSearchFields() {
        // NOSONAR
        /** @type {?} */
        const searchFields = [
            new FormField({
                // NOSONAR
                name: "code",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_code"),
                // NOSONAR
                type: FieldType.Integer,
            }),
            new FormField({
                // NOSONAR
                name: "name",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_name"),
                // NOSONAR
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_WORKSCHEDULE_SEARCH_FIELDS:START}*/
        /*{CA:GET_WORKSCHEDULE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getWorkscheduleSearchGridFields() {
        // NOSONAR
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                // NOSONAR
                name: "code",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_code"),
                // NOSONAR
                type: FieldType.Integer,
            }),
            new FormField({
                // NOSONAR
                name: "name",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_name"),
                // NOSONAR
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_WORKSCHEDULE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_WORKSCHEDULE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    getSituationSearchFields() {
        // NOSONAR
        /** @type {?} */
        const searchFields = [
            new FormField({
                // NOSONAR
                name: "code",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_code"),
                // NOSONAR
                type: FieldType.Integer,
            }),
            new FormField({
                // NOSONAR
                name: "name",
                // NOSONAR
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_name"),
                // NOSONAR
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_SITUATION_SEARCH_FIELDS:START}*/
        /*{CA:GET_SITUATION_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getSituationSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_name"),
                type: FieldType.String,
            }),
            new FormField({
                name: "situationType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_situation_type"),
                type: FieldType.Enum,
                placeholder: this.translate.instant("hcm_clocking_event_foundation.general.situation_situation_type_placeholder"),
                options: [
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_working"), value: "WORKING" },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_vacation"), value: "VACATION" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_illnessaid"),
                        value: "ILLNESSAID",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_laboraccident"),
                        value: "LABORACCIDENT",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_militaryservice"),
                        value: "MILITARYSERVICE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleave"),
                        value: "MATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleavenoncriminalabortion"),
                        value: "MATERNITYLEAVENONCRIMINALABORTION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleaveanticipationextension"),
                        value: "MATERNITYLEAVEANTICIPATIONEXTENSION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_citizencompanymaternity"),
                        value: "CITIZENCOMPANYMATERNITY",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_inssmaternityleave"),
                        value: "INSSMATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_leavewithoutcompensation"),
                        value: "LEAVEWITHOUTCOMPENSATION",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_paidleave"), value: "PAIDLEAVE" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_paternityleave"),
                        value: "PATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_citizencompanypaternity"),
                        value: "CITIZENCOMPANYPATERNITY",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_collectivevacation"),
                        value: "COLLECTIVEVACATION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_medicalleave"),
                        value: "MEDICALLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_medicalleavewithoutinss"),
                        value: "MEDICALLEAVEWITHOUTINSS",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_absences"), value: "ABSENCES" },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_overtime"), value: "OVERTIME" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_timeevaluationsituation"),
                        value: "TIMEEVALUATIONSITUATION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_precautionreadiness"),
                        value: "PRECAUTIONREADINESS",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_tradeunionmandate"),
                        value: "TRADEUNIONMANDATE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_workaccidentleave"),
                        value: "WORKACCIDENTLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_workaccidentleavewithoutinss"),
                        value: "WORKACCIDENTLEAVEWITHOUTINSS",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_retirementduetodisability"),
                        value: "RETIREMENTDUETODISABILITY",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_others"), value: "OTHERS" },
                ],
            }),
        ];
        /*{CA:GET_SITUATION_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_SITUATION_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    goBack() {
        /** @type {?} */
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    /**
     * @private
     * @param {?} formGroup
     * @return {?}
     */
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((/**
         * @param {?} field
         * @return {?}
         */
        field => {
            /** @type {?} */
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        }));
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls['employee'].value;
        value.adjustmentReason = value.adjustmentReason && value.adjustmentReason.adjustmentReason ? value.adjustmentReason.adjustmentReason : value.adjustmentReason;
        /** @type {?} */
        const compensationDto = Compensation.toDto(value);
        /** @type {?} */
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.compensationService.insert(compensationDto);
        }
        else {
            /** @type {?} */
            const id = this.routeParams.compensation;
            observable = this.compensationService.update(id, compensationDto);
        }
        return observable;
    }
    /**
     * @private
     * @return {?}
     */
    getDeleteObservable() {
        return this.compensationService.delete(this.routeParams.compensation).pipe(tap((/**
         * @return {?}
         */
        () => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
            this.goBack(); // NOSONAR
        })) // NOSONAR
        ); // NOSONAR
    } // NOSONAR
    // NOSONAR
    /**
     * @private
     * @return {?}
     */
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        /** @type {?} */
        const toValidate = ["employee", "situation", "workschedule"];
        if (!toValidate.every((/**
         * @param {?} e
         * @return {?}
         */
        e => this.allPermissions[e] && this.allPermissions[e].visualizar))) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((/**
         * @param {?} r
         * @return {?}
         */
        r => r.value === value))[0].label;
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions
                .filter((/**
             * @param {?} r
             * @return {?}
             */
            r => {
                /** @type {?} */
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            }))
                .map((/**
             * @param {?} r
             * @return {?}
             */
            r => r.value));
        }
        return [];
    }
    /**
     * @private
     * @return {?}
     */
    validLimitDaysBackwardScheduling() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const startDate = control.get('startDate');
            /** @type {?} */
            const employee = control.get('employee');
            if (employee.value && startDate.value) {
                /** @type {?} */
                const limitDate = this.cacheLimitDaysBackwardScheduling.get(employee.value.employer.id);
                if (limitDate && moment$j(startDate.value).isBefore(limitDate, 'day')) {
                    startDate.setErrors({ exceededLimit: { value: startDate.value } });
                }
                else {
                    removeErrorFromField(startDate, 'exceededLimit');
                }
            }
            else {
                removeErrorFromField(startDate, 'exceededLimit');
            }
            return null;
        });
    }
    /**
     * @private
     * @return {?}
     */
    startDateIsBeforeOrEqualToEndDate() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const startDateTime = control.get('startDate');
            /** @type {?} */
            const endDateTime = control.get('endDate');
            startDateIsBeforeOrEqualToEndDateValidator(startDateTime, endDateTime);
            return null;
        });
    }
    /**
     * @private
     * @param {?} formGroup
     * @return {?}
     */
    enableAndDisableFields(formGroup) {
        this.enableOrDisableField(this.enableFileds.numberOfHours, formGroup.controls.numberOfHours);
        this.enablePeriods = this.enableFileds.periods;
        if (!this.enablePeriods.some((/**
         * @param {?} period
         * @return {?}
         */
        period => period.value === formGroup.controls.periodType.value))) {
            formGroup.controls.periodType.setValue(null);
        }
        this.enableOrDisableField(this.enablePeriods.length > 0, formGroup.controls.periodType);
        this.enableOrDisableField(this.enableFileds.workSchedule, formGroup.controls.workschedule);
        this.enableOrDisableField(this.enableFileds.interval, formGroup.controls.intervalStart);
        this.enableOrDisableField(this.enableFileds.interval, formGroup.controls.intervalEnd);
    }
    /**
     * @private
     * @param {?} isEnabled
     * @param {?} field
     * @return {?}
     */
    enableOrDisableField(isEnabled, field) {
        if (isEnabled && field.disabled) {
            field.enable();
            field.setErrors({ required: true });
            field.setValidators(Validators.required);
        }
        else if (!isEnabled && field.enabled) {
            field.setValidators(null);
            removeErrorFromField(field, 'required');
            field.setValue(null);
            field.disable();
        }
    }
    /**
     * @param {?} companyId
     * @param {?} limitDays
     * @return {?}
     */
    setCahceLimmitDays(companyId, limitDays) {
        if (limitDays && limitDays > 0) {
            /** @type {?} */
            let limitDate = new Date();
            limitDate.setDate(limitDate.getDate() - limitDays);
            this.cacheLimitDaysBackwardScheduling.set(companyId, limitDate);
        }
        else {
            this.cacheLimitDaysBackwardScheduling.set(companyId, null);
        }
    }
    /**
     * @return {?}
     */
    getAdjustmentReasonInfoSign() {
        return (/** @type {?} */ (this.translate.instant('hcm_clocking_event_foundation.general.compensation_adjustment_reason_info_sign')));
    }
    /**
     * Verifica na definição de apuração se é utilizado e depois se é obrigatório na especialização do ponto da situação.
     *
     * @private
     * @param {?} formGroup Formulario
     * @return {?}
     */
    mandatoryAdjustmentReasonValidator(formGroup) {
        /** @type {?} */
        const adjustmentReason = formGroup.controls['adjustmentReason'];
        /** @type {?} */
        const employee = this.formGroup.controls['employee'];
        /** @type {?} */
        const situation = formGroup.controls['situation'];
        if (this.controlAdjustmentReason) {
            if (situation.value && situation.value.situationClockingEvent) {
                if (employee.value) {
                    this.enableAdjustmentReason(situation, adjustmentReason);
                }
                removeErrorFromField(situation, 'hasNotSituationClockingEvent');
            }
            else {
                adjustmentReason.disable();
                adjustmentReason.setValue(null);
                situation.setErrors({ 'hasNotSituationClockingEvent': true });
            }
        }
        else {
            adjustmentReason.disable();
            adjustmentReason.setValue(null);
        }
    }
    /**
     * @private
     * @param {?} situation
     * @param {?} adjustmentReason
     * @return {?}
     */
    enableAdjustmentReason(situation, adjustmentReason) {
        adjustmentReason.enable();
        this.selectedSituationId = situation.value.id;
        if (situation.value.situationClockingEvent.mandatoryAdjustmentReason) {
            adjustmentReason.setValidators(Validators.required);
            adjustmentReason.updateValueAndValidity();
            this.adjustmentReasonIsRequired = true;
        }
        else {
            adjustmentReason.clearValidators();
            adjustmentReason.updateValueAndValidity();
            this.adjustmentReasonIsRequired = false;
        }
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLockedEmployee(value) {
        /** @type {?} */
        const employee = this.formGroup.controls["employee"].value;
        this.formGroup.reset();
        this.formGroup.controls["employee"].setValue(employee);
        if (this.formGroup.controls["employee"].value) {
            this.formGroup.controls["startDate"].setValue(moment$j(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((/**
             * @param {?} dto
             * @return {?}
             */
            (dto) => {
                this.onLoadFormSubject.next(false);
                /** @type {?} */
                const workScheduleChange = new WorkScheduleChange();
                workScheduleChange.date = moment$j(value.evaluationDate).toDate();
                workScheduleChange.employee = Employee.fromDto(dto.contents[0], "WorkScheduleChange");
                this.updateSuggestions(workScheduleChange);
                this.formGroup.patchValue(workScheduleChange);
                this.formGroup.controls["employee"].disable();
                this.loading = false;
            }));
        }
    }
    /*{CA:CLASS_METHODS:END}*/
    /**
     * @private
     * @param {?} severity
     * @param {?} summary
     * @param {?} detail
     * @return {?}
     */
    addMessage(severity, summary, detail) {
        this.messageService.add({
            severity,
            summary: this.translate.instant(summary),
            detail: this.translate.instant(detail),
        });
    }
}
CompensationFormComponent.decorators = [
    { type: Component, args: [{
                template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel\n            *sLoadingState=\"loading\" \n            [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\" \n            [toggleable]=\"false\" \n            [collapsed]=\"mainPanelCollapsed\" \n            [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.compensation_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6 ui-xl-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.compensation_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-12 ui-lg-12 ui-xl-4 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.compensation_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.compensation_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\" [errorMessages]=\"{ \n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            hasNotCompanyClockingEventIndications: 'hcm_clocking_event_foundation.general.error_missing_company_clocking_event_indications' | translate\n                        }\"></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-12 ui-lg-12 ui-xl-4 required\">\n                        <label for=\"compensationType\">{{\"hcm_clocking_event_foundation.general.compensation_compensation_type\" | translate}}</label>\n                        <p-dropdown inputId=\"compensationType\" name=\"compensationType\" [options]=\"compensationType\" formControlName=\"compensationType\"\n                            [autoWidth]=\"false\" placeholder=\"{{'hcm_clocking_event_foundation.general.compensation_compensation_type_placeholder' | translate}}\"></p-dropdown>\n                        <s-control-errors [control]=\"formGroup.controls['compensationType']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div [ngClass]=\"enableFileds.periods.length > 0 ? 'ui-g-12 ui-md-12 ui-lg-12 ui-xl-4 required' : 'ui-g-12 ui-md-12 ui-lg-12 ui-xl-4'\">\n                        <label for=\"periodType\">{{\"hcm_clocking_event_foundation.general.compensation_period_type\" | translate}}</label>\n                        <p-dropdown inputId=\"periodType\" name=\"periodType\" [options]=\"enablePeriods\" formControlName=\"periodType\"\n                            [autoWidth]=\"false\" placeholder=\"{{'hcm_clocking_event_foundation.general.compensation_period_type_placeholder' | translate}}\"></p-dropdown>\n                        <s-control-errors [control]=\"formGroup.controls['periodType']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 ui-lg-6 ui-xl-3 required\">\n                        <label for=\"startDate\">{{\"hcm_clocking_event_foundation.general.compensation_start_date\" | translate}}</label>\n                        <p-calendar #startDateFormInput inputId=\"startDate\" name=\"startDate\" [showIcon]=\"true\" formControlName=\"startDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDate']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_start_date_after_end_date' | translate,\n                                exceededLimit: 'hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling' | translate\n                            }\">\n                        </s-control-errors>                    \n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 ui-lg-6 ui-xl-3 required\">\n                        <label for=\"endDate\">{{\"hcm_clocking_event_foundation.general.compensation_end_date\" | translate}}</label>\n                        <p-calendar #endDateFormInput inputId=\"endDate\" name=\"endDate\" [showIcon]=\"true\" formControlName=\"endDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                            <s-control-errors [control]=\"formGroup.controls['endDate']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_end_date_before_start_date' | translate\n                            }\">\n                        </s-control-errors>\n                    </div>\n                    <div [ngClass]=\"enableFileds.interval ? 'ui-g-12 ui-md-6 ui-lg-6 ui-xl-3 required' : 'ui-g-12 ui-md-6 ui-lg-6'\" class=\"ui-g-12 ui-md-6 ui-lg-6 ui-xl-3\">\n                        <label for=\"intervalStart\">{{\"hcm_clocking_event_foundation.general.compensation_interval_start\" | translate}}</label>\n                        <p-calendar #intervalStartFormInput inputId=\"intervalStart\" name=\"intervalStart\" [showIcon]=\"true\" [timeOnly]=\"true\"\n                            [showSeconds]=\"false\" icon=\"fa fa-clock-o\" formControlName=\"intervalStart\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['intervalStart']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div [ngClass]=\"enableFileds.interval ? 'ui-g-12 ui-md-6 ui-lg-6 ui-xl-3 required' : 'ui-g-12 ui-md-6 ui-lg-6 ui-xl-3'\">\n                        <label for=\"intervalEnd\">{{\"hcm_clocking_event_foundation.general.compensation_interval_end\" | translate}}</label>\n                        <p-calendar #intervalEndFormInput inputId=\"intervalEnd\" name=\"intervalEnd\" [showIcon]=\"true\" [timeOnly]=\"true\"\n                            [showSeconds]=\"false\" icon=\"fa fa-clock-o\" formControlName=\"intervalEnd\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['intervalEnd']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div [ngClass]=\"enableFileds.numberOfHours ? 'ui-g-12 ui-md-12 ui-lg-6 required' : 'ui-g-12 ui-md-12 ui-lg-6'\">\n                        <label for=\"numberOfHours\">{{\"hcm_clocking_event_foundation.general.compensation_number_of_hours\" | translate}}</label>\n                        <p-inputMask\n                            #numberOfHoursFormInput\n                            id=\"numberOfHours\"\n                            name=\"numberOfHours\"\n                            formControlName=\"numberOfHours\"\n                            mask=\"99:99\"\n                            placeholder=\"hh:mm\"\n                        ></p-inputMask>\n                        <s-control-errors [control]=\"formGroup.controls['numberOfHours']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate, \n                                pattern: 'hcm_clocking_event_foundation.general.error_invalid' | translate \n                            }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.situation.visualizar\" class=\"ui-g-12 ui-md-12 ui-lg-6 required\">\n                        <label for=\"situation\">{{\"hcm_clocking_event_foundation.general.compensation_situation\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"situation\" name=\"situation\" formControlName=\"situation\" [searchFields]=\"situationSearchFields\"\n                            [searchGridFields]=\"situationSearchGridFields\" [searchGridData]=\"situationSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"situationLookupSuggestions\" (onLookupRequest)=\"onSituationLookupRequest($event)\"\n                            (onSearchRequest)=\"onSituationSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=situationSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.compensation_situation_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: situationSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['situation']\" [errorMessages]=\"{ \n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            hasNotSituationClockingEvent: 'hcm_clocking_event_foundation.general.situation_has_no_situation_clocking_event' | translate \n                        }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.adjustmentReason.visualizar\" class=\"ui-g-12 ui-md-12 ui-lg-6\" [ngClass]=\"adjustmentReasonIsRequired ? 'required' : ''\">\n                        <label for=\"adjustmentReason\">{{\"hcm_clocking_event_foundation.general.compensation_adjustment_reason\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"adjustmentReason\" name=\"adjustmentReason\" formControlName=\"adjustmentReason\"\n                            [searchFields]=\"adjustmentReasonSearchFields\" [searchGridFields]=\"adjustmentReasonSearchGridFields\"\n                            [searchGridData]=\"adjustmentReasonSearchGridData\" [multiple]=\"false\" [lookupSuggestions]=\"adjustmentReasonLookupSuggestions\"\n                            (onLookupRequest)=\"onAdjustmentReasonLookupRequest($event)\" (onSearchRequest)=\"onAdjustmentReasonSearchRequest($event)\"\n                            lookupDisplayField=\"label\" [searchTotalRecords]=adjustmentReasonSearchTotalRecords\n                            [searchTitle]=\"'hcm_clocking_event_foundation.general.compensation_adjustment_reason_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: adjustmentReasonSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                            <s-control-errors [control]=\"formGroup.controls['adjustmentReason']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.workschedule.visualizar\" [ngClass]=\"enableFileds.workSchedule ? 'ui-g-12 ui-md-12 ui-lg-6 required' : 'ui-g-12 ui-md-12 ui-lg-6'\">\n                        <label for=\"workschedule\">{{\"hcm_clocking_event_foundation.general.compensation_workschedule\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"workschedule\" name=\"workschedule\" formControlName=\"workschedule\" [searchFields]=\"workscheduleSearchFields\"\n                            [searchGridFields]=\"workscheduleSearchGridFields\" [searchGridData]=\"workscheduleSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"workscheduleLookupSuggestions\" (onLookupRequest)=\"onWorkscheduleLookupRequest($event)\"\n                            (onSearchRequest)=\"onWorkscheduleSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=workscheduleSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.compensation_workschedule_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: workscheduleSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['workschedule']\" \n                            [errorMessages]=\"{ \n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"compensation\" formControlName=\"custom\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->",
                selector: "cem-compensation-form",
                providers: [
                    ConfirmationService,
                ],
                styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
            }] }
];
/** @nocollapse */
CompensationFormComponent.ctorParameters = () => [
    { type: CompanyClockingEventIndicationsService },
    { type: CompensationService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: AdjustmentReasonSituationService },
    { type: WorkscheduleService },
    { type: EmployeeService },
    { type: SituationService },
    { type: SituationClockingEventService }
];
CompensationFormComponent.propDecorators = {
    customTemplate: [{ type: ViewChild, args: ["customTemplate", { static: false },] }],
    customFormFields: [{ type: ViewChild, args: ["customFormFields", { static: false },] }],
    onSubmitObservable: [{ type: Input }],
    onLockedEmployeeChanges: [{ type: Input }],
    lockedEmployee: [{ type: Input }],
    onCloseObservable: [{ type: Output }],
    onLoadForm: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    CompensationFormComponent.prototype.localeConfig;
    /** @type {?} */
    CompensationFormComponent.prototype.currencyLocaleOptions;
    /** @type {?} */
    CompensationFormComponent.prototype.permissions;
    /** @type {?} */
    CompensationFormComponent.prototype.allPermissions;
    /** @type {?} */
    CompensationFormComponent.prototype.formGroup;
    /** @type {?} */
    CompensationFormComponent.prototype.loading;
    /** @type {?} */
    CompensationFormComponent.prototype.mainPanelCollapsed;
    /** @type {?} */
    CompensationFormComponent.prototype.compensationType;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonLookupSuggestions;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonLookupDisplayFields;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonAdvancedDisplayFields;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonLookupSeparator;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonSearchFields;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonSearchGridFields;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonSearchGridData;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonSearchTotalRecords;
    /** @type {?} */
    CompensationFormComponent.prototype.workscheduleLookupSuggestions;
    /** @type {?} */
    CompensationFormComponent.prototype.workscheduleLookupDisplayFields;
    /** @type {?} */
    CompensationFormComponent.prototype.workscheduleAdvancedDisplayFields;
    /** @type {?} */
    CompensationFormComponent.prototype.workscheduleLookupSeparator;
    /** @type {?} */
    CompensationFormComponent.prototype.workscheduleSearchFields;
    /** @type {?} */
    CompensationFormComponent.prototype.workscheduleSearchGridFields;
    /** @type {?} */
    CompensationFormComponent.prototype.workscheduleSearchGridData;
    /** @type {?} */
    CompensationFormComponent.prototype.workscheduleSearchTotalRecords;
    /** @type {?} */
    CompensationFormComponent.prototype.contractTypeOptions;
    /** @type {?} */
    CompensationFormComponent.prototype.employeeLookupSuggestions;
    /** @type {?} */
    CompensationFormComponent.prototype.employeeLookupDisplayFields;
    /** @type {?} */
    CompensationFormComponent.prototype.employeeAdvancedDisplayFields;
    /** @type {?} */
    CompensationFormComponent.prototype.employeeLookupSeparator;
    /** @type {?} */
    CompensationFormComponent.prototype.employeeSearchFields;
    /** @type {?} */
    CompensationFormComponent.prototype.employeeSearchGridFields;
    /** @type {?} */
    CompensationFormComponent.prototype.employeeSearchGridData;
    /** @type {?} */
    CompensationFormComponent.prototype.employeeSearchTotalRecords;
    /** @type {?} */
    CompensationFormComponent.prototype.situationLookupSuggestions;
    /** @type {?} */
    CompensationFormComponent.prototype.situationLookupDisplayFields;
    /** @type {?} */
    CompensationFormComponent.prototype.situationAdvancedDisplayFields;
    /** @type {?} */
    CompensationFormComponent.prototype.situationLookupSeparator;
    /** @type {?} */
    CompensationFormComponent.prototype.situationSearchFields;
    /** @type {?} */
    CompensationFormComponent.prototype.situationSearchGridFields;
    /** @type {?} */
    CompensationFormComponent.prototype.situationSearchGridData;
    /** @type {?} */
    CompensationFormComponent.prototype.situationSearchTotalRecords;
    /** @type {?} */
    CompensationFormComponent.prototype.customTemplate;
    /** @type {?} */
    CompensationFormComponent.prototype.customFormFields;
    /** @type {?} */
    CompensationFormComponent.prototype.onSubmitObservable;
    /** @type {?} */
    CompensationFormComponent.prototype.onLockedEmployeeChanges;
    /** @type {?} */
    CompensationFormComponent.prototype.lockedEmployee;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.onClose;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.onLoadFormSubject;
    /** @type {?} */
    CompensationFormComponent.prototype.onCloseObservable;
    /** @type {?} */
    CompensationFormComponent.prototype.onLoadForm;
    /** @type {?} */
    CompensationFormComponent.prototype.selectedSituationId;
    /** @type {?} */
    CompensationFormComponent.prototype.controlAdjustmentReason;
    /** @type {?} */
    CompensationFormComponent.prototype.mandatoryAdjustmentReasonBySituation;
    /** @type {?} */
    CompensationFormComponent.prototype.mandatoryAdjustmentReason;
    /** @type {?} */
    CompensationFormComponent.prototype.cacheAdjustmentReasonIsEnable;
    /** @type {?} */
    CompensationFormComponent.prototype.cacheLimitDaysBackwardScheduling;
    /** @type {?} */
    CompensationFormComponent.prototype.enablePeriods;
    /** @type {?} */
    CompensationFormComponent.prototype.enableFileds;
    /** @type {?} */
    CompensationFormComponent.prototype.controlOfFormFields;
    /** @type {?} */
    CompensationFormComponent.prototype.adjustmentReasonIsRequired;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.routeParams;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.ngUnsubscribe;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.companyClockingEventIndicationsService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.compensationService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.router;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.route;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.messageService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.confirmationService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.formBuilder;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.translate;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.hotkeysService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.fieldCustomization;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.focusService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.adjustmentReasonSituationService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.workscheduleService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.employeeService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.situationService;
    /**
     * @type {?}
     * @private
     */
    CompensationFormComponent.prototype.situationClockingEventService;
}
/**
 * @record
 */
function CompensationValidationFields() { }
if (false) {
    /** @type {?} */
    CompensationValidationFields.prototype.interval;
    /** @type {?} */
    CompensationValidationFields.prototype.numberOfHours;
    /** @type {?} */
    CompensationValidationFields.prototype.workSchedule;
    /** @type {?} */
    CompensationValidationFields.prototype.periods;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/compensation/compensation-form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CompensationFormModule {
}
CompensationFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    LocaleModule.forChild(),
                    SharedScheduleModule,
                    DropdownModule,
                    InfoSignModule,
                    InputMaskModule
                ],
                declarations: [
                    CompensationFormComponent
                ],
                exports: [
                    CompensationFormComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/dtos/employee-date.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function EmployeeDate() { }
if (false) {
    /** @type {?} */
    EmployeeDate.prototype.evaluationDate;
    /** @type {?} */
    EmployeeDate.prototype.employeeId;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason-situation/adjustment-reason-situation.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class AdjustmentReasonSituationModule {
}
AdjustmentReasonSituationModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "adjustmentReasonSituation",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/adjustmentReasonSituation`,
                        },
                    ]),
                ],
                providers: [
                    AdjustmentReasonSituationService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason/adjustment-reason.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class AdjustmentReasonService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/adjustmentReason`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    /**
     * @param {?} situationId
     * @return {?}
     */
    listAdjustmentReasonsBySituation(situationId) {
        /** @type {?} */
        const url = "hcm_clocking_event_foundation/general/queries/getAllAdjustmentReasonsBySituation";
        return this.http
            .post(url, situationId)
            .pipe(this.defaultCatch());
    }
}
AdjustmentReasonService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AdjustmentReasonService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    AdjustmentReasonService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    AdjustmentReasonService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    AdjustmentReasonService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason/adjustment-reason.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class AdjustmentReasonModule {
}
AdjustmentReasonModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "adjustmentReason",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/adjustmentReason`,
                        },
                    ]),
                ],
                providers: [
                    AdjustmentReasonService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/bridge.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BridgeModule {
}
BridgeModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "bridge",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/bridge`,
                        },
                    ]),
                ],
                providers: [
                    BridgeService
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/company-clocking-event-indications.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class CompanyClockingEventIndicationsModule {
}
CompanyClockingEventIndicationsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "companyClockingEventIndications",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/companyClockingEventIndications`,
                        },
                    ]),
                ],
                providers: [
                    CompanyClockingEventIndicationsService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/compensation/compensation.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class CompensationModule {
}
CompensationModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "compensation",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/compensation`,
                        },
                    ]),
                ],
                providers: [
                    CompensationService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/e-001-pes.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E001PesService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `erpx_fnd/pessoa/entities/e001pes`, `erpx_fnd/pessoa/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    listExternalE001Pes(listParams) {
        return this.http
            .get("erpx_fnd/pessoa/entities/e001pes", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
}
E001PesService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
E001PesService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    E001PesService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    E001PesService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    E001PesService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/e-001-pes.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class E001PesModule {
}
E001PesModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "e001pes",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/erpx_fnd/pessoa/entities/e001pes`,
                        },
                    ]),
                ],
                providers: [
                    E001PesService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/employee.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class EmployeeModule {
}
EmployeeModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "employee",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_contract/employment_contract/entities/employee`,
                        },
                    ]),
                ],
                providers: [
                    EmployeeService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/overtime-authorization/overtime-authorization.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OvertimeAuthorizationModule {
}
OvertimeAuthorizationModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "overtimeAuthorization",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/overtimeAuthorization`,
                        },
                    ]),
                ],
                providers: [
                    OvertimeAuthorizationService,
                ],
                declarations: [],
                exports: [],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/readiness/readiness.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class ReadinessModule {
}
ReadinessModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "readiness",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/readiness`,
                        },
                    ]),
                ],
                providers: [
                    ReadinessService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/situation-clocking-event.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SituationClockingEventModule {
}
SituationClockingEventModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "situationClockingEvent",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/situationClockingEvent`,
                        },
                    ]),
                ],
                providers: [
                    SituationClockingEventService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/situation.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SituationModule {
}
SituationModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "situation",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_foundation/general/entities/situation`,
                        },
                    ]),
                ],
                providers: [
                    SituationService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/time-evaluation-definition.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationDefinitionService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationDefinition`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
TimeEvaluationDefinitionService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TimeEvaluationDefinitionService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationDefinitionService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationDefinitionService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationDefinitionService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/time-evaluation-definition.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationDefinitionModule {
}
TimeEvaluationDefinitionModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "timeEvaluationDefinition",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationDefinition`,
                        },
                    ]),
                ],
                providers: [
                    TimeEvaluationDefinitionService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/time-evaluation-situation-definition-history.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionHistoryService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
TimeEvaluationSituationDefinitionHistoryService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TimeEvaluationSituationDefinitionHistoryService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionHistoryService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionHistoryService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionHistoryService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/time-evaluation-situation-definition-history.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionHistoryModule {
}
TimeEvaluationSituationDefinitionHistoryModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "timeEvaluationSituationDefinitionHistory",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`,
                        },
                    ]),
                ],
                providers: [
                    TimeEvaluationSituationDefinitionHistoryService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/time-evaluation-situation-definition.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinition`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} id
     * @return {?}
     */
    getTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id) {
        return this.http
            .get(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`)
            .pipe(this.defaultCatch());
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} id
     * @param {?} timeEvaluationSituationDefinitionHistoryDto
     * @return {?}
     */
    updateTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id, timeEvaluationSituationDefinitionHistoryDto) {
        return this.http
            .put(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`, timeEvaluationSituationDefinitionHistoryDto)
            .pipe(this.defaultCatch());
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} listParams
     * @return {?}
     */
    listTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, listParams) {
        return this.http
            .get(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, { params: this.getListQueryParams(listParams) })
            .pipe(this.defaultCatch());
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} timeEvaluationSituationDefinitionHistoryDto
     * @return {?}
     */
    insertTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, timeEvaluationSituationDefinitionHistoryDto) {
        return this.http
            .post(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, timeEvaluationSituationDefinitionHistoryDto)
            .pipe(this.defaultCatch());
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} id
     * @return {?}
     */
    deleteTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id) {
        return this.http
            .delete(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`)
            .pipe(this.defaultCatch());
    }
}
TimeEvaluationSituationDefinitionService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TimeEvaluationSituationDefinitionService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/time-evaluation-situation-definition.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionModule {
}
TimeEvaluationSituationDefinitionModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "timeEvaluationSituationDefinition",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinition`,
                        },
                    ]),
                ],
                providers: [
                    TimeEvaluationSituationDefinitionService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/work-schedule-change/work-schedule-change.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkScheduleChangeModule {
}
WorkScheduleChangeModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "workScheduleChange",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/workScheduleChange`,
                        },
                    ]),
                ],
                providers: [
                    WorkScheduleChangeService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workschedule/workschedule.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkscheduleModule {
}
WorkscheduleModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "workschedule",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_foundation/work_schedule/entities/workschedule`,
                        },
                    ]),
                ],
                providers: [
                    WorkscheduleService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-change/workshift-change.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftChangeModule {
}
WorkshiftChangeModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "workshiftChange",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/workshiftChange`,
                        },
                    ]),
                ],
                providers: [
                    WorkshiftChangeService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-group/workshift-group.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftGroupModule {
}
WorkshiftGroupModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "workshiftGroup",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_foundation/work_schedule/entities/workshiftGroup`,
                        },
                    ]),
                ],
                providers: [
                    WorkshiftGroupService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift/workshift.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftModule {
}
WorkshiftModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "workshift",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_foundation/work_schedule/entities/workshift`,
                        },
                    ]),
                ],
                providers: [
                    WorkshiftService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/core-schedules.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CoreSchedulesHistoriesModule {
}
CoreSchedulesHistoriesModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    BridgeModule,
                    OvertimeAuthorizationModule,
                    EmployeeModule,
                    E001PesModule,
                    CompanyClockingEventIndicationsModule,
                    TimeEvaluationDefinitionModule,
                    SituationModule,
                    TimeEvaluationSituationDefinitionModule,
                    TimeEvaluationSituationDefinitionHistoryModule,
                    SituationClockingEventModule,
                    WorkscheduleModule,
                    WorkScheduleChangeModule,
                    ReadinessModule,
                    WorkshiftChangeModule,
                    WorkshiftGroupModule,
                    WorkshiftModule,
                    CompensationModule,
                    AdjustmentReasonModule,
                    AdjustmentReasonSituationModule
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/bridge-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function BridgeDto() { }
if (false) {
    /** @type {?|undefined} */
    BridgeDto.prototype.id;
    /** @type {?} */
    BridgeDto.prototype.employee;
    /** @type {?} */
    BridgeDto.prototype.originDate;
    /** @type {?} */
    BridgeDto.prototype.destinationDate;
    /** @type {?|undefined} */
    BridgeDto.prototype.createdBy;
    /** @type {?|undefined} */
    BridgeDto.prototype.createdDate;
    /** @type {?|undefined} */
    BridgeDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    BridgeDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    BridgeDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/time-evaluation-definition.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/** @type {?} */
const moment$k = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationDefinition {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} timeEvaluationDefinitionDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(timeEvaluationDefinitionDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, timeEvaluationDefinitionDto);
        model.createdDate = model.createdDate && moment$k(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$k(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["code", "name"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Situation" && model.incompleteJourneySituation)
            model.incompleteJourneySituation = Situation.fromDto(model.incompleteJourneySituation, "TimeEvaluationDefinition");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} timeEvaluationDefinition
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(timeEvaluationDefinition, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, timeEvaluationDefinition);
        dto.createdDate = dto.createdDate && moment$k(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$k(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Situation" && dto.incompleteJourneySituation)
            dto.incompleteJourneySituation = Situation.toDto(dto.incompleteJourneySituation, "TimeEvaluationDefinition");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    TimeEvaluationDefinition.prototype.id;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.code;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.name;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.useWorkscheduleDayOff;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.verifiedDaysControl;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.controlAdjustmentReason;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.controlObservation;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.daysResume;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.clockingEventTolerance;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.retroactiveAdjustment;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.evaluateIncompleteJourney;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.incompleteJourneySituation;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.numberOfDaysAdjustment;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.calculateHolidayAbsenceRotationWorkshift;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.considerClockingEventInterval;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.clockingEventInterval;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.schedulingOverlapsHoliday;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.limitDaysBackwardScheduling;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.bridgeOverlapsWorkscheduleChange;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.allowClockingEventModificationBeforeTransference;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.calculateReadiness;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.discountHoursWorkedReadiness;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.expirationDays;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.limitOfDaysAfterPointClosing;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.blockPendingAfterExpires;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.allowsTakeLedgerPending;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.allowsCompleteUntreatedPending;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.createdBy;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.createdDate;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.lastModifiedBy;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.lastModifiedDate;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/time-evaluation-situation-definition.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$l = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PACKAGE_IMPORTS:END}*/
class TimeEvaluationSituationDefinition {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} timeEvaluationSituationDefinitionDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(timeEvaluationSituationDefinitionDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, timeEvaluationSituationDefinitionDto);
        model.createdDate = model.createdDate && moment$l(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$l(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["code", "name"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} timeEvaluationSituationDefinition
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(timeEvaluationSituationDefinition, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, timeEvaluationSituationDefinition);
        dto.createdDate = dto.createdDate && moment$l(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$l(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.id;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.code;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.name;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.createdBy;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.createdDate;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.lastModifiedBy;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.lastModifiedDate;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/company-clocking-event-indications.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$m = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class CompanyClockingEventIndications {
    /**
     * @param {?} companyClockingEventIndicationsDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(companyClockingEventIndicationsDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, companyClockingEventIndicationsDto);
        model.createdDate = model.createdDate && moment$m(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$m(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "timeEvaluationDefinition.code",
            "timeEvaluationDefinition.name",
            "timeEvaluationSituationDefinition.code",
            "timeEvaluationSituationDefinition.name",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "TimeEvaluationDefinition" && model.timeEvaluationDefinition)
            model.timeEvaluationDefinition = TimeEvaluationDefinition.fromDto(model.timeEvaluationDefinition, "CompanyClockingEventIndications");
        if (originEntity !== "TimeEvaluationSituationDefinition" && model.timeEvaluationSituationDefinition)
            model.timeEvaluationSituationDefinition = TimeEvaluationSituationDefinition.fromDto(model.timeEvaluationSituationDefinition, "CompanyClockingEventIndications");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} companyClockingEventIndications
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(companyClockingEventIndications, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, companyClockingEventIndications);
        dto.createdDate = dto.createdDate && moment$m(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$m(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "TimeEvaluationDefinition" && dto.timeEvaluationDefinition)
            dto.timeEvaluationDefinition = TimeEvaluationDefinition.toDto(dto.timeEvaluationDefinition, "CompanyClockingEventIndications");
        if (originEntity !== "TimeEvaluationSituationDefinition" && dto.timeEvaluationSituationDefinition)
            dto.timeEvaluationSituationDefinition = TimeEvaluationSituationDefinition.toDto(dto.timeEvaluationSituationDefinition, "CompanyClockingEventIndications");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    CompanyClockingEventIndications.prototype.id;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.timeEvaluationDefinition;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.timeEvaluationSituationDefinition;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.createdBy;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.createdDate;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.lastModifiedBy;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.lastModifiedDate;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/company-clocking-event-indications-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function CompanyClockingEventIndicationsDto() { }
if (false) {
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.id;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.company;
    /** @type {?} */
    CompanyClockingEventIndicationsDto.prototype.timeEvaluationDefinition;
    /** @type {?} */
    CompanyClockingEventIndicationsDto.prototype.timeEvaluationSituationDefinition;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.createdBy;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.createdDate;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/e-001-pes-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function E001PesDto() { }
if (false) {
    /** @type {?|undefined} */
    E001PesDto.prototype.id;
    /** @type {?} */
    E001PesDto.prototype.nomPes;
    /** @type {?|undefined} */
    E001PesDto.prototype.excluido;
    /** @type {?|undefined} */
    E001PesDto.prototype.extIntSts;
    /** @type {?|undefined} */
    E001PesDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    E001PesDto.prototype.createdBy;
    /** @type {?|undefined} */
    E001PesDto.prototype.createdDate;
    /** @type {?|undefined} */
    E001PesDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    E001PesDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    E001PesDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/time-evaluation-definition-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function TimeEvaluationDefinitionDto() { }
if (false) {
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.id;
    /** @type {?} */
    TimeEvaluationDefinitionDto.prototype.code;
    /** @type {?} */
    TimeEvaluationDefinitionDto.prototype.name;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.useWorkscheduleDayOff;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.verifiedDaysControl;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.controlAdjustmentReason;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.controlObservation;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.daysResume;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.clockingEventTolerance;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.retroactiveAdjustment;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.evaluateIncompleteJourney;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.incompleteJourneySituation;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.numberOfDaysAdjustment;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.calculateHolidayAbsenceRotationWorkshift;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.considerClockingEventInterval;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.clockingEventInterval;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.schedulingOverlapsHoliday;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.limitDaysBackwardScheduling;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.bridgeOverlapsWorkscheduleChange;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.allowClockingEventModificationBeforeTransference;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.calculateReadiness;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.discountHoursWorkedReadiness;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.expirationDays;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.limitOfDaysAfterPointClosing;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.blockPendingAfterExpires;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.allowsTakeLedgerPending;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.allowsCompleteUntreatedPending;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.createdBy;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.createdDate;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/time-evaluation-situation-definition-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function TimeEvaluationSituationDefinitionDto() { }
if (false) {
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.id;
    /** @type {?} */
    TimeEvaluationSituationDefinitionDto.prototype.code;
    /** @type {?} */
    TimeEvaluationSituationDefinitionDto.prototype.name;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.createdBy;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.createdDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/readiness/readiness-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function ReadinessDto() { }
if (false) {
    /** @type {?|undefined} */
    ReadinessDto.prototype.id;
    /** @type {?} */
    ReadinessDto.prototype.employee;
    /** @type {?} */
    ReadinessDto.prototype.startDateTime;
    /** @type {?} */
    ReadinessDto.prototype.endDateTime;
    /** @type {?} */
    ReadinessDto.prototype.situation;
    /** @type {?|undefined} */
    ReadinessDto.prototype.observation;
    /** @type {?|undefined} */
    ReadinessDto.prototype.continuous;
    /** @type {?|undefined} */
    ReadinessDto.prototype.createdBy;
    /** @type {?|undefined} */
    ReadinessDto.prototype.createdDate;
    /** @type {?|undefined} */
    ReadinessDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    ReadinessDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    ReadinessDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/readiness/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/situation-clocking-event.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/** @type {?} */
const moment$n = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class SituationClockingEvent {
    constructor() {
        this.daytimeSituation = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} situationClockingEventDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(situationClockingEventDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, situationClockingEventDto);
        model.createdDate = model.createdDate && moment$n(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$n(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "complementarySituation.code",
            "complementarySituation.name",
            "exceptionSituation",
            "mandatoryAdjustmentReason",
            "daytimeSituation",
            "convertNightHours",
            "obligateAttachmentOnLeave",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Situation" && model.situation)
            model.situation = Situation.fromDto(model.situation, "SituationClockingEvent");
        if (originEntity !== "Situation" && model.complementarySituation)
            model.complementarySituation = Situation.fromDto(model.complementarySituation, "SituationClockingEvent");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} situationClockingEvent
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(situationClockingEvent, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, situationClockingEvent);
        dto.createdDate = dto.createdDate && moment$n(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$n(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Situation" && dto.situation)
            dto.situation = Situation.toDto(dto.situation, "SituationClockingEvent");
        if (originEntity !== "Situation" && dto.complementarySituation)
            dto.complementarySituation = Situation.toDto(dto.complementarySituation, "SituationClockingEvent");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    SituationClockingEvent.prototype.id;
    /** @type {?} */
    SituationClockingEvent.prototype.situation;
    /** @type {?} */
    SituationClockingEvent.prototype.complementarySituation;
    /** @type {?} */
    SituationClockingEvent.prototype.exceptionSituation;
    /** @type {?} */
    SituationClockingEvent.prototype.mandatoryAdjustmentReason;
    /** @type {?} */
    SituationClockingEvent.prototype.daytimeSituation;
    /** @type {?} */
    SituationClockingEvent.prototype.convertNightHours;
    /** @type {?} */
    SituationClockingEvent.prototype.obligateAttachmentOnLeave;
    /** @type {?} */
    SituationClockingEvent.prototype.createdBy;
    /** @type {?} */
    SituationClockingEvent.prototype.createdDate;
    /** @type {?} */
    SituationClockingEvent.prototype.lastModifiedBy;
    /** @type {?} */
    SituationClockingEvent.prototype.lastModifiedDate;
    /** @type {?} */
    SituationClockingEvent.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/time-evaluation-situation-definition-history.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$o = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionHistory {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} timeEvaluationSituationDefinitionHistoryDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(timeEvaluationSituationDefinitionHistoryDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, timeEvaluationSituationDefinitionHistoryDto);
        model.startDate = model.startDate && moment$o(model.startDate).toDate();
        model.endDate = model.endDate && moment$o(model.endDate).toDate();
        model.createdDate = model.createdDate && moment$o(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$o(model.lastModifiedDate).toDate();
        if (model.normalOvertimeSeparationLimit && model.normalOvertimeSeparationLimit !== undefined) {
            model.normalOvertimeSeparationLimit = convertMinutesToTime(model.normalOvertimeSeparationLimit.toString());
        }
        if (model.overtimeSeparationLimitDuringRest && model.normalOvertimeSeparationLimit !== undefined) {
            model.overtimeSeparationLimitDuringRest = convertMinutesToTime(model.overtimeSeparationLimitDuringRest.toString());
        }
        if (model.overtimeSeparationLimitDuringCompensatedDays && model.overtimeSeparationLimitDuringCompensatedDays !== undefined) {
            model.overtimeSeparationLimitDuringCompensatedDays = convertMinutesToTime(model.overtimeSeparationLimitDuringCompensatedDays.toString());
        }
        if (model.overtimeSeparationLimitDuringHoliday && model.overtimeSeparationLimitDuringHoliday !== undefined) {
            model.overtimeSeparationLimitDuringHoliday = convertMinutesToTime(model.overtimeSeparationLimitDuringHoliday.toString());
        }
        if (model.overtimeSeparationLimitDuringDayOff && model.overtimeSeparationLimitDuringDayOff !== undefined) {
            model.overtimeSeparationLimitDuringDayOff = convertMinutesToTime(model.overtimeSeparationLimitDuringDayOff.toString());
        }
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["situationDefinition.code", "situationDefinition.name", "startDate", "endDate"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "TimeEvaluationSituationDefinition" && model.situationDefinition)
            model.situationDefinition = TimeEvaluationSituationDefinition.fromDto(model.situationDefinition, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.workSituation)
            model.workSituation = SituationClockingEvent.fromDto(model.workSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.nightShiftWorkPremium)
            model.nightShiftWorkPremium = SituationClockingEvent.fromDto(model.nightShiftWorkPremium, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.invalidEventsSituation)
            model.invalidEventsSituation = SituationClockingEvent.fromDto(model.invalidEventsSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.vacationPaidLeaveSituation)
            model.vacationPaidLeaveSituation = SituationClockingEvent.fromDto(model.vacationPaidLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.dailyRestViolationSituation)
            model.dailyRestViolationSituation = SituationClockingEvent.fromDto(model.dailyRestViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.workBreakViolationSituation)
            model.workBreakViolationSituation = SituationClockingEvent.fromDto(model.workBreakViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.absenceSituation)
            model.absenceSituation = SituationClockingEvent.fromDto(model.absenceSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.tardinessSituation)
            model.tardinessSituation = SituationClockingEvent.fromDto(model.tardinessSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.intermediateLeaveSituation)
            model.intermediateLeaveSituation = SituationClockingEvent.fromDto(model.intermediateLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.earlyLeaveSituation)
            model.earlyLeaveSituation = SituationClockingEvent.fromDto(model.earlyLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.absenceSituationOnRelayScheduleHolidays)
            model.absenceSituationOnRelayScheduleHolidays = SituationClockingEvent.fromDto(model.absenceSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.unauthorizedOvertime)
            model.unauthorizedOvertime = SituationClockingEvent.fromDto(model.unauthorizedOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeBefore)
            model.overtimeBefore = SituationClockingEvent.fromDto(model.overtimeBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeEntry)
            model.overtimeEntry = SituationClockingEvent.fromDto(model.overtimeEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeDuringMeal)
            model.overtimeDuringMeal = SituationClockingEvent.fromDto(model.overtimeDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.leaveOvertime)
            model.leaveOvertime = SituationClockingEvent.fromDto(model.leaveOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeAfter)
            model.overtimeAfter = SituationClockingEvent.fromDto(model.overtimeAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeDuringRest)
            model.overtimeDuringRest = SituationClockingEvent.fromDto(model.overtimeDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeOnCompensatedDays)
            model.overtimeOnCompensatedDays = SituationClockingEvent.fromDto(model.overtimeOnCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeDuringHoliday)
            model.overtimeDuringHoliday = SituationClockingEvent.fromDto(model.overtimeDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeDuringDayOff)
            model.overtimeDuringDayOff = SituationClockingEvent.fromDto(model.overtimeDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSituationOnRelayScheduleHolidays)
            model.overtimeSituationOnRelayScheduleHolidays = SituationClockingEvent.fromDto(model.overtimeSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.nightShiftOvertimePremiumSituation)
            model.nightShiftOvertimePremiumSituation = SituationClockingEvent.fromDto(model.nightShiftOvertimePremiumSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationBefore)
            model.overtimeSeparationBefore = SituationClockingEvent.fromDto(model.overtimeSeparationBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationEntry)
            model.overtimeSeparationEntry = SituationClockingEvent.fromDto(model.overtimeSeparationEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringMeal)
            model.overtimeSeparationDuringMeal = SituationClockingEvent.fromDto(model.overtimeSeparationDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationLeave)
            model.overtimeSeparationLeave = SituationClockingEvent.fromDto(model.overtimeSeparationLeave, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationAfter)
            model.overtimeSeparationAfter = SituationClockingEvent.fromDto(model.overtimeSeparationAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringRest)
            model.overtimeSeparationDuringRest = SituationClockingEvent.fromDto(model.overtimeSeparationDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringCompensatedDays)
            model.overtimeSeparationDuringCompensatedDays = SituationClockingEvent.fromDto(model.overtimeSeparationDuringCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringHoliday)
            model.overtimeSeparationDuringHoliday = SituationClockingEvent.fromDto(model.overtimeSeparationDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringDayOff)
            model.overtimeSeparationDuringDayOff = SituationClockingEvent.fromDto(model.overtimeSeparationDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionHistory
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(timeEvaluationSituationDefinitionHistory, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, timeEvaluationSituationDefinitionHistory);
        if (dto.normalOvertimeSeparationLimit && dto.normalOvertimeSeparationLimit !== undefined) {
            dto.normalOvertimeSeparationLimit = convertTimeToMinutes(dto.normalOvertimeSeparationLimit);
        }
        if (dto.overtimeSeparationLimitDuringRest && dto.overtimeSeparationLimitDuringRest !== undefined) {
            dto.overtimeSeparationLimitDuringRest = convertTimeToMinutes(dto.overtimeSeparationLimitDuringRest);
        }
        if (dto.overtimeSeparationLimitDuringCompensatedDays && dto.overtimeSeparationLimitDuringCompensatedDays !== undefined) {
            dto.overtimeSeparationLimitDuringCompensatedDays = convertTimeToMinutes(dto.overtimeSeparationLimitDuringCompensatedDays);
        }
        if (dto.overtimeSeparationLimitDuringHoliday && dto.overtimeSeparationLimitDuringHoliday !== undefined) {
            dto.overtimeSeparationLimitDuringHoliday = convertTimeToMinutes(dto.overtimeSeparationLimitDuringHoliday);
        }
        if (dto.overtimeSeparationLimitDuringDayOff && dto.overtimeSeparationLimitDuringDayOff !== undefined) {
            dto.overtimeSeparationLimitDuringDayOff = convertTimeToMinutes(dto.overtimeSeparationLimitDuringDayOff);
        }
        dto.startDate = dto.startDate && moment$o(dto.startDate).format("YYYY-MM-DD");
        dto.endDate = dto.endDate && moment$o(dto.endDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$o(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$o(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "TimeEvaluationSituationDefinition" && dto.situationDefinition)
            dto.situationDefinition = TimeEvaluationSituationDefinition.toDto(dto.situationDefinition, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.workSituation)
            dto.workSituation = SituationClockingEvent.toDto(dto.workSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.nightShiftWorkPremium)
            dto.nightShiftWorkPremium = SituationClockingEvent.toDto(dto.nightShiftWorkPremium, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.invalidEventsSituation)
            dto.invalidEventsSituation = SituationClockingEvent.toDto(dto.invalidEventsSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.vacationPaidLeaveSituation)
            dto.vacationPaidLeaveSituation = SituationClockingEvent.toDto(dto.vacationPaidLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.dailyRestViolationSituation)
            dto.dailyRestViolationSituation = SituationClockingEvent.toDto(dto.dailyRestViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.workBreakViolationSituation)
            dto.workBreakViolationSituation = SituationClockingEvent.toDto(dto.workBreakViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.absenceSituation)
            dto.absenceSituation = SituationClockingEvent.toDto(dto.absenceSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.tardinessSituation)
            dto.tardinessSituation = SituationClockingEvent.toDto(dto.tardinessSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.intermediateLeaveSituation)
            dto.intermediateLeaveSituation = SituationClockingEvent.toDto(dto.intermediateLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.earlyLeaveSituation)
            dto.earlyLeaveSituation = SituationClockingEvent.toDto(dto.earlyLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.absenceSituationOnRelayScheduleHolidays)
            dto.absenceSituationOnRelayScheduleHolidays = SituationClockingEvent.toDto(dto.absenceSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.unauthorizedOvertime)
            dto.unauthorizedOvertime = SituationClockingEvent.toDto(dto.unauthorizedOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeBefore)
            dto.overtimeBefore = SituationClockingEvent.toDto(dto.overtimeBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeEntry)
            dto.overtimeEntry = SituationClockingEvent.toDto(dto.overtimeEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeDuringMeal)
            dto.overtimeDuringMeal = SituationClockingEvent.toDto(dto.overtimeDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.leaveOvertime)
            dto.leaveOvertime = SituationClockingEvent.toDto(dto.leaveOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeAfter)
            dto.overtimeAfter = SituationClockingEvent.toDto(dto.overtimeAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeDuringRest)
            dto.overtimeDuringRest = SituationClockingEvent.toDto(dto.overtimeDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeOnCompensatedDays)
            dto.overtimeOnCompensatedDays = SituationClockingEvent.toDto(dto.overtimeOnCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeDuringHoliday)
            dto.overtimeDuringHoliday = SituationClockingEvent.toDto(dto.overtimeDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeDuringDayOff)
            dto.overtimeDuringDayOff = SituationClockingEvent.toDto(dto.overtimeDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSituationOnRelayScheduleHolidays)
            dto.overtimeSituationOnRelayScheduleHolidays = SituationClockingEvent.toDto(dto.overtimeSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.nightShiftOvertimePremiumSituation)
            dto.nightShiftOvertimePremiumSituation = SituationClockingEvent.toDto(dto.nightShiftOvertimePremiumSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationBefore)
            dto.overtimeSeparationBefore = SituationClockingEvent.toDto(dto.overtimeSeparationBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationEntry)
            dto.overtimeSeparationEntry = SituationClockingEvent.toDto(dto.overtimeSeparationEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringMeal)
            dto.overtimeSeparationDuringMeal = SituationClockingEvent.toDto(dto.overtimeSeparationDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationLeave)
            dto.overtimeSeparationLeave = SituationClockingEvent.toDto(dto.overtimeSeparationLeave, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationAfter)
            dto.overtimeSeparationAfter = SituationClockingEvent.toDto(dto.overtimeSeparationAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringRest)
            dto.overtimeSeparationDuringRest = SituationClockingEvent.toDto(dto.overtimeSeparationDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringCompensatedDays)
            dto.overtimeSeparationDuringCompensatedDays = SituationClockingEvent.toDto(dto.overtimeSeparationDuringCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringHoliday)
            dto.overtimeSeparationDuringHoliday = SituationClockingEvent.toDto(dto.overtimeSeparationDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringDayOff)
            dto.overtimeSeparationDuringDayOff = SituationClockingEvent.toDto(dto.overtimeSeparationDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.id;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.situationDefinition;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.startDate;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.endDate;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.workSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.nightShiftWorkPremium;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.invalidEventsSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.vacationPaidLeaveSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.dailyRestViolationSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.workBreakViolationSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.absenceSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.tardinessSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.intermediateLeaveSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.earlyLeaveSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.absenceSituationOnRelayScheduleHolidays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.percentageNextDay;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.normalOvertimeSeparationLimit;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.separateOvertimeAfterConvertingNightShiftHours;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.unauthorizedOvertime;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeBefore;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeEntry;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeDuringMeal;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.leaveOvertime;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeAfter;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLimitDuringRest;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeDuringRest;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLimitDuringCompensatedDays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeOnCompensatedDays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLimitDuringHoliday;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeDuringHoliday;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLimitDuringDayOff;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeDuringDayOff;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSituationOnRelayScheduleHolidays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.nightShiftOvertimePremiumSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationBefore;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationEntry;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringMeal;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLeave;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationAfter;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringRest;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringCompensatedDays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringHoliday;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringDayOff;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.createdBy;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.createdDate;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.lastModifiedBy;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.lastModifiedDate;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/time-evaluation-situation-definition-history-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function TimeEvaluationSituationDefinitionHistoryDto() { }
if (false) {
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.id;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.situationDefinition;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.startDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.endDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.workSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.nightShiftWorkPremium;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.invalidEventsSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.vacationPaidLeaveSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.dailyRestViolationSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.workBreakViolationSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.absenceSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.tardinessSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.intermediateLeaveSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.earlyLeaveSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.absenceSituationOnRelayScheduleHolidays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.percentageNextDay;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.normalOvertimeSeparationLimit;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.separateOvertimeAfterConvertingNightShiftHours;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.unauthorizedOvertime;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeBefore;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeEntry;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeDuringMeal;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.leaveOvertime;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeAfter;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLimitDuringRest;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeDuringRest;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLimitDuringCompensatedDays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeOnCompensatedDays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLimitDuringHoliday;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeDuringHoliday;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLimitDuringDayOff;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeDuringDayOff;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSituationOnRelayScheduleHolidays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.nightShiftOvertimePremiumSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationBefore;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationEntry;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringMeal;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLeave;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationAfter;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringRest;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringCompensatedDays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringHoliday;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringDayOff;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.createdBy;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.createdDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/situation-clocking-event-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function SituationClockingEventDto() { }
if (false) {
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.id;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.situation;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.complementarySituation;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.exceptionSituation;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.mandatoryAdjustmentReason;
    /** @type {?} */
    SituationClockingEventDto.prototype.daytimeSituation;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.convertNightHours;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.obligateAttachmentOnLeave;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.createdBy;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.createdDate;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-change/workshift-change-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function WorkshiftChangeDto() { }
if (false) {
    /** @type {?|undefined} */
    WorkshiftChangeDto.prototype.id;
    /** @type {?} */
    WorkshiftChangeDto.prototype.employee;
    /** @type {?} */
    WorkshiftChangeDto.prototype.startDate;
    /** @type {?} */
    WorkshiftChangeDto.prototype.endDate;
    /** @type {?} */
    WorkshiftChangeDto.prototype.workshift;
    /** @type {?|undefined} */
    WorkshiftChangeDto.prototype.workshiftGroup;
    /** @type {?|undefined} */
    WorkshiftChangeDto.prototype.createdBy;
    /** @type {?|undefined} */
    WorkshiftChangeDto.prototype.createdDate;
    /** @type {?|undefined} */
    WorkshiftChangeDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    WorkshiftChangeDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    WorkshiftChangeDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-change/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift/workshift-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/**
 * @record
 */
function WorkshiftDto() { }
if (false) {
    /** @type {?|undefined} */
    WorkshiftDto.prototype.id;
    /** @type {?} */
    WorkshiftDto.prototype.code;
    /** @type {?} */
    WorkshiftDto.prototype.shortName;
    /** @type {?} */
    WorkshiftDto.prototype.workshiftType;
    /** @type {?|undefined} */
    WorkshiftDto.prototype.deleted;
    /** @type {?|undefined} */
    WorkshiftDto.prototype.extIntSts;
    /** @type {?|undefined} */
    WorkshiftDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    WorkshiftDto.prototype.createdBy;
    /** @type {?|undefined} */
    WorkshiftDto.prototype.createdDate;
    /** @type {?|undefined} */
    WorkshiftDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    WorkshiftDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    WorkshiftDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-group/workshift-group-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function WorkshiftGroupDto() { }
if (false) {
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.id;
    /** @type {?} */
    WorkshiftGroupDto.prototype.code;
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.deleted;
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.extIntSts;
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.createdBy;
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.createdDate;
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    WorkshiftGroupDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/workshift-group/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/compensation/compensation-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function CompensationDto() { }
if (false) {
    /** @type {?|undefined} */
    CompensationDto.prototype.id;
    /** @type {?} */
    CompensationDto.prototype.employee;
    /** @type {?} */
    CompensationDto.prototype.startDate;
    /** @type {?} */
    CompensationDto.prototype.endDate;
    /** @type {?|undefined} */
    CompensationDto.prototype.intervalStart;
    /** @type {?|undefined} */
    CompensationDto.prototype.intervalEnd;
    /** @type {?} */
    CompensationDto.prototype.compensationType;
    /** @type {?|undefined} */
    CompensationDto.prototype.periodType;
    /** @type {?|undefined} */
    CompensationDto.prototype.numberOfHours;
    /** @type {?} */
    CompensationDto.prototype.situation;
    /** @type {?|undefined} */
    CompensationDto.prototype.workschedule;
    /** @type {?|undefined} */
    CompensationDto.prototype.adjustmentReason;
    /** @type {?|undefined} */
    CompensationDto.prototype.createdBy;
    /** @type {?|undefined} */
    CompensationDto.prototype.createdDate;
    /** @type {?|undefined} */
    CompensationDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    CompensationDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    CompensationDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/compensation/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason/adjustment-reason-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function AdjustmentReasonDto() { }
if (false) {
    /** @type {?|undefined} */
    AdjustmentReasonDto.prototype.id;
    /** @type {?} */
    AdjustmentReasonDto.prototype.code;
    /** @type {?} */
    AdjustmentReasonDto.prototype.name;
    /** @type {?|undefined} */
    AdjustmentReasonDto.prototype.mandatoryObservation;
    /** @type {?|undefined} */
    AdjustmentReasonDto.prototype.createdBy;
    /** @type {?|undefined} */
    AdjustmentReasonDto.prototype.createdDate;
    /** @type {?|undefined} */
    AdjustmentReasonDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    AdjustmentReasonDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    AdjustmentReasonDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason-situation/adjustment-reason-situation.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/** @type {?} */
const moment$p = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class AdjustmentReasonSituation {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} adjustmentReasonSituationDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(adjustmentReasonSituationDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, adjustmentReasonSituationDto);
        model.createdDate = model.createdDate && moment$p(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$p(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "situation.code",
            "situation.name",
            "adjustmentReason.code",
            "adjustmentReason.name",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Situation" && model.situation) {
            model.situation = Situation.fromDto(model.situation, "AdjustmentReasonSituation");
        }
        if (originEntity !== "AdjustmentReason" && model.adjustmentReason) {
            model.adjustmentReason = AdjustmentReason.fromDto(model.adjustmentReason, "AdjustmentReasonSituation");
        }
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} adjustmentReasonSituation
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(adjustmentReasonSituation, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, adjustmentReasonSituation);
        dto.createdDate = dto.createdDate && moment$p(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$p(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Situation" && dto.situation) {
            dto.situation = Situation.toDto(dto.situation, "AdjustmentReasonSituation");
        }
        if (originEntity !== "AdjustmentReason" && dto.adjustmentReason) {
            dto.adjustmentReason = AdjustmentReason.toDto(dto.adjustmentReason, "AdjustmentReasonSituation");
        }
        return dto;
    }
}
if (false) {
    /** @type {?} */
    AdjustmentReasonSituation.prototype.id;
    /** @type {?} */
    AdjustmentReasonSituation.prototype.situation;
    /** @type {?} */
    AdjustmentReasonSituation.prototype.adjustmentReason;
    /** @type {?} */
    AdjustmentReasonSituation.prototype.createdBy;
    /** @type {?} */
    AdjustmentReasonSituation.prototype.createdDate;
    /** @type {?} */
    AdjustmentReasonSituation.prototype.lastModifiedBy;
    /** @type {?} */
    AdjustmentReasonSituation.prototype.lastModifiedDate;
    /** @type {?} */
    AdjustmentReasonSituation.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason-situation/adjustment-reason-situation-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function AdjustmentReasonSituationDto() { }
if (false) {
    /** @type {?|undefined} */
    AdjustmentReasonSituationDto.prototype.id;
    /** @type {?} */
    AdjustmentReasonSituationDto.prototype.situation;
    /** @type {?} */
    AdjustmentReasonSituationDto.prototype.adjustmentReason;
    /** @type {?|undefined} */
    AdjustmentReasonSituationDto.prototype.createdBy;
    /** @type {?|undefined} */
    AdjustmentReasonSituationDto.prototype.createdDate;
    /** @type {?|undefined} */
    AdjustmentReasonSituationDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    AdjustmentReasonSituationDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    AdjustmentReasonSituationDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/adjustment-reason-situation/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/overtime-authorization/overtime-authorization-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function OvertimeAuthorizationDto() { }
if (false) {
    /** @type {?|undefined} */
    OvertimeAuthorizationDto.prototype.id;
    /** @type {?} */
    OvertimeAuthorizationDto.prototype.employee;
    /** @type {?} */
    OvertimeAuthorizationDto.prototype.startDateTime;
    /** @type {?} */
    OvertimeAuthorizationDto.prototype.endDateTime;
    /** @type {?|undefined} */
    OvertimeAuthorizationDto.prototype.authorizer;
    /** @type {?|undefined} */
    OvertimeAuthorizationDto.prototype.observation;
    /** @type {?|undefined} */
    OvertimeAuthorizationDto.prototype.createdBy;
    /** @type {?|undefined} */
    OvertimeAuthorizationDto.prototype.createdDate;
    /** @type {?|undefined} */
    OvertimeAuthorizationDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    OvertimeAuthorizationDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    OvertimeAuthorizationDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/overtime-authorization/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/clocking-event-tolerance-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const ClockingEventToleranceType = {
    V1: "V1",
    V2: "V2",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/consider-clocking-event-interval-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const ConsiderClockingEventIntervalType = {
    V1: "V1",
    V2: "V2",
    V3: "V3",
    V4: "V4",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/retroactive-adjustment-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const RetroactiveAdjustmentType = {
    V1: "V1",
    V2: "V2",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/verified-days-control-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const VerifiedDaysControlType = {
    V0: "V0",
    V1: "V1",
    V2: "V2",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: locale/fallback.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const fallback = {
    "hcm_clocking_event_foundation.general.click_here": "clique aqui",
    "hcm_clocking_event_foundation.general.compensation_end_date": "Data final",
    "hcm_clocking_event_foundation.general.compensation_interval_end": "Fim do intervalo",
    "hcm_clocking_event_foundation.general.compensation_interval_start": "Início do intervalo",
    "hcm_clocking_event_foundation.general.compensation_start_date": "Data inicial",
    "hcm_clocking_event_foundation.general.confirm_process_message": "O processo acontecerá em segundo plano. Quando concluído informaremos o resultado por notificação.<br><br>Confirma a execução do processo?",
    "hcm_clocking_event_foundation.general.detail_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.detail_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.employees_and_companies_are_empty": "Ao menos um dos filtros deve ser preenchido",
    "hcm_clocking_event_foundation.general.error_end_date_before_start_date": "A data final deve ser maior que a data inicial",
    "hcm_clocking_event_foundation.general.error_start_date_after_dismissal_date": "A data inicial deve ser menor ou igual à data de demissão",
    "hcm_clocking_event_foundation.general.error_start_date_after_end_date_to_end_date": "A data final deve ser maior que a data inicial",
    "hcm_clocking_event_foundation.general.evaluate_process_start": "O processo foi iniciado. Você será notificado quando o processo acabar. O andamento estará disponível na tela de logs de processo. ",
    "hcm_clocking_event_foundation.general.generic_btn_cancel_label": "Cancelar",
    "hcm_clocking_event_foundation.general.generic_btn_select_label": "Selecionar",
    "hcm_clocking_event_foundation.general.generic_clear_label": "Limpar",
    "hcm_clocking_event_foundation.general.generic_filter_label": "Filtrar",
    "hcm_clocking_event_foundation.general.generic_filter_title": "Filtros",
    "hcm_clocking_event_foundation.general.generic_lookup_empty_message": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.generic_n_records_found": "{{value}} registros encontrados",
    "hcm_clocking_event_foundation.general.generic_no_records_found": "Nenhum registro encontrado",
    "hcm_clocking_event_foundation.general.generic_record_found": "{{value}} registro encontrado",
    "hcm_clocking_event_foundation.general.generic_total_records": "{{value}} registro(s) encontrado(s)",
    "hcm_clocking_event_foundation.general.go_to_logs": "Para acessar",
    "hcm_clocking_event_foundation.general.lookup_company_code": "Código",
    "hcm_clocking_event_foundation.general.lookup_company_name": "Nome",
    "hcm_clocking_event_foundation.general.start_date_is_before_end_date_to_end_date": "A data final deve ser maior ou igual à data inicial",
    "hcm_clocking_event_foundation.general.start_date_is_before_end_date_to_start_date": "A data inicial deve ser menor ou igual à data final",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_form_detail_title": "Detalhes da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_time_evaluation_situation_definition_history_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_time_evaluation_situation_definition_history_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_time_evaluation_situation_definition_history": "Histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.add_collective": "Adicionar coletivamente",
    "hcm_clocking_event_foundation.general.add": "Adicionar",
    "hcm_clocking_event_foundation.general.adjustment_reason_code": "Código",
    "hcm_clocking_event_foundation.general.adjustment_reason_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.adjustment_reason_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.adjustment_reason_form_general_title": "Motivos de acertos",
    "hcm_clocking_event_foundation.general.adjustment_reason_form_title": "Motivos de acertos",
    "hcm_clocking_event_foundation.general.adjustment_reason_id": "Identificador único",
    "hcm_clocking_event_foundation.general.adjustment_reason_list_grid_title": "Lista de motivos de acertos",
    "hcm_clocking_event_foundation.general.adjustment_reason_list_title": "Motivos de acertos",
    "hcm_clocking_event_foundation.general.adjustment_reason_mandatory_observation": "Observação Obrigatória",
    "hcm_clocking_event_foundation.general.adjustment_reason_name": "Descrição",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_adjustment_reason_code": "Motivo",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_adjustment_reason_name": "Descrição do motivo",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_adjustment_reason_search_title": "Motivo",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_adjustment_reason": "Motivo",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_form_general_title": "Motivos por Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_form_title": "Motivos por Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_id": "Identificador único",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_list_grid_title": "Lista de motivos por situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_list_title": "Motivos por situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_situation_code": "Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_situation_name": "Descrição da situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_situation_search_title": "Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_situation": "Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation": "Motivos por Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason": "Motivos de acertos",
    "hcm_clocking_event_foundation.general.and": "e",
    "hcm_clocking_event_foundation.general.article_62_clt_type_v_1": "Não se aplica",
    "hcm_clocking_event_foundation.general.article_62_clt_type_v_2": "Atividade externa especificada no inciso I",
    "hcm_clocking_event_foundation.general.article_62_clt_type_v_3": "Funções especificadas no inciso II",
    "hcm_clocking_event_foundation.general.article_62_clt_type_v_4": "Teletrabalho, previsto no inciso III",
    "hcm_clocking_event_foundation.general.at_date": "em",
    "hcm_clocking_event_foundation.general.at_time": "às",
    "hcm_clocking_event_foundation.general.batch_filters": "Filtros",
    "hcm_clocking_event_foundation.general.bridge_destination_date": "Data destino",
    "hcm_clocking_event_foundation.general.bridge_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.bridge_employee_person_nom_pes": "Nome colaborador",
    "hcm_clocking_event_foundation.general.bridge_employee_search_title": "Colaborador",
    "hcm_clocking_event_foundation.general.bridge_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.bridge_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.bridge_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.bridge_form_general_title": "Ponte",
    "hcm_clocking_event_foundation.general.bridge_form_title": "Ponte",
    "hcm_clocking_event_foundation.general.bridge_id": "Identificador único",
    "hcm_clocking_event_foundation.general.bridge_list_grid_title": "Lista de Pontes",
    "hcm_clocking_event_foundation.general.bridge_list_title": "Pontes",
    "hcm_clocking_event_foundation.general.bridge_origin_date": "Data origem",
    "hcm_clocking_event_foundation.general.bridge": "Pontes",
    "hcm_clocking_event_foundation.general.cancel_label": "Cancelar",
    "hcm_clocking_event_foundation.general.cancel": "Cancelar",
    "hcm_clocking_event_foundation.general.choose_label": "Selecionar",
    "hcm_clocking_event_foundation.general.clear": "Limpar",
    "hcm_clocking_event_foundation.general.clocking_event_tolerance_type_v_1": "Avaliação Independente",
    "hcm_clocking_event_foundation.general.clocking_event_tolerance_type_v_2": "Avaliação Dependente",
    "hcm_clocking_event_foundation.general.compensation_adjustment_reason_info_sign": "Este campo só poderá ser habilitado se o campo 'Controlar motivos de acerto' na Definição de apuração estiver selecionado. Ele será obrigatório quando o campo 'Motivo de acerto obrigatório' na Situação do ponto estiver selecionado",
    "hcm_clocking_event_foundation.general.compensation_adjustment_reason_search_title": "Localizar motivo da situação",
    "hcm_clocking_event_foundation.general.compensation_adjustment_reason": "Motivo da situação",
    "hcm_clocking_event_foundation.general.compensation_collective_companies_search_title": "Pesquisa de Empresas",
    "hcm_clocking_event_foundation.general.compensation_collective_companies": "Empresas",
    "hcm_clocking_event_foundation.general.compensation_collective_employee_search_title": "Pesquisa de Colaboradores",
    "hcm_clocking_event_foundation.general.compensation_collective_employees": "Colaboradores",
    "hcm_clocking_event_foundation.general.compensation_collective_form_general_title": "Compensação - Inclusão Coletiva",
    "hcm_clocking_event_foundation.general.compensation_compensation_type_placeholder": "Escolha um tipo de compensação",
    "hcm_clocking_event_foundation.general.compensation_compensation_type": "Tipo de compensação",
    "hcm_clocking_event_foundation.general.compensation_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.compensation_employee_person_nom_pes": "Nome Colaborador",
    "hcm_clocking_event_foundation.general.compensation_employee_search_title": "Localizar o colaborador",
    "hcm_clocking_event_foundation.general.compensation_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.compensation_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.compensation_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.compensation_form_general_title": "Compensação",
    "hcm_clocking_event_foundation.general.compensation_form_title": "Compensação",
    "hcm_clocking_event_foundation.general.compensation_id": "Identificador único",
    "hcm_clocking_event_foundation.general.compensation_list_grid_title": "Lista de compensações",
    "hcm_clocking_event_foundation.general.compensation_list_title": "Compensações",
    "hcm_clocking_event_foundation.general.compensation_number_of_hours": "Quantidade de Horas",
    "hcm_clocking_event_foundation.general.compensation_period_type_placeholder": "Escolha um tipo de período",
    "hcm_clocking_event_foundation.general.compensation_period_type": "Tipo de período",
    "hcm_clocking_event_foundation.general.compensation_situation_code": "Situação",
    "hcm_clocking_event_foundation.general.compensation_situation_name": "Descrição Situação",
    "hcm_clocking_event_foundation.general.compensation_situation_search_title": "Localizar a situação",
    "hcm_clocking_event_foundation.general.compensation_situation": "Situação",
    "hcm_clocking_event_foundation.general.compensation_type_v_1": "Extra para compensação",
    "hcm_clocking_event_foundation.general.compensation_type_v_2": "Ausência para compensação",
    "hcm_clocking_event_foundation.general.compensation_type_v_4": "Dispensar parte expediente",
    "hcm_clocking_event_foundation.general.compensation_type_v_5": "Dispensar intervalo horas",
    "hcm_clocking_event_foundation.general.compensation_type_v_6": "Programar intervalo fora expediente",
    "hcm_clocking_event_foundation.general.compensation_workschedule_code": "Horário",
    "hcm_clocking_event_foundation.general.compensation_workschedule_name": "Descrição Horário",
    "hcm_clocking_event_foundation.general.compensation_workschedule_search_title": "Localizar o horário",
    "hcm_clocking_event_foundation.general.compensation_workschedule": "Horário",
    "hcm_clocking_event_foundation.general.compensation": "Compensação",
    "hcm_clocking_event_foundation.general.consider_clocking_event_interval_type_v_1": "Não considerar",
    "hcm_clocking_event_foundation.general.consider_clocking_event_interval_type_v_2": "Segundo data e hora das marcações",
    "hcm_clocking_event_foundation.general.consider_clocking_event_interval_type_v_3": "Segundo data, hora, relógio e função das marcações",
    "hcm_clocking_event_foundation.general.consider_clocking_event_interval_type_v_4": "Segundo data, hora e uso de marcação",
    "hcm_clocking_event_foundation.general.contract_type_aprentice": "Aprendiz",
    "hcm_clocking_event_foundation.general.contract_type_director": "Diretor",
    "hcm_clocking_event_foundation.general.contract_type_employee": "Empregado",
    "hcm_clocking_event_foundation.general.contract_type_third_party": "Terceiro",
    "hcm_clocking_event_foundation.general.contract_type_trainee": "Estagiário",
    "hcm_clocking_event_foundation.general.created_by": "Criado por",
    "hcm_clocking_event_foundation.general.delete_confirmation_message": "Após excluir o(s) registro(s), não será mais possível consultá-lo(s)",
    "hcm_clocking_event_foundation.general.delete_confirmation_title": "Deseja excluir o(s) registro(s) selecionado(s)?",
    "hcm_clocking_event_foundation.general.delete": "Excluir",
    "hcm_clocking_event_foundation.general.deleted_message_content": "Registro(s) excluído(s) com sucesso",
    "hcm_clocking_event_foundation.general.deleted_message_title": "Sucesso",
    "hcm_clocking_event_foundation.general.e_001_pes_cod_pes": "Código",
    "hcm_clocking_event_foundation.general.e_001_pes_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.e_001_pes_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.e_001_pes_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.e_001_pes_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.e_001_pes_excluido": "Indica se o registro foi excluído",
    "hcm_clocking_event_foundation.general.e_001_pes_ext_int_msg": "Indica a mensagem da replicação",
    "hcm_clocking_event_foundation.general.e_001_pes_ext_int_sts": "Indica status da replicação",
    "hcm_clocking_event_foundation.general.e_001_pes_id": "Identificador único",
    "hcm_clocking_event_foundation.general.e_001_pes_last_modified_by": "Última modificação por",
    "hcm_clocking_event_foundation.general.e_001_pes_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.e_001_pes_nom_pes": "Nome",
    "hcm_clocking_event_foundation.general.e_001_pes": "Pessoa",
    "hcm_clocking_event_foundation.general.edit": "Editar",
    "hcm_clocking_event_foundation.general.employee_code": "Código do colaborador",
    "hcm_clocking_event_foundation.general.employee_employer_cod_emp": "Código da empresa",
    "hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type": "Tipo de contrato",
    "hcm_clocking_event_foundation.general.employee_person_nom_pes": "Nome do colaborador",
    "hcm_clocking_event_foundation.general.empty_label": "Não informar",
    "hcm_clocking_event_foundation.general.error_company_of_employee_need_time_evaluation_definition": "A empresa do colaborador deve ter assinalamentos do ponto",
    "hcm_clocking_event_foundation.general.error_destination_date_is_after_dismissal_date": "A data de destino deve ser maior ou igual à data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_end_date_after_admission_date": "A data final deve ser menor ou igual à data de demissão",
    "hcm_clocking_event_foundation.general.error_end_date_time_is_after_authorizer_dismissal_date": "A data/hora final deve ser menor ou igual a data de demissão do autorizador",
    "hcm_clocking_event_foundation.general.error_end_date_time_is_after_dismissal_date": "A data/hora final deve ser menor ou igual a data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_evaluation_time_is_after_dismissal_date": "O início da apuração deve ser menor ou igual à data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_evaluation_time_start_time_is_before_hire_date": "O início da apuração deve ser maior ou igual à data de admissão do colaborador",
    "hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling": "O limite de dias para programações retroativas foi excedido",
    "hcm_clocking_event_foundation.general.error_forbidden_description": "Você não possui permissão para acessar este conteúdo",
    "hcm_clocking_event_foundation.general.error_forbidden_title": "403 - Acesso negado",
    "hcm_clocking_event_foundation.general.error_invalid": "O valor é inválido",
    "hcm_clocking_event_foundation.general.error_max_length": "Tamanho maior que o permitido",
    "hcm_clocking_event_foundation.general.error_max_value": "Valor maior que o permitido",
    "hcm_clocking_event_foundation.general.error_min_value": "Valor menor que o permitido",
    "hcm_clocking_event_foundation.general.error_missing_company_clocking_event_indications": "Não possui assinalamentos do ponto para a empresa",
    "hcm_clocking_event_foundation.general.error_not_found_description": "O endereço pode estar incorreto, não estar disponível ou o conteúdo pode ter sido removido",
    "hcm_clocking_event_foundation.general.error_not_found_title": "404 - Página não encontrada",
    "hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_end_date": "A data de destino deve ser menor que a data de origem",
    "hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_start_date": "A data de origem deve ser menor que a data de destino",
    "hcm_clocking_event_foundation.general.error_origin_date_is_after_dismissal_date": "A data de origem deve ser menor ou igual à data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_origin_date_is_before_hire_date": "A data de origem deve ser maior ou igual à data de admissão do colaborador",
    "hcm_clocking_event_foundation.general.error_required": "O campo é obrigatório",
    "hcm_clocking_event_foundation.general.error_server_description": "Ocorreu um erro no sistema que impediu a exibição do conteúdo. Contate o administrador do sistema",
    "hcm_clocking_event_foundation.general.error_server_title": "500 - Erro interno do servidor",
    "hcm_clocking_event_foundation.general.error_server_try_again": "Tentar novamente",
    "hcm_clocking_event_foundation.general.error_situation_clocking_event_not_found": "Situação do ponto não encontrada",
    "hcm_clocking_event_foundation.general.error_start_date_after_end_date_to_start_date": "A data inicial deve ser menor que a data final",
    "hcm_clocking_event_foundation.general.error_start_date_after_end_date": "A data inicial deve ser menor que a data final",
    "hcm_clocking_event_foundation.general.error_start_date_before_admission_date": "A data inicial deve ser maior ou igual à data de admissão",
    "hcm_clocking_event_foundation.general.error_start_date_time_is_after_authorizer_dismissal_date": "A data/hora inicial deve ser menor ou igual à data de demissão do autorizador",
    "hcm_clocking_event_foundation.general.error_start_date_time_is_after_dismissal_date": "A data/hora inicial deve ser menor ou igual a data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_start_date_time_is_before_authorizer_hire_date": "A data inicial deve ser maior ou igual a data de admissão do autorizador",
    "hcm_clocking_event_foundation.general.error_start_date_time_is_before_hire_date": "A data/hora inicial deve ser maior ou igual a data de admissão do colaborador",
    "hcm_clocking_event_foundation.general.error_unauthorized_description": "Usuário não autorizado",
    "hcm_clocking_event_foundation.general.error_unauthorized_title": "Não autorizado",
    "hcm_clocking_event_foundation.general.error_verify_start_date_or_and_date": "Verifique a data inicial ou a data final",
    "hcm_clocking_event_foundation.general.false_label": "Não",
    "hcm_clocking_event_foundation.general.filter": "Filtrar",
    "hcm_clocking_event_foundation.general.filters": "Filtros",
    "hcm_clocking_event_foundation.general.generic_confirm": "Confirmação",
    "hcm_clocking_event_foundation.general.generic_no": "Não",
    "hcm_clocking_event_foundation.general.generic_yes": "Sim",
    "hcm_clocking_event_foundation.general.info_employee_is_leave_on_destination_date": "O colaborador está afastado na data de destino",
    "hcm_clocking_event_foundation.general.info_employee_is_leave_on_origin_date": "O colaborador está afastado na data de origem",
    "hcm_clocking_event_foundation.general.list_grid_boolean_false": "Não",
    "hcm_clocking_event_foundation.general.list_grid_boolean_true": "Sim",
    "hcm_clocking_event_foundation.general.list_grid_empty_field": "Não informado",
    "hcm_clocking_event_foundation.general.no": "Não",
    "hcm_clocking_event_foundation.general.nothing_found": "Nenhum registro encontrado",
    "hcm_clocking_event_foundation.general.other_actions": "Outras ações",
    "hcm_clocking_event_foundation.general.overtime_authorization_authorizer_code": "Autorizador",
    "hcm_clocking_event_foundation.general.overtime_authorization_authorizer_person_nom_pes": "Nome do autorizador",
    "hcm_clocking_event_foundation.general.overtime_authorization_authorizer_search_title": "Autorizador",
    "hcm_clocking_event_foundation.general.overtime_authorization_authorizer": "Autorizador",
    "hcm_clocking_event_foundation.general.overtime_authorization_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.overtime_authorization_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.overtime_authorization_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.overtime_authorization_employee_person_nom_pes": "Nome do colaborador",
    "hcm_clocking_event_foundation.general.overtime_authorization_employee_search_title": "Colaborador",
    "hcm_clocking_event_foundation.general.overtime_authorization_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.overtime_authorization_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.overtime_authorization_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.overtime_authorization_end_date_time": "Data/Hora Final",
    "hcm_clocking_event_foundation.general.overtime_authorization_form_general_title": "Autorização de horas extras",
    "hcm_clocking_event_foundation.general.overtime_authorization_form_title": "Autorização de horas extras",
    "hcm_clocking_event_foundation.general.overtime_authorization_id": "Identificador único",
    "hcm_clocking_event_foundation.general.overtime_authorization_last_modified_by": "Última modificação por",
    "hcm_clocking_event_foundation.general.overtime_authorization_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.overtime_authorization_list_grid_title": "Lista de autorizações de horas extras",
    "hcm_clocking_event_foundation.general.overtime_authorization_list_title": "Autorizações de horas extras",
    "hcm_clocking_event_foundation.general.overtime_authorization_observation": "Observação",
    "hcm_clocking_event_foundation.general.overtime_authorization_start_date_time": "Data/Hora Inicial",
    "hcm_clocking_event_foundation.general.overtime_authorization": "Autorização de horas extras",
    "hcm_clocking_event_foundation.general.period_type_v_1": "Qualquer parte do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_2": "Início e fim do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_3": "Durante intervalos de refeição",
    "hcm_clocking_event_foundation.general.period_type_v_4": "Início do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_5": "Final do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_6": "Início do expediente antecipando horário",
    "hcm_clocking_event_foundation.general.period_type_v_7": "Final do expediente prorrogando horário",
    "hcm_clocking_event_foundation.general.period_type_v_8": "Dispensar 1ª parte do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_9": "Dispensar 2ª parte do expediente",
    "hcm_clocking_event_foundation.general.product_header_title": "Gestão de Pessoas",
    "hcm_clocking_event_foundation.general.readiness_continuous": "Contínuo",
    "hcm_clocking_event_foundation.general.readiness_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.readiness_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.readiness_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.readiness_employee_person_nom_pes": "Nome do colaborador",
    "hcm_clocking_event_foundation.general.readiness_employee_search_title": "Localizar o colaborador",
    "hcm_clocking_event_foundation.general.readiness_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.readiness_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.readiness_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.readiness_end_date_time": "Data/Hora Final",
    "hcm_clocking_event_foundation.general.readiness_form_general_title": "Sobreaviso",
    "hcm_clocking_event_foundation.general.readiness_form_title": "Sobreaviso",
    "hcm_clocking_event_foundation.general.readiness_id": "Identificador único",
    "hcm_clocking_event_foundation.general.readiness_last_modified_by": "Última modificação",
    "hcm_clocking_event_foundation.general.readiness_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.readiness_list_grid_title": "Lista de sobreavisos",
    "hcm_clocking_event_foundation.general.readiness_list_title": "Sobreavisos",
    "hcm_clocking_event_foundation.general.readiness_observation": "Observação",
    "hcm_clocking_event_foundation.general.readiness_situation_code": "Situação",
    "hcm_clocking_event_foundation.general.readiness_situation_name": "Nome da situação",
    "hcm_clocking_event_foundation.general.readiness_situation_search_title": "Localizar a situação",
    "hcm_clocking_event_foundation.general.readiness_situation_situation_type": "Tipo da situação",
    "hcm_clocking_event_foundation.general.readiness_situation": "Situação",
    "hcm_clocking_event_foundation.general.readiness_start_date_time": "Data/Hora Inicial",
    "hcm_clocking_event_foundation.general.readiness": "Sobreaviso",
    "hcm_clocking_event_foundation.general.register_justification_code": "Código",
    "hcm_clocking_event_foundation.general.register_justification_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.register_justification_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.register_justification_form_general_title": "Justificativas de Acerto",
    "hcm_clocking_event_foundation.general.register_justification_form_title": "Justificativa de Acerto",
    "hcm_clocking_event_foundation.general.register_justification_id": "Identificador único",
    "hcm_clocking_event_foundation.general.register_justification_list_grid_title": "Lista de justificativas de Acerto",
    "hcm_clocking_event_foundation.general.register_justification_list_title": "Justificativas de Acerto",
    "hcm_clocking_event_foundation.general.register_justification_name": "Descrição",
    "hcm_clocking_event_foundation.general.register_justification": "Justificativa de Acerto",
    "hcm_clocking_event_foundation.general.remove_label": "Excluir",
    "hcm_clocking_event_foundation.general.retroactive_adjustment_type_v_1": "Alertar",
    "hcm_clocking_event_foundation.general.retroactive_adjustment_type_v_2": "Ignorar",
    "hcm_clocking_event_foundation.general.save": "Salvar",
    "hcm_clocking_event_foundation.general.saved_message_content": "Registro(s) salvo(s) com sucesso",
    "hcm_clocking_event_foundation.general.saved_message_title": "Sucesso",
    "hcm_clocking_event_foundation.general.see_details": "Ver detalhes",
    "hcm_clocking_event_foundation.general.select": "Selecionar",
    "hcm_clocking_event_foundation.general.situation_clocking_event_complementary_situation_code": "Código",
    "hcm_clocking_event_foundation.general.situation_clocking_event_complementary_situation_name": "Descrição",
    "hcm_clocking_event_foundation.general.situation_clocking_event_complementary_situation_search_title": "Pesquisa de situações complementares",
    "hcm_clocking_event_foundation.general.situation_clocking_event_complementary_situation": "Situação complementar",
    "hcm_clocking_event_foundation.general.situation_clocking_event_convert_night_hours": "Converte em horas noturnas",
    "hcm_clocking_event_foundation.general.situation_clocking_event_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.situation_clocking_event_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.situation_clocking_event_daytime_situation": "Situação diurna",
    "hcm_clocking_event_foundation.general.situation_clocking_event_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.situation_clocking_event_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.situation_clocking_event_exception_situation": "Situação de exceção",
    "hcm_clocking_event_foundation.general.situation_clocking_event_form_general_title": "Situação do ponto",
    "hcm_clocking_event_foundation.general.situation_clocking_event_form_title": "Situação do ponto",
    "hcm_clocking_event_foundation.general.situation_clocking_event_id": "Identificador único",
    "hcm_clocking_event_foundation.general.situation_clocking_event_last_modified_by": "Última modificação",
    "hcm_clocking_event_foundation.general.situation_clocking_event_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.situation_clocking_event_list_grid_title": "Lista de situações do ponto",
    "hcm_clocking_event_foundation.general.situation_clocking_event_list_title": "Situações do ponto",
    "hcm_clocking_event_foundation.general.situation_clocking_event_mandatory_adjustment_reason": "Motivo de acerto obrigatório",
    "hcm_clocking_event_foundation.general.situation_clocking_event_obligate_attachment_on_leave": "Obrigar anexo no afastamento",
    "hcm_clocking_event_foundation.general.situation_clocking_event_situation_code": "Código",
    "hcm_clocking_event_foundation.general.situation_clocking_event_situation_name": "Descrição",
    "hcm_clocking_event_foundation.general.situation_clocking_event_situation_search_title": "Pesquisa de situações",
    "hcm_clocking_event_foundation.general.situation_clocking_event_situation": "Situação",
    "hcm_clocking_event_foundation.general.situation_code": "Código",
    "hcm_clocking_event_foundation.general.situation_deleted": "Indica se o registro foi excluído",
    "hcm_clocking_event_foundation.general.situation_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.situation_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.situation_ext_int_msg": "Indica a mensagem da replicação",
    "hcm_clocking_event_foundation.general.situation_ext_int_sts": "Indica status da replicação",
    "hcm_clocking_event_foundation.general.situation_id": "Identificador único",
    "hcm_clocking_event_foundation.general.situation_name": "Nome",
    "hcm_clocking_event_foundation.general.situation_situation_type_placeholder": "Selecione o tipo da situação",
    "hcm_clocking_event_foundation.general.situation_situation_type": "Tipo da situação",
    "hcm_clocking_event_foundation.general.situation_type_absences": "Faltas",
    "hcm_clocking_event_foundation.general.situation_type_citizencompanymaternity": "Maternidade empresa cidadã",
    "hcm_clocking_event_foundation.general.situation_type_citizencompanypaternity": "Paternidade empresa cidadã",
    "hcm_clocking_event_foundation.general.situation_type_collectivevacation": "Férias coletivas",
    "hcm_clocking_event_foundation.general.situation_type_illnessaid": "Auxílio doença",
    "hcm_clocking_event_foundation.general.situation_type_inssmaternityleave": "Licença maternidade INSS",
    "hcm_clocking_event_foundation.general.situation_type_laboraccident": "Acidente de trabalho",
    "hcm_clocking_event_foundation.general.situation_type_leavewithoutcompensation": "Licença sem remuneração",
    "hcm_clocking_event_foundation.general.situation_type_maternityleave": "Licença maternidade",
    "hcm_clocking_event_foundation.general.situation_type_medicalleave": "Licença médica (pgto Empresa)",
    "hcm_clocking_event_foundation.general.situation_type_militaryservice": "Serviço militar",
    "hcm_clocking_event_foundation.general.situation_type_others": "Outros",
    "hcm_clocking_event_foundation.general.situation_type_overtime": "Horas extras",
    "hcm_clocking_event_foundation.general.situation_type_paidleave": "Licença remunerada",
    "hcm_clocking_event_foundation.general.situation_type_paternityleave": "Licença paternidade",
    "hcm_clocking_event_foundation.general.situation_type_precautionreadiness": "Sobreaviso/Prontidão",
    "hcm_clocking_event_foundation.general.situation_type_retirementduetodisability": "Aposentadoria por invalidez",
    "hcm_clocking_event_foundation.general.situation_type_timeevaluationsituation": "Situação de apuração ponto",
    "hcm_clocking_event_foundation.general.situation_type_tradeunionmandate": "Mandato sindical",
    "hcm_clocking_event_foundation.general.situation_type_vacation": "Férias",
    "hcm_clocking_event_foundation.general.situation_type_workaccidentleave": "Licença acidente de trabalho (pgto empresa)",
    "hcm_clocking_event_foundation.general.situation_type_working": "Trabalhando",
    "hcm_clocking_event_foundation.general.situation": "Situação",
    "hcm_clocking_event_foundation.general.success_tooltip": "Sucesso",
    "hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt_placeholder": "Selecione uma opção do artigo 62 da CLT",
    "hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt": "Artigo 62 da CLT",
    "hcm_clocking_event_foundation.general.time_evaluation_history_clocking_adjustment": "Ajusta ponto",
    "hcm_clocking_event_foundation.general.time_evaluation_history_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_history_employee_person_nom_pes": "Nome do Colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_history_employee_search_title": "Pesquisa de colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_history_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_history_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_history_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_history_form_general_title": "Histórico de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_form_title": "Histórico de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_id": "Identificador único",
    "hcm_clocking_event_foundation.general.time_evaluation_history_list_grid_title": "Lista de históricos de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_list_title": "Históricos de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_process_adjustment": "Participa do processo de acerto",
    "hcm_clocking_event_foundation.general.time_evaluation_history_situation_definition_search_title": "Busca de definições de situações",
    "hcm_clocking_event_foundation.general.time_evaluation_history_situation_definition": "Definição de situações",
    "hcm_clocking_event_foundation.general.time_evaluation_history_start_date": "Início da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_time_evaluation_type_placeholder": "Selecione um tipo de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_time_evaluation_type": "Tipo de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history": "Histórico de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_code": "Código",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_form_general_title": "Definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_form_title": "Definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_on_relay_schedule_holidays_search_title": "Pesquisa das situações de faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_on_relay_schedule_holidays_situation_code": "Código da situação de faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_on_relay_schedule_holidays_situation_name": "Descrição da situação de faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_on_relay_schedule_holidays": "Situação de faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_search_title": "Pesquisa das situações de falta",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_situation_code": "Código da situação de falta",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_situation_name": "Descrição da situação de falta",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation": "Situação de falta",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_daily_rest_violation_situation_search_title": "Pesquisa das situações de violação de interjornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_daily_rest_violation_situation_situation_code": "Código da situação de violação de interjornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_daily_rest_violation_situation_situation_name": "Descrição da situação de violação de interjornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_daily_rest_violation_situation": "Situação de violação de interjornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_early_leave_situation_search_title": "Pesquisa das situações de saída antecipada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_early_leave_situation_situation_code": "Código da situação de saída antecipada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_early_leave_situation_situation_name": "Descrição da situação de saída antecipada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_early_leave_situation": "Situação de saída antecipada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_end_date": "Data final",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_form_detail_title": "Detalhes do histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_form_general_title": "Histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_form_title": "Histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_id": "Identificador único",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_intermediate_leave_situation_search_title": "Pesquisa das situações de saída intermediária",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_intermediate_leave_situation_situation_code": "Código da situação de saída intermediária",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_intermediate_leave_situation_situation_name": "Descrição da situação de saída intermediária",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_intermediate_leave_situation": "Situação de saída intermediária",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_invalid_events_situation_search_title": "Pesquisa das situações marcações inválidas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_invalid_events_situation_situation_code": "Código da situação marcações inválidas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_invalid_events_situation_situation_name": "Descrição da situação marcações inválidas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_invalid_events_situation": "Situação marcações inválidas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_leave_overtime_search_title": "Pesquisa das situações extras da saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_leave_overtime_situation_code": "Código da situação extra da saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_leave_overtime_situation_name": "Descrição da situação extra da saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_leave_overtime": "Extras da saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_list_grid_title": "Lista de históricos da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_list_title": "Históricos da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_overtime_premium_situation_search_title": "Pesquisa de situações de adicional noturno extras",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_overtime_premium_situation_situation_code": "Código da situação de adicional noturno extra",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_overtime_premium_situation_situation_name": "Descrição da situação de adicional noturno extra",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_overtime_premium_situation": "Situação de adicional noturno extras",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_work_premium_search_title": "Pesquisa de situações adicional noturno trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_work_premium_situation_code": "Código da situação adicional noturno trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_work_premium_situation_name": "Descrição da situação adicional noturno trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_work_premium": "Adicional noturno trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_normal_overtime_separation_limit": "Limite separação de extras normais",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_after_search_title": "Pesquisa de situações extras após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_after_situation_code": "Código da situação extra após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_after_situation_name": "Descrição da situação extra após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_after": "Extras após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_before_search_title": "Pesquisa de situações extras antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_before_situation_code": "Código da situação extra antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_before_situation_name": "Descrição da situação extra antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_before": "Extras antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_day_off_search_title": "Pesquisa de situações extras na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_day_off_situation_code": "Código da situação extra na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_day_off_situation_name": "Descrição da situação extra na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_day_off": "Extras na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_holiday_search_title": "Pesquisa de situações extras no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_holiday_situation_code": "Código da situação extra no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_holiday_situation_name": "Descrição da situação extra no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_holiday": "Extras no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_meal_search_title": "Pesquisa de situações extras na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_meal_situation_code": "Código da situação extra na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_meal_situation_name": "Descrição da situação extra na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_meal": "Extras na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_rest_search_title": "Pesquisa de situações extras no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_rest_situation_code": "Código da situação extra no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_rest_situation_name": "Descrição da situação extra no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_rest": "Extras no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_entry_search_title": "Pesquisa de situações extras na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_entry_situation_code": "Código da situação extra na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_entry_situation_name": "Descrição da situação extra na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_entry": "Extras na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_on_compensated_days_search_title": "Pesquisa de situações extras no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_on_compensated_days_situation_code": "Código da situação extra no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_on_compensated_days_situation_name": "Descrição da situação extra no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_on_compensated_days": "Extras no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_after_search_title": "Pesquisa de situações Extras Separação Após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_after_situation_code": "Código da situação extra separação após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_after_situation_name": "Descrição da situação extra separação após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_after": "Extras Separação Após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_before_search_title": "Pesquisa de situações Extras Separação Antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_before_situation_code": "Código da situação extra separação antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_before_situation_name": "Descrição da situação extra separação antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_before": "Extras Separação Antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_compensated_days_search_title": "Pesquisa de situações Extras Separação no Compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_compensated_days_situation_code": "Código da situação extra separação no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_compensated_days_situation_name": "Descrição da situação extra separação no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_compensated_days": "Extras Separação no Compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_day_off_search_title": "Pesquisa de situações Extras Separação na Folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_day_off_situation_code": "Código da situação extra separação na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_day_off_situation_name": "Descrição da situação extra separação na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_day_off": "Extras Separação na Folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_holiday_search_title": "Pesquisa de situações Extras Separação no Feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_holiday_situation_code": "Código da situação extra separação no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_holiday_situation_name": "Descrição da situação extra separação no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_holiday": "Extras Separação no Feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_meal_search_title": "Pesquisa de situações Extras Separação na Refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_meal_situation_code": "Código da situação extra separação na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_meal_situation_name": "Descrição da situação extra separação na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_meal": "Extras Separação na Refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_rest_search_title": "Pesquisa de situações Extras Separação no Descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_rest_situation_code": "Código da situação extra separação no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_rest_situation_name": "Descrição da situação extra separação no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_rest": "Extras Separação no Descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_entry_search_title": "Pesquisa de situações Extras Separação na Entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_entry_situation_code": "Código da situação extra separação na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_entry_situation_name": "Descrição da situação extra separação na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_entry": "Extras Separação na Entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_leave_search_title": "Pesquisa de situações Extras Separação na Saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_leave_situation_code": "Código da situação extra separação na saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_leave_situation_name": "Descrição da situação extra separação na saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_leave": "Extras Separação na Saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_limit_during_compensated_days": "Limite separação de extras no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_limit_during_day_off": "Limite separação de extras na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_limit_during_holiday": "Limite separação de extras no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_limit_during_rest": "Limite separação de extras no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_situation_on_relay_schedule_holidays_search_title": "Pesquisa de situações de extra no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_situation_on_relay_schedule_holidays_situation_code": "Código da situação de extra no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_situation_on_relay_schedule_holidays_situation_name": "Descrição da situação de extra no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_situation_on_relay_schedule_holidays": "Situação de extra no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_percentage_next_day": "Percentual dia seguinte",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_separate_overtime_after_converting_night_shift_hours": "Separar extras após conversão das noturnas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situation_definition_code": "Código",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situation_definition_name": "Descrição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situation_definition_search_title": "Pesquisa de definições das situações",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situation_definition": "Definição de situações",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_absence": "Ausências",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_extra": "Extras",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_general": "Gerais",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_normal_overtimes": "Extras normais",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_other_overtimes": "Outros parâmetros",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_overtimes_during_day_off": "Extras na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_overtimes_during_holiday": "Extras no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_overtimes_during_rest": "Extras no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_overtimes_on_compensated_days": "Extras no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_start_date": "Data de alteração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_tardiness_situation_search_title": "Pesquisa de situações de atraso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_tardiness_situation_situation_code": "Código da situação de atraso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_tardiness_situation_situation_name": "Descrição da situação de atraso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_tardiness_situation": "Situação de atraso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_unauthorized_overtime_search_title": "Pesquisa de situações extras não autorizadas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_unauthorized_overtime_situation_code": "Código da situação extra não autorizada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_unauthorized_overtime_situation_name": "Descrição da situação extra não autorizada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_unauthorized_overtime": "Extras não autorizadas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_vacation_paid_leave_situation_search_title": "Pesquisa de situações licença remunerada férias",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_vacation_paid_leave_situation_situation_code": "Código da situação licença remunerada férias",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_vacation_paid_leave_situation_situation_name": "Descrição da situação licença remunerada férias",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_vacation_paid_leave_situation": "Situação licença remunerada férias",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_break_violation_situation_search_title": "Pesquisa de situações de violação de intrajornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_break_violation_situation_situation_code": "Código da situação de violação de intrajornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_break_violation_situation_situation_name": "Descrição da situação de violação de intrajornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_break_violation_situation": "Situação de violação de intrajornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_situation_search_title": "Pesquisa de situações de trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_situation_situation_code": "Código da situação de trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_situation_situation_name": "Descrição da situação de trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_situation": "Situação de trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history": "Histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_id": "Identificador único",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_list_grid_title": "Lista das definições de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_list_title": "Definições das situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_name": "Descrição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition": "Definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_1": "Normal",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_2": "Dispensado do ponto",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_3": "Somente refeitório",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_4": "Dispensado do ponto - desconsidera todas as marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_5": "Sem controle de ponto e refeitório",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_6": "Dispensado do ponto - desconsiderar marcações de ponto",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_7": "Ponto por exceção",
    "hcm_clocking_event_foundation.general.total_records": "{{value}} registro(s) encontrado(s)",
    "hcm_clocking_event_foundation.general.true_label": "Sim",
    "hcm_clocking_event_foundation.general.updated_by": "Atualizado por",
    "hcm_clocking_event_foundation.general.work_schedule_change_date": "Data da troca",
    "hcm_clocking_event_foundation.general.work_schedule_change_employee_code": "Contrato",
    "hcm_clocking_event_foundation.general.work_schedule_change_employee_person_nom_pes": "Colaborador",
    "hcm_clocking_event_foundation.general.work_schedule_change_employee_search_title": "Pesquisa de colaborador",
    "hcm_clocking_event_foundation.general.work_schedule_change_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.work_schedule_change_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.work_schedule_change_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.work_schedule_change_form_general_title": "Troca de horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_form_title": "Trocas de horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_id": "Identificador único",
    "hcm_clocking_event_foundation.general.work_schedule_change_list_grid_title": "Lista de trocas de horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_list_title": "Trocas de horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_work_schedule_code": "Código do horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_work_schedule_name": "Descrição do horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_work_schedule_search_title": "Pesquisa de horários",
    "hcm_clocking_event_foundation.general.work_schedule_change_work_schedule": "Horário",
    "hcm_clocking_event_foundation.general.work_schedule_change": "Troca de horário",
    "hcm_clocking_event_foundation.general.workschedule_code": "Código",
    "hcm_clocking_event_foundation.general.workschedule_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.workschedule_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.workschedule_deleted": "Indica se o registro foi excluído",
    "hcm_clocking_event_foundation.general.workschedule_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.workschedule_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.workschedule_ext_int_msg": "Indica a mensagem da replicação",
    "hcm_clocking_event_foundation.general.workschedule_ext_int_sts": "Indica status da replicação",
    "hcm_clocking_event_foundation.general.workschedule_id": "Identificador único",
    "hcm_clocking_event_foundation.general.workschedule_last_modified_by": "Última modificação por",
    "hcm_clocking_event_foundation.general.workschedule_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.workschedule_name": "Descrição horário",
    "hcm_clocking_event_foundation.general.workschedule": "Horário",
    "hcm_clocking_event_foundation.general.workshift_change_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.workshift_change_employee_person_nom_pes": "Nome do colaborador",
    "hcm_clocking_event_foundation.general.workshift_change_employee_search_title": "Colaborador",
    "hcm_clocking_event_foundation.general.workshift_change_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.workshift_change_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.workshift_change_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.workshift_change_end_date": "Data Final",
    "hcm_clocking_event_foundation.general.workshift_change_form_general_title": "Troca de escala",
    "hcm_clocking_event_foundation.general.workshift_change_form_title": "Troca de escala",
    "hcm_clocking_event_foundation.general.workshift_change_id": "Identificador único",
    "hcm_clocking_event_foundation.general.workshift_change_list_grid_title": "Lista de trocas de escala",
    "hcm_clocking_event_foundation.general.workshift_change_list_title": "Trocas de escala",
    "hcm_clocking_event_foundation.general.workshift_change_start_date": "Data Inicial",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_code": "Escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_group_code": "Turma de escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_group_search_title": "Turma de escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_group": "Turma de escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_search_title": "Escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_short_name": "Descrição da escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift": "Escala",
    "hcm_clocking_event_foundation.general.workshift_change": "Troca de escala",
    "hcm_clocking_event_foundation.general.workshift_code": "Escala",
    "hcm_clocking_event_foundation.general.workshift_group_code": "Turma de escala",
    "hcm_clocking_event_foundation.general.workshift_group_base_date": "Data base",
    "hcm_clocking_event_foundation.general.workshift_short_name": "Descrição da escala",
    "hcm_clocking_event_foundation.general.yes": "Sim",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_type": "Tipo de escala",
    "platform.backend.hcm_clocking_event_foundation_general_adjustment_reason_situation": "Motivo por Situação",
    "platform.backend.hcm_clocking_event_foundation_general_adjustment_reason": "Motivo de Acerto",
    "platform.backend.hcm_clocking_event_foundation_general_bridge": "Ponte",
    "platform.backend.hcm_clocking_event_foundation_general_compensation": "Compensação",
    "platform.backend.hcm_clocking_event_foundation_general_computation": "Cálculos",
    "platform.backend.hcm_clocking_event_foundation_general_definition": "Definições",
    "platform.backend.hcm_clocking_event_foundation_general_employees_histories": "Históricos",
    "platform.backend.hcm_clocking_event_foundation_general_employees": "Colaboradores",
    "platform.backend.hcm_clocking_event_foundation_general_overtime_authorization": "Autorização de Hora Extra",
    "platform.backend.hcm_clocking_event_foundation_general_readiness": "Sobreaviso",
    "platform.backend.hcm_clocking_event_foundation_general_records": "Cadastros",
    "platform.backend.hcm_clocking_event_foundation_general_register_justification": "Justificativa de Acerto",
    "platform.backend.hcm_clocking_event_foundation_general_scheduling": "Programações",
    "platform.backend.hcm_clocking_event_foundation_general_time_evaluation_definition": "Definição de Apuração",
    "platform.backend.hcm_clocking_event_foundation_general_time_evaluation_history": "Histórico de Apuração",
    "platform.backend.hcm_clocking_event_foundation_general_time_evaluation_situation_definition": "Situações de Apuração",
    "platform.backend.hcm_clocking_event_foundation_general_time_evaluation": "Apuração",
    "platform.backend.hcm_clocking_event_foundation_general_work_schedule_change": "Troca de Horário",
    "platform.backend.hcm_clocking_event_foundation_general_workshift_change": "Troca de Escala",
    "platform.backend.hcm_clocking_event_foundation_records": "Cadastros",
    "hcm_clocking_event_foundation.general.validation_date_is_after_hire_date": "Data de troca deve ser maior que a data de admissão do colaborador",
    "hcm_clocking_event_foundation.general.validation_date_is_before_dismissal_date": "Data de troca deve ser menor que a data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_definition": "Definição de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_allow_clocking_event_modification_before_transference": "Alterar ponto antes da transferência de filial",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_allow_register_clocking_event_without_verification": "Permitir gravar marcações sem apurar",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_automatic_recalculation_scheduling_leave": "Recálculo automático em programações/afastamentos",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_bridge_overlaps_workschedule_change": "Ponte sobrepõe troca de horário",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_calculate_holiday_absence_rotation_workshift": "Calcular faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_calculate_readiness": "Calcular sobreaviso",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_clocking_event_interval": "Intervalo entre marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_clocking_event_tolerance": "Tolerância por marcação e dia",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_code": "Código",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_complement_work_waiting_time": "Complementar trabalho com cálculo de espera",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_bridge_for_projection": "Considerar pontes para projeção em dias de folga",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_clocking_event_interval": "Considerar intervalo",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_clocking_event_interval_placeholder": "Escolha como considerar intervalo",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_direction_clocking_event_order": "Considerar direção pela ordem de marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_pairs_day_off_day": "Considerar pares dias de folga",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_pairs_normal_day": "Considerar pares dias normais",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_workschedule_change_for_projection": "Considerar troca de horário para projeção",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_control_adjustment_reason": "Controlar motivos de acerto",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_control_observation": "Controlar observação",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_days_resume": "Dias para retomar",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_discount_hours_worked_readiness": "Descontar horas trabalhadas do sobreaviso",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_dismissal_situation": "Situação de demissão",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_eliminate_clocking_event": "Eliminar marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_evaluate_incomplete_journey": "Apurar jornada incompleta",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_form_general_title": "Definição de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_form_title": "Definição de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_id": "Identificador único",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_incomplete_journey_situation": "Situação para jornada incompleta",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_incomplete_journey_situation_search_title": "Pesquisa de situações de jornada incompleta",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_justify_clocking_event": "Justificar marcações digitadas",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_limit_days_backward_scheduling": "Limite de dias para programações retroativas",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_list_grid_title": "Lista de definições de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_list_title": "Definições de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_name": "Descrição",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_night_hours_calculation": "Cálculo conversão noturnas",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_number_of_days_adjustment": "Quantidade de dias para realizar acertos",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_number_of_hours_journey_separation": "Separação jornada dia normal",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_retroactive_adjustment": "Acerto retroativo",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_retroactive_adjustment_placeholder": "Escolha o tipo de acerto retroativo",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_scheduling_overlaps_holiday": "Programação sobrepõe feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_use_clocking_event_direction_allocation": "Utilizar direção para alocação",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_use_clocking_event_regularization": "Utiliza regularização de marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_use_workschedule_day_off": "Utilizar horário na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_verified_days_control": "Controle de dias verificados",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_verified_days_control_placeholder": "Escolha o tipo de controle de dias verificados",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_general": "Gerais",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_clocking_event": "Marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_schedules_readiness": "Programações/Afastamentos",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_adjustment_process": "Processo de Acerto",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_form_detail_title": "Detalhes da definição de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_incomplete_journey_situation_code": "Código da jornada incompleta",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_incomplete_journey_situation_name": "Descrição da jornada incompleta",
    "hcm_clocking_event_foundation.general.verified_days_control_type_v_0": "Não utilizar",
    "hcm_clocking_event_foundation.general.verified_days_control_type_v_1": "Obrigatório",
    "hcm_clocking_event_foundation.general.verified_days_control_type_v_2": "Opcional",
    "hcm_clocking_event_foundation.general.validation_employee_has_currently_this_work_shift": "Este colaborador já tem a escala selecionada. Deseja continuar mesmo assim?",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_expiration_days": "Dias para Expiração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_limit_of_days_after_point_closing": "Limite de dias após fechamento do ponto",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_block_pending_after_expires": "Bloqueia pendência após expirar",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_allows_take_ledger_pending": "Permite assumir pendência do liderado",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_allows_complete_untreated_pending": "Permite concluir pendência não tratada",
    "hcm_clocking_event_foundation.general.time_evaluation_history_clocking_adjustment_info_sign": "Este campo só poderá ser habilitado se o campo \"Participa do processo de acerto\" estiver selecionado",
    "hcm_clocking_event_foundation.general.time_evaluation_history_approve_own_clocking_info_sign": "Este campo só poderá ser habilitado se o campo \"Participa do processo de acerto\" e o \"Ajusta ponto\" estiverem selecionados",
    "hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt_info_sign": "Este campo só poderá ser habilitado se o campo \"Tipo de apuração\" estiver selecionado com \"Dispensado do ponto\"",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_group_info_sign": "Este campo só poderá ser habilitado se o campo \"Escala\" estiver preenchido",
    "platform.backend.hcm_clocking_event": "Gestão do ponto",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_type_permanent": "Permanente",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_type_automatic_search": "Busca automática",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_form_general_title": "Troca de horário - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_employees": "Colaboradores",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_companies": "Empresas",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_employee_search_title": "Pesquisa de colaboradores",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_companies_search_title": "Pesquisa de empresas",
    "hcm_clocking_event_foundation.general.bridge_collective_form_general_title": "Ponte - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.collective_employees": "Colaboradores",
    "hcm_clocking_event_foundation.general.collective_companies": "Empresas",
    "hcm_clocking_event_foundation.general.collective_employee_search_title": "Pesquisa de colaboradores",
    "hcm_clocking_event_foundation.general.collective_companies_search_title": "Pesquisa de empresas",
    "hcm_clocking_event_foundation.general.workshift_change_collective_form_general_title": "Troca de escala - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.readiness_collective_form_general_title": "Sobreaviso - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.overtime_authorization_collective_form_general_title": "Autorização de horas extras - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_history_start_date_is_equal_to_hire_date": "Não é permitido excluir o histórico de apuração com início igual a data de admissão do colaborador.",
    "hcm_clocking_event_foundation.general.compensation_collective_delete_form_title": "Compensação - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.compensation_collective_delete_form_general_title": "Compensação - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.bridge_collective_delete_form_general_title": "Ponte - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.bridge_collective_delete_form_title": "Ponte - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.readiness_collective_delete_form_general_title": "Sobreaviso - Exclusão Coletiva",
    "hcm_clocking_event_foundation.general.readiness_collective_delete_form_title": "Sobreaviso - Exclusão Coletiva",
    "hcm_clocking_event_foundation.general.workshift_change_collective_delete_form_title": "Troca de escala - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.workshift_change_collective_delete_form_general_title": "Troca de escala - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.remove_collective": "Excluir coletivamente",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_delete_form_title": "Troca de horário - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_delete_form_general_title": "Troca de horário - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_form_title": "Troca de horário - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.workshift_change_collective_form_title": "Troca de escala - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.bridge_collective_form_title": "Ponte - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.readiness_collective_form_title": "Sobreaviso - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.overtime_authorization_collective_form_title": "Autorização de horas extras - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.overtime_authorization_delete_collective_form_title": "Autorização de horas extras - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.overtime_authorization_collective_delete_form_general_title": "Autorização de horas extras - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.compensation_collective_form_title": "Compensação - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_clocking_event_tolerance_placeholder": "Escolha o tipo de tolerância por marcação e dia",
    "hcm_clocking_event_foundation.general.time_evaluation_history_collective_form_title": "Histórico de apuração - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_history_collective_form_general_title": "Histórico de apuração - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_history_collective_delete_form_general_title": "Histórico de apuração - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_history_collective_delete_form_title": "Histórico de apuração - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.situation_has_no_situation_clocking_event": "A situação não possui definição geral do ponto",
    "hcm_clocking_event_foundation.general.situation_type_maternityleavenoncriminalabortion": "Licença maternidade - Aborto não criminoso",
    "hcm_clocking_event_foundation.general.situation_type_maternityleaveanticipationextension": "Licença maternidade - Prorrogação mediante atestado médico",
    "hcm_clocking_event_foundation.general.situation_type_workaccidentleavewithoutinss": "Licença acidente de trabalho sem incidência INSS",
    "hcm_clocking_event_foundation.general.situation_type_medicalleavewithoutinss": "Licença médica sem incidência INSS",
    "hcm_clocking_event_foundation.general.activate_incomplete_journey": "Ative a apuração de jornada incompleta para preencher o campo",
    "hcm_clocking_event_foundation.general.error_start_date_time_after_end_date_time_to_start_date": "A data/hora inicial deve ser menor que a data/hora final",
    "hcm_clocking_event_foundation.general.error_start_date_time_after_end_date_time_to_end_date": "A data/hora final deve ser maior que a data/hora inicial"
};

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: senior-gestao-pessoas-hcm-clocking-event-foundation-schedules-histories.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AdjustmentReason, AdjustmentReasonService, AdjustmentReasonSituation, AdjustmentReasonSituationService, Bridge, BridgeFormComponent, BridgeFormModule, BridgeService, ClockingEventToleranceType, CompanyClockingEventIndications, CompanyClockingEventIndicationsService, Compensation, CompensationFormComponent, CompensationFormModule, CompensationService, CompensationType, ConsiderClockingEventIntervalType, CoreSchedulesHistoriesModule, E001Pes, E001PesService, Employee, EmployeeService, FieldCustomizationService, FiltersStorageService, FocusService, OvertimeAuthorization, OvertimeAuthorizationFormComponent, OvertimeAuthorizationFormModule, OvertimeAuthorizationService, PaginatorStorageService, PeriodType, Readiness, ReadinessFormComponent, ReadinessFormModule, ReadinessService, RetroactiveAdjustmentType, Situation, SituationClockingEvent, SituationClockingEventService, SituationService, StorageService, TimeEvaluationDefinition, TimeEvaluationDefinitionService, TimeEvaluationSituationDefinition, TimeEvaluationSituationDefinitionHistory, TimeEvaluationSituationDefinitionHistoryService, TimeEvaluationSituationDefinitionService, VerifiedDaysControlType, WorkScheduleChange, WorkScheduleChangeFormComponent, WorkScheduleChangeFormModule, WorkScheduleChangeService, Workschedule, WorkscheduleService, Workshift, WorkshiftChange, WorkshiftChangeFormComponent, WorkshiftChangeFormModule, WorkshiftChangeService, WorkshiftGroup, WorkshiftGroupService, WorkshiftService, convertMinutesToTime, convertTimeToMinutes, fallback, getTypeInformation, isValidFilter, mergeUnique, SharedScheduleModule as ɵa, EntityService as ɵb, BridgeModule as ɵc, OvertimeAuthorizationModule as ɵd, EmployeeModule as ɵe, E001PesModule as ɵf, CompanyClockingEventIndicationsModule as ɵg, TimeEvaluationDefinitionModule as ɵh, SituationModule as ɵi, TimeEvaluationSituationDefinitionModule as ɵj, TimeEvaluationSituationDefinitionHistoryModule as ɵk, SituationClockingEventModule as ɵl, WorkscheduleModule as ɵm, WorkScheduleChangeModule as ɵn, ReadinessModule as ɵo, WorkshiftChangeModule as ɵp, WorkshiftGroupModule as ɵq, WorkshiftModule as ɵr, CompensationModule as ɵs, AdjustmentReasonModule as ɵt, AdjustmentReasonSituationModule as ɵu };
//# sourceMappingURL=senior-gestao-pessoas-hcm-clocking-event-foundation-schedules-histories.js.map
